/*==========================================================*
Paper: 		"The impacts of microcredit: Evidence from B&H"

Purpose:		This do-file: 
				Conducts Multiple Hypothesis testing using
				Romano Wolf procedure
\				
Code Author: 	IFS
Date created: 	Feb 2013
Last modified:  

Note:			see "readme"-file for info
				Adjust working directory paths in lines 19 & 73
*===========================================================*/
capture log close
set more off
adopath+"C:\ado"
drop _all
global workdir "XXX"	// adjust also in line 73!		
cap mkdir "${workdir}"	
cd "${workdir}"						

*-------------------*
*	 PREPARE DATA:	*
*-------------------*

	use "data\Baseline\Covariates Bosnia Baseline.dta", clear
	gen b_resp_age2=b_resp_age*b_resp_age 
	merge 1:1 intervid using "data\indicator reinterviewed.dta", nogen
	* merge in OUTCOMES:
	merge 1:1 intervid using "data\Followup\Employment status respondent.dta", nogen keepusing(resp_es2)
	merge 1:1 intervid using "data\Followup\SECTION 2 - Loans cl.dta", nogen
	merge 1:1 intervid using "data\Followup\SECTION 3 - Consumption cl.dta", nogen /*keepusing(durablec nondc foodc_h foodc_o cigalcc foodc)*/
	merge 1:1 intervid using "data\Followup\SECTION 4 - Assets cl.dta",  nogen
	merge 1:1 intervid using "data\Followup\SECTION 5 - Income cl.dta", nogen 
	merge 1:1 intervid using "data\Followup\SECTION 6 - Business cl.dta", nogen keepusing(bm_own bm_expenses bm_revenue bm_profit bm_staff_FT bm_staff_PT bm_staff_T  bm_staffsalary   bm_staff_hhft bm_staff_hhpt bm_staff_hht bm_staff_hhpay bm_staff_outft bm_staff_outpt bm_staff_outt bm_staff_outpay bm_trade bm_service bm_agric bm_prod  bm_reg)
	merge 1:1 intervid using "data\Followup\SECTION 7 - Savingscl.dta", nogen keepusing(savings_avg savings_yn contrib_weekly contrib_monthly contrib_yearly contrib_no sav_busexp sav_edu sav_med sav_old sav_repair sav_emergency sav_cons sav_bequest sav_debt sav_festival sav_other)
	merge 1:1 intervid using "data\Followup\SECTION 8 - Household roster cl.dta", nogen
	merge 1:1 intervid using "data\Followup\SECTION 9 - Shocks cl.dta", nogen keepusing(jobloss_yn jobgain_yn othergain_yn badharvest_yn illnessearn_yn illnessnonearn_yn deathearn_yn deathnonearn_yn emplleft_yn crime_yn compet_yn otherloss_yn jobgain_yn othergain_yn jobloss_ydec badharvest_ydec illnessearn_ydec illnessnonearn_ydec deathearn_ydec deathnonearn_ydec emplleft_ydec crime_ydec compet_ydec otherloss_ydec)
	merge 1:1 intervid using "data\Followup\SECTION 10 - Stress cl.dta", nogen
	merge 1:1 intervid using "data\incentive given.dta", nogen

*-- GLOBALS
	#d ;
		global Xvar "b_resp_female b_resp_age b_resp_age2 b_resp_ms1 b_resp_ms4 b_resp_ms5  b_resp_ss b_resp_ul
			 b_kids_05 b_kids_610 b_kids_1116 b_hhmem_female  b_hhmem_employed b_hhmem_school b_hhmem_retired";
		global Edu "t_edul t_eduh respedu_l";
		global Busi "t_busi t_nobus b_bm_own";
		global Xvaredu "b_resp_female b_resp_age b_resp_age2 b_resp_ms1 b_resp_ms4 b_resp_ms5  
			 b_kids_05 b_kids_610 b_kids_1116 b_hhmem_female  b_hhmem_employed b_hhmem_school b_hhmem_retired";
	#d cr


*-------------------*
*	 PREPARE DATA:	*
*-------------------*
	do "Multiple Hypothesis testing\do-files\(0) prepare data.do"
	
	* make sure no capitals in var names
	rename assetvalueTR3p assetvaluetr3p
	rename 	bm_revenueTR1p bm_revenuetr1p
	rename 	bm_profitTR1p bm_profittr1p
	rename 	totalcTR totalctr
	rename 	educ_yrTR educ_yrtr
	rename 	durableTR durabletr
	rename 	nondcTR nondctr
	rename 	nondcTR_tot nondctr_tot
	rename 	HDGI hdgi

*-----------------------*
*	 CHANGE DIRECTORY:	*
*-----------------------*
	global workdir "XXX"		
	cap mkdir "${workdir}"	
	cd "${workdir}"						

	
*---------------------------*
*	 GLOBALS FOR TABLES:	*
*---------------------------*

	global Loan "loan loans f_l_mfi f_l_bank"	// f_l_percB f_lamount_mfi f_lamount_bank f_loanamount
	global T3 "assetvalueTR3p inventory bm_revenue bm_revenuetr1p bm_expenses bm_profit bm_profittr1p bm_profitcalc y_selfempl bm_own bm_service bm_agric b_start b_close bm_profit01"
	global T4Income01 "y_selfempl yval_selfempl y_wages yval_wages y_agric yval_agric y_shop yval_shop y_manuf yval_manuf y_privb yval_privb y_governmnt yval_governmnt y_remit yval_remit y_benefit yval_benefit y_pension yval_pension y_rent"
	global LabourSupply "$AllAdults $AllAdultsPM $Teens $TeensPM $Teens1619 $Teens1619PM"
	global YvarCons "totalc totalc_cap totalctr foodc_h foodc_o foodc educ_yr educ_yrtr temptation_yr cigalcc  nondc durablec durabletr nondctr nondc_tot nondctr_tot recre_yr hdgi"
	global YvarSav "savings_avg savings_yn contrib_weekly contrib_monthly contrib_yearly contrib_no sav_busexp sav_edu sav_med sav_old sav_repair sav_emergency"

	* Put here the table you want to check
	global Table "loan loans f_l_mfi f_l_bank "
	
*-------------------------------*
*	 ESTIMATE FULL MODEL:		*
*-------------------------------*
*1. estimate 'full model', keep b, se, t (to identify largest)
foreach y in $Table  {
	eststo `y': reg `y' treat $Xvar if followup==1, robust
		local	b_`y' 	=_b[treatment]
		local 	se_`y'	=_se[treatment]
		g t_`y' =abs(_b[treatment]/_se[treatment])
	}

	local keep_coeffs "treatment"
	esttab $Table using "Estimates full model\Coeff_se_BosniaT2.csv", keep(`keep_coeffs') se(5) label replace plain nopar noobs
	esttab $Table using "Estimates full model\Coeff_t_BosniaT2.csv", keep(`keep_coeffs') t(5) label replace plain nopar noobs

	preserve
		clear
		insheet using "Estimates full model\Coeff_se_BosniaT2.csv", names
		drop in 1
		foreach x of varlist $Table {
		rename `x' b_`x'
		destring b_`x', replace
		}
		drop v1
		drop in 2 // drop standard errors 
		gen m=1	// this is for later merging
		save "Estimates full model\Coefficiens from actual regressionsT2.dta", replace
	restore

	preserve
		clear
		insheet using "Estimates full model\Coeff_se_BosniaT2.csv", names
		drop in 1
		foreach x of varlist $Table {
		rename `x' se_`x'
		destring se_`x', replace
		}
		drop v1
		drop in 1 // drop coefficients
		gen m=1	// this is for later merging
		save "Estimates full model\Standard errors from actual regressionsT2.dta", replace
	restore
	
	preserve
		clear
		insheet using "Estimates full model\Coeff_t_BosniaT2.csv", names
		drop in 1/2  // drop first row and coefficients
		foreach x of varlist $Table {
		rename `x' t_`x'
		destring t_`x', replace
		}
		drop v1
		gen m=1	// this is for later merging
		save "Estimates full model\T stats from actual regressionsT2.dta", replace
	restore

*---------------------------*
*	 BOOTSTRAPPING b':		*
*---------------------------*

keep $Table followup $Xvar treatment
keep if followup==1
su $Table
tempfile db_block1
save `db_block1'.dta, replace	/*ORIGINAL DATA SET TO USE IN BS*/

local B = 1000  /* NUMBER OF REPLICATIONS*/
g n = _n
set seed 1
tempname rwT2
postfile `rwT2' iter str22 y bb_ bse_ bn_ using rwT2.dta, replace


* BOOTSTRAP LOOP 
local I = 1
while `I' <= `B' {
	di as error "." _cont
	*qui {
		use `db_block1'.dta, clear
		
		* Block-Bootstrap at soum level */
		bsample 
		local counter = 1
		foreach vary of global Table {											
			qui reg `vary' treatment $Xvar if followup==1, robust
			local b  =_b[treatment]
			local se =_se[treatment]
			local n = e(N)

			post `rwT2' (`I') ("`vary'") (`b') (`se') (`n')
			}
			local counter = `counter' + 1
	local I = `I' + 1
} /*END BOOTSTRAP (WHILE) LOOP*/
postclose `rwT2'

	
*----------------------
* COMBINE DATA SETS:
*----------------------

use "rwT2.dta" , clear
reshape wide bb bse bn, i(iter) j(y) string
gen m=1
merge m:1 m using "Estimates full model\Coefficiens from actual regressionsT2.dta", nogen
merge m:1 m using "Estimates full model\Standard errors from actual regressionsT2.dta", nogen
merge m:1 m using "Estimates full model\T stats from actual regressionsT2.dta", nogen

*---------------------------*
*	 CALCULATE TTESTS:		*
*---------------------------*

*4. compute t-stat of interest = tt_`y' =[(bb_`y' - b_`y') / se_`y']

	foreach y in $Table {
		gen tt_`y' = abs((bb_`y' - b_`y') / bse_`y')
		}

*-------------------------*
* 99 Confidence Interval 
*-------------------------*
local j = 1
preserve

di "******************Iteration `j'*******************"
	* Highest tstat by iteration (step 4.a - alg 2.4)
	egen	max_tt_`j' = rowmax(tt_*)

	* Critical value as the 99th percentile of the max tstats distribution 
	sort 	max_tt_`j' 
	egen 	d_hat_`j' = pctile(max_tt_`j'), p(99)	
	
	di "********************Variables Above Critical T-stat Iteration `j'*******************"

	foreach y in $Table {
		* Reject S if tsat > critical value (step 3 - alg 4.1)
		g rej_`y'_`j'  = (abs(t_`y') > d_hat_`j')				/*REJECT IF ABS OF T > CRITICAL VALUE*/ 
		}
		
		* Display those that pass the test
		di "******************`y'*****************"
		sum d_hat_`j'
		sum rej_*_`j' t_*
restore	
exit	
		// IF SOME VARIABLES PASS (rej_*==1) and some don't (rej_*==0) THEN DO THE FOLLOWING MANUALLY:
		*(1) Drop variable that pass (i.e. those for which rej_*==1)
			*drop tt_XXX
		*(2) update the global "Tables" to the variables that did not pass (rej_*==0)
			*global Table "UPDATES"
		*(3) redo lines 213-235 above

		* Drop variable that pass (tt_XXX:
		drop XXX
		* Update global (excluding the variables dropped):
		global Table "XXX"


		// To get the critical value for 95%:
		   *(1) Change in line 202 p(99) to p(95)
		
