/*==========================================================*
Paper: 		"The impacts of microcredit: Evidence from B&H"

Purpose:		This do-file: 
				Creates the data set:
				"data\Followup\Household level info working hrs and schooling - teenagers.dta"
\				
Code Author: 	IFS
Date created: 	Feb 2013
Last modified:  

Note:			XXX 
*===========================================================*/
capture log close
set more off
adopath+"C:\ado"
drop _all
global workdir "XXX"		
cap mkdir "${workdir}"	
cd "${workdir}"						


// Get data 
use "data\Baseline\BL - SECTION 8 - Household roster cl.dta", clear	
merge intervid using "data\Baseline\Covariates Bosnia Baseline.dta", unique sort
	tab _m
	drop if _m==2	
	drop _m
	
// Preaparation of variables:
	egen hhmem=rowtotal(hhmem_male hhmem_female)
	* create age variable and clean working hrs and school attendance:
	forvalues i=1(1)9 {
		gen age0`i'=2010- o8_2_g0`i' // create year variable
		replace  o8_9_0`i'=0 if  o8_9_0`i'==. //clean working hours
		replace  o8_9_0`i'=. if  o8_9_0`i'>=100
		replace  o8_10_0`i'=0 if  o8_10_0`i'==. // clean working hours on business
		replace  o8_10_0`i'=. if  o8_10_0`i'>=100
		replace  o8_7_0`i'=0 if o8_7_0`i'==. // clean school attendance variable
		replace o8_7_0`i'=0 if o8_7_0`i'==2
		}
	forvalues i=10(1)12 {
		gen age`i'=2010- o8_2_g`i'
		replace  o8_9_`i'=0 if  o8_9_`i'==.
		replace  o8_9_`i'=. if  o8_9_`i'>=100
		replace  o8_10_`i'=0 if  o8_10_`i'==.
		replace  o8_10_`i'=. if  o8_10_`i'>=100
		replace  o8_7_`i'=0 if o8_7_`i'==. // clean school attendance variable
		replace o8_7_`i'=0 if o8_7_`i'==2
		}
	* create total working hours at hh level for different age groups:
	forvalues i=15(1)20 {
		gen hrswork_tot`i'=0
		gen hrswork_bus`i'=0
		gen schoolattend`i'=0
		gen count`i'=0
		}
	forvalues y=17(1)20 {
		gen hrswork_tot15`y'=0
		gen hrswork_tot16`y'=0
		gen count16`y'=0
		gen count15`y'=0
		forvalues i=1(1)9 {
			replace hrswork_tot15`y'=hrswork_tot15`y'+ o8_9_0`i' if age0`i'>=15 & age0`i'<=`y'
			replace hrswork_tot16`y'=hrswork_tot16`y'+ o8_9_0`i' if age0`i'>=16 & age0`i'<=`y'
			replace hrswork_tot15=hrswork_tot15+ o8_9_0`i' if age0`i'==15
			replace hrswork_tot16=hrswork_tot16+ o8_9_0`i' if age0`i'==16
			replace hrswork_tot17=hrswork_tot17+ o8_9_0`i' if age0`i'==17
			replace hrswork_tot18=hrswork_tot18+ o8_9_0`i' if age0`i'==18
			replace hrswork_tot19=hrswork_tot19+ o8_9_0`i' if age0`i'==19
			replace hrswork_tot20=hrswork_tot20+ o8_9_0`i' if age0`i'==20
			replace count15`y'=count15`y'+1 if age0`i'>=15 & age0`i'<=`y'
			replace count16`y'=count16`y'+1 if age0`i'>=16 & age0`i'<=`y'
			replace count15=count15+1 if age0`i'==15
			replace count16=count16+1 if age0`i'==16
			replace count17=count17+1 if age0`i'==17
			replace count18=count18+1 if age0`i'==18
			replace count19=count19+1 if age0`i'==19
			replace count20=count20+1 if age0`i'==20
			}
		forvalues i=10(1)12 {
			replace hrswork_tot15`y'=hrswork_tot15`y'+ o8_9_`i' if age`i'>=15 & age`i'<=`y'
			replace hrswork_tot16`y'=hrswork_tot16`y'+ o8_9_`i' if age`i'>=16 & age`i'<=`y'
			replace hrswork_tot15=hrswork_tot15+ o8_9_`i' if age`i'==15
			replace hrswork_tot16=hrswork_tot16+ o8_9_`i' if age`i'==16
			replace hrswork_tot17=hrswork_tot17+ o8_9_`i' if age`i'==17
			replace hrswork_tot18=hrswork_tot18+ o8_9_`i' if age`i'==18
			replace hrswork_tot19=hrswork_tot19+ o8_9_`i' if age`i'==19
			replace hrswork_tot20=hrswork_tot20+ o8_9_`i' if age`i'==20
			replace count15`y'=count15`y'+1 if age`i'>=15 & age`i'<=`y'
			replace count16`y'=count16`y'+1 if age`i'>=16 & age`i'<=`y'
			replace count15=count15+1 if age`i'==15
			replace count16=count16+1 if age`i'==16
			replace count17=count17+1 if age`i'==17
			replace count18=count18+1 if age`i'==18
			replace count19=count19+1 if age`i'==19
			replace count20=count20+1 if age`i'==20
			}
		replace hrswork_tot15`y'=0 if hrswork_tot15`y'==.
		replace hrswork_tot16`y'=0 if hrswork_tot16`y'==.
		gen hrswork_pm15`y'= hrswork_tot15`y'/count15`y'
		gen hrswork_pm16`y'= hrswork_tot16`y'/count16`y'
		replace hrswork_pm15`y'=0 if count15`y'==0
		replace hrswork_pm16`y'=0 if count16`y'==0
		}
		
		
	// working hours on business at hh level for different age groups
	forvalues y=17(1)20 {
		gen hrswork_bus15`y'=0
		gen hrswork_bus16`y'=0
		forvalues i=1(1)9 {
			replace hrswork_bus15`y'=hrswork_bus15`y'+ o8_10_0`i' if age0`i'>=15 & age0`i'<=`y'
			replace hrswork_bus16`y'=hrswork_bus16`y'+ o8_10_0`i' if age0`i'>=16 & age0`i'<=`y'
			replace hrswork_bus15=hrswork_bus15+ o8_10_0`i' if age0`i'==15
			replace hrswork_bus16=hrswork_bus16+ o8_10_0`i' if age0`i'==16
			replace hrswork_bus17=hrswork_bus17+ o8_10_0`i' if age0`i'==17
			replace hrswork_bus18=hrswork_bus18+ o8_10_0`i' if age0`i'==18
			replace hrswork_bus19=hrswork_bus19+ o8_10_0`i' if age0`i'==19
			replace hrswork_bus20=hrswork_bus20+ o8_10_0`i' if age0`i'==20
			}
		forvalues i=10(1)12 {
			replace hrswork_bus15`y'=hrswork_bus15`y'+ o8_10_`i' if age`i'>=15 & age`i'<=`y'
			replace hrswork_bus16`y'=hrswork_bus16`y'+ o8_10_`i' if age`i'>=16 & age`i'<=`y'
			replace hrswork_bus15=hrswork_bus15+ o8_10_`i' if age`i'==15
			replace hrswork_bus16=hrswork_bus16+ o8_10_`i' if age`i'==16
			replace hrswork_bus17=hrswork_bus17+ o8_10_`i' if age`i'==17
			replace hrswork_bus18=hrswork_bus18+ o8_10_`i' if age`i'==18
			replace hrswork_bus19=hrswork_bus19+ o8_10_`i' if age`i'==19
			replace hrswork_bus20=hrswork_bus20+ o8_10_`i' if age`i'==20
			}
		replace hrswork_bus15`y'=0 if hrswork_bus15`y'==.
		replace hrswork_bus16`y'=0 if hrswork_bus16`y'==.
		gen hrswork_buspm15`y'= hrswork_bus15`y'/count15`y'
		gen hrswork_buspm16`y'= hrswork_bus16`y'/count16`y'
		replace hrswork_buspm15`y'=0 if count15`y'==0
		replace hrswork_buspm16`y'=0 if count16`y'==0
		}
		
	// Hours work (on business) for HH mem of working age (16-19) [ADDED July 2013]
		gen hrswork_1664=0
		forvalues i=1(1)9 {
			replace  o8_9_0`i'=0 if  o8_9_0`i'==.
			replace hrswork_1664=hrswork_1664+ o8_9_0`i' if age0`i'>=16 & age0`i'<=64	// create working hours for HH mem of working age
			replace hrswork_1664=0 if hrswork_1664==.
			}
		forvalues i=10(1)12 {
			replace  o8_9_`i'=0 if  o8_9_`i'==.
			replace hrswork_1664=hrswork_1664+ o8_9_`i' if age`i'>=16 & age`i'<=64	// create working hours for HH mem of working age
			replace hrswork_1664=0 if hrswork_1664==.
			}
		gen hrswork_bus1664=0
		forvalues i=1(1)9 {
			replace  o8_10_0`i'=0 if  o8_10_0`i'==.
			replace hrswork_bus1664=hrswork_bus1664+ o8_10_0`i' if age0`i'>=16 & age0`i'<=64	// create working hours on bus for HH mem of working age
			replace hrswork_bus1664=0 if hrswork_bus1664==.
			}
		forvalues i=10(1)12 {
			replace  o8_10_`i'=0 if  o8_10_`i'==.
			replace hrswork_bus1664=hrswork_bus1664+ o8_10_`i' if age`i'>=16 & age`i'<=64	// create working hours on bus for HH mem of working age
			replace hrswork_bus1664=0 if hrswork_bus1664==.
			}
		replace hrswork_1664=. if hrswork_1664>600
		// gen count of nr of childen 16-19 in hh & of working age
		gen count1664=0
			forvalues i=1(1)9 {
				replace count1664=count1664+1 if age0`i'>=16 & age0`i'<=64
				}
			forvalues i=10(1)12 {
				replace count1664=count1664+1 if age`i'>=16 & age`i'<=64
				}

		gen hrswork_1664pm=hrswork_1664/count1664
		gen hrswork_bus1664pm=hrswork_bus1664/count1664
	

// school attendance for different age groups
	forvalues y=17(1)20 {
		gen schoolattend16`y'=0
		gen schoolattend15`y'=0
		forvalues i=1(1)9 {
			replace schoolattend15`y'=schoolattend15`y'+ o8_7_0`i' if age0`i'>=15 & age0`i'<=`y'
			replace schoolattend16`y'=schoolattend16`y'+ o8_7_0`i' if age0`i'>=16 & age0`i'<=`y'
			replace schoolattend15=schoolattend15+ o8_7_0`i' if age0`i'==15
			replace schoolattend16=schoolattend16+ o8_7_0`i' if age0`i'==16
			replace schoolattend17=schoolattend17+ o8_7_0`i' if age0`i'==17
			replace schoolattend18=schoolattend18+ o8_7_0`i' if age0`i'==18
			replace schoolattend19=schoolattend19+ o8_7_0`i' if age0`i'==19
			replace schoolattend20=schoolattend20+ o8_7_0`i' if age0`i'==20
			}
		forvalues i=10(1)12 {
			replace schoolattend15`y'=schoolattend15`y'+ o8_7_`i' if age`i'>=15 & age`i'<=`y'
			replace schoolattend16`y'=schoolattend16`y'+ o8_7_`i' if age`i'>=16 & age`i'<=`y'
			replace schoolattend15=schoolattend15+ o8_7_`i' if age`i'==15
			replace schoolattend16=schoolattend16+ o8_7_`i' if age`i'==16
			replace schoolattend17=schoolattend17+ o8_7_`i' if age`i'==17
			replace schoolattend18=schoolattend18+ o8_7_`i' if age`i'==18
			replace schoolattend19=schoolattend19+ o8_7_`i' if age`i'==19
			replace schoolattend20=schoolattend20+ o8_7_`i' if age`i'==20
			}
		replace schoolattend15`y'=0 if schoolattend15`y'==.
		replace schoolattend16`y'=0 if schoolattend16`y'==.
		gen schoolattendpm15`y'= schoolattend15`y'/count15`y'
		gen schoolattendpm16`y'= schoolattend16`y'/count16`y'
		replace schoolattendpm15`y'=0 if count15`y'==0
		replace schoolattendpm16`y'=0 if count16`y'==0
		}

		
	forvalues i=15(1)20 {
		replace hrswork_tot`i'=0 if hrswork_tot`i'==.
		replace hrswork_bus`i'=0 if hrswork_bus`i'==.
		replace schoolattend`i'=0 if schoolattend`i'==.
		gen hrswork_totpm`i'=hrswork_tot`i'/count`i'
		replace hrswork_totpm`i'=0 if count`i'==0
		gen hrswork_buspm`i'=hrswork_bus`i'/count`i'
		replace hrswork_buspm`i'=0 if count`i'==0
		gen schoolattendpm`i'=schoolattend`i'/count`i'
		replace schoolattendpm`i'=0 if count`i'==0
		}
		su hrswork_tot* hrswork_pm* schoolattend*
		
	gen followup=0
		
	gen hrswork_tot=0
	forvalues i=1(1)9 {
		replace  o8_9_0`i'=0 if  o8_9_0`i'==.
		replace hrswork_tot=hrswork_tot+ o8_9_0`i'
		replace hrswork_tot=0 if hrswork_tot==.
		}
	forvalues i=10(1)12 {
		replace  o8_9_`i'=0 if  o8_9_`i'==.
		replace hrswork_tot=hrswork_tot+ o8_9_`i'
		replace hrswork_tot=0 if hrswork_tot==.
		}
	gen hrswork_bus=0
	forvalues i=1(1)9 {
		replace  o8_10_0`i'=0 if  o8_10_0`i'==.
		replace hrswork_bus=hrswork_bus+ o8_10_0`i'
		replace hrswork_bus=0 if hrswork_bus==.
		}
	forvalues i=10(1)12 {
		replace  o8_10_`i'=0 if  o8_10_`i'==.
		replace hrswork_bus=hrswork_bus+ o8_10_`i'
		replace hrswork_bus=0 if hrswork_bus==.
		}
	replace hrswork_tot=. if hrswork_tot>600
	rename hrswork_tot  hrswork_tot0
	
	gen hrswork_totpm=hrswork_tot0/hhmem
	gen hrswork_buspm=hrswork_bus/hhmem
	

	global YSchoolattend15 "schoolattend1517 schoolattend1518 schoolattend1519 schoolattend1520 schoolattendpm1517 schoolattendpm1518 schoolattendpm1519 schoolattendpm1520"
	global YSchoolattend16 "schoolattend1617 schoolattend1618 schoolattend1619 schoolattend1620 schoolattendpm1617 schoolattendpm1618 schoolattendpm1619 schoolattendpm1620"
	global YvarHrsWTot15 "hrswork_tot1517 hrswork_tot1518 hrswork_tot1519 hrswork_tot1520 hrswork_pm1517 hrswork_pm1518 hrswork_pm1519 hrswork_pm1520"
	global YvarHrsWTot16 "hrswork_tot1617 hrswork_tot1618 hrswork_tot1619 hrswork_tot1620 hrswork_pm1617 hrswork_pm1618 hrswork_pm1619 hrswork_pm1620"
	global YvarHrsWBus15 "hrswork_bus hrswork_bus1517 hrswork_bus1518 hrswork_bus1519 hrswork_bus1520 hrswork_buspm1517 hrswork_buspm1518 hrswork_buspm1519 hrswork_buspm1520"
	global YvarHrsWBus16 "hrswork_bus1617 hrswork_bus1618 hrswork_bus1619 hrswork_bus1620 hrswork_buspm1617 hrswork_buspm1618 hrswork_buspm1619 hrswork_buspm1620"

	keep intervid treatment hrswork_tot0 hrswork_1664 hrswork_1664pm hrswork_bus hrswork_bus1664 hrswork_bus1664pm $YSchoolattend15 $YvarHrsWTot15 $YvarHrsWBus15 $YSchoolattend16 $YvarHrsWTot16 $YvarHrsWBus16 count* hrswork_totpm hrswork_buspm
	rename hrswork_tot0 hrswork_tot 

	foreach x of varlist hrswork_tot hrswork_1664 hrswork_1664pm hrswork_bus1664 hrswork_bus1664pm $YSchoolattend15 $YvarHrsWTot15 $YvarHrsWBus15 $YSchoolattend16 $YvarHrsWTot16 $YvarHrsWBus16 hrswork_totpm hrswork_buspm{
		rename `x' `x'0
		}

	renpfix hrswork_ BLhrswork_
	renpfix schoolattend BLschoolattend
	renpfix count BLcount

	save "data\Followup\labour supply and schooling outcomes - hh level.dta", replace
	
