/*==========================================================*
Paper: 		"The impacts of microcredit: Evidence from B&H"

Purpose:		This do-file: 
				Estimates results presented in Table 9 of the 
				paper -- estimating probability of late 
				payment and default among marginal borrowers
\				
Code Author: 	IFS
Date created: 	May 2013
Last modified:  

Note:			The working directory path in line 20 needs to 
				be adjusted for the file to run.
*===========================================================*/
capture log close
set more off
adopath+"C:\ado"
drop _all
global workdir "XXX"
cap mkdir "${workdir}"	
cd "${workdir}"						


*-- PUT DATA SET TOGETHER: 
	use "data\EKI client data\Marginal client data_EKI.dta", clear
	* merge in timing on loan info:
	merge 1:1 loanid using "data\EKI client data\Marginal client_loan timing.dta"
	drop if _m==2
	rename _m m_loantiming
	* merge in covariates:
	merge 1:1 intervid using "data\Baseline\Covariates Bosnia Baseline.dta"
	gen b_resp_age2=b_resp_age*b_resp_age 
	drop if _m==2
	rename _m m_covariates
	* merge in info on loan:
	merge 1:1 intervid using "data\Followup\SECTION 2 - Loans cl.dta"
	drop if _m==2 // drop non-loan taker (and non-treated) observations

	
*--------------*
* Regressions. *
*--------------*
** dependent variables: ever late ("late") and defaulted ("default")

*-- SOME DATA CLEANING/PREPARATION:
	* gen indicator of whether client provided collateral or not:
	egen l1_eki_colnr=rowtotal(l1_col_*) if l1_eki==1
	replace l1_eki_colnr=0 if l1_col_none==1 & l1_eki==1
	la var l1_eki_colnr "Nr of collateral types provided for first loan from EKI"
	gen l1_eki_col=l1_eki_colnr!=0
		replace l1_eki_col=. if l1_eki_colnr==.
		la var l1_eki_col "=1 if respondent provided collateral for EKI loan"
	gen ekireq_coll=eki_req_collateral==0 if eki_req_collateral!=.
	gen ekireq_repcap=eki_req_repcap==0 if eki_req_repcap!=.
	gen ekireq_busicap=eki_req_busicap==0 if eki_req_busicap!=.
	gen ekireq_credithist=eki_req_credithist==0 if eki_req_credithist!=.

	foreach x of varlist appl_competent appl_reliable appl_trustworthy appl_knowledge appl_experience appl_integrated appl_clever appl_risktaker appl_fighter appl_aggressive appl_stable appl_insecure {
		gen `x'12=`x'==1
		replace `x'12=1 if `x'==2
		replace `x'12=. if `x'==.
		}
	* rescale:
	replace original_amount=original_amount/1000
	replace loan_age=loan_age/365
	
*-- Variables for branch fixed effects:
	ta branch_n, gen(branchN)

*-- GLOBALSs:
	#d ;
		global Xvar "b_resp_female b_resp_age b_resp_age2 b_resp_ms1 b_resp_ms4 b_resp_ms5  b_resp_ss b_resp_ul
			 b_kids_05 b_kids_610 b_kids_1116 b_hhmem_female  b_hhmem_employed b_hhmem_school b_hhmem_retired";
		global XAppl1 "appl_competent12 appl_clever12 appl_trustworthy12 appl_aggressive12";
		global XInt "eki_req_coll eki_req_repcap ";
	#d cr
	
	
*--------------*
* Regressions. *
*--------------*
// Note: In the paper we only show regressions that include information on the timing on the loan. We leave remaining regressions for completeness

	// LATE PAYMENT
	qui dprobit late eki_req_collateral eki_req_repcap $XInt $Xvar branchN*
	outreg2 using "output\Repayment and client\T9 - Late-default.xls", addstat(Pseudo R2, `e(r2_p)', Log-Likelihood, `e(ll)', Chi2, `e(chi2)') cttop(as above) cttop(+ BranchFE) replace
	qui dprobit late eki_req_collateral eki_req_repcap $XInt  $XAppl1 $Xvar branchN* 
	outreg2 using "output\Repayment and client\T9 - Late-default.xls", addstat(Pseudo R2, `e(r2_p)', Log-Likelihood, `e(ll)', Chi2, `e(chi2)') cttop(as above) cttop(+ BranchFE) append
	* add info on loan timing
	qui dprobit late eki_req_collateral eki_req_repcap $XInt loan_time loan_age original_amount $Xvar branchN*
	outreg2 using "output\Repayment and client\T9 - Late-default.xls", addstat(Pseudo R2, `e(r2_p)', Log-Likelihood, `e(ll)', Chi2, `e(chi2)') cttop(as above) cttop(+ BranchFE) append
	qui dprobit late eki_req_collateral eki_req_repcap $XInt  loan_time loan_age original_amount $XAppl1 $Xvar branchN* 
	outreg2 using "output\Repayment and client\T9 - Late-default.xls", addstat(Pseudo R2, `e(r2_p)', Log-Likelihood, `e(ll)', Chi2, `e(chi2)') cttop(as above) cttop(+ BranchFE) append

	// DEFAULT
	qui dprobit default eki_req_collateral eki_req_repcap $XInt $Xvar branchN*
	outreg2 using "output\Repayment and client\T9 - Late-default.xls", addstat(Pseudo R2, `e(r2_p)', Log-Likelihood, `e(ll)', Chi2, `e(chi2)') cttop(as above) cttop(+ BranchFE) append
	qui dprobit default eki_req_collateral eki_req_repcap $XInt $Xvar branchN*  $XAppl1
	outreg2 using "output\Repayment and client\T9 - Late-default.xls", addstat(Pseudo R2, `e(r2_p)', Log-Likelihood, `e(ll)', Chi2, `e(chi2)') cttop(as above) cttop(+ BranchFE) append
	* add info on loan timing
	qui dprobit default eki_req_collateral eki_req_repcap $XInt loan_time loan_age original_amount $Xvar branchN*
	outreg2 using "output\Repayment and client\T9 - Late-default.xls", addstat(Pseudo R2, `e(r2_p)', Log-Likelihood, `e(ll)', Chi2, `e(chi2)') cttop(as above) cttop(+ BranchFE) append
	qui dprobit default eki_req_collateral eki_req_repcap $XInt loan_time loan_age original_amount $Xvar branchN*  $XAppl1
	outreg2 using "output\Repayment and client\T9 - Late-default.xls", addstat(Pseudo R2, `e(r2_p)', Log-Likelihood, `e(ll)', Chi2, `e(chi2)') cttop(as above) cttop(+ BranchFE) append

