/*==========================================================*
Paper: 		"The impacts of microcredit: Evidence from B&H"

Purpose:		This do-file: 
				Double checks results for all dollar amount
				variables - trimmed and untrimmed

Code Author: 	IFS
Date created: 	May 2013
Last modified:  

Note:			XXX 
*===========================================================*/
capture log close
set more off
adopath+"C:\ado"
drop _all
global workdir "C:\Users\britta\Dropbox\Bosnia\Paper\AEJ Applied - Special issue\Analysis files"
cap mkdir "${workdir}"	
cd "${workdir}"						

*-- PUT DATA SET TOGETHER: 
	use "data\Baseline\Covariates Bosnia Baseline.dta", clear
	gen b_resp_age2=b_resp_age*b_resp_age 
	merge 1:1 intervid using "data\indicator reinterviewed.dta", nogen
	* merge in OUTCOMES:
	merge 1:1 intervid using "data\Followup\Employment status respondent.dta", nogen keepusing(resp_es2)
	merge 1:1 intervid using "data\Followup\SECTION 2 - Loans cl.dta", nogen
	merge 1:1 intervid using "data\Followup\SECTION 3 - Consumption cl.dta", nogen /*keepusing(durablec nondc foodc_h foodc_o cigalcc foodc)*/
	merge 1:1 intervid using "data\Followup\SECTION 4 - Assets cl.dta",  nogen
	merge 1:1 intervid using "data\Followup\SECTION 5 - Income cl.dta", nogen 
	merge 1:1 intervid using "data\Followup\SECTION 6 - Business cl.dta", nogen keepusing(bm_own bm_expenses bm_revenue bm_profit bm_staff_FT bm_staff_PT bm_staff_T  bm_staffsalary   bm_staff_hhft bm_staff_hhpt bm_staff_hht bm_staff_hhpay bm_staff_outft bm_staff_outpt bm_staff_outt bm_staff_outpay bm_trade bm_service bm_agric bm_prod  bm_reg)
	merge 1:1 intervid using "data\Followup\SECTION 7 - Savingscl.dta", nogen keepusing(savings_avg savings_yn contrib_weekly contrib_monthly contrib_yearly contrib_no sav_busexp sav_edu sav_med sav_old sav_repair sav_emergency sav_cons sav_bequest sav_debt sav_festival sav_other)
	merge 1:1 intervid using "data\Followup\SECTION 8 - Household roster cl.dta", nogen
	merge 1:1 intervid using "data\Followup\SECTION 9 - Shocks cl.dta", nogen keepusing(jobloss_yn jobgain_yn othergain_yn badharvest_yn illnessearn_yn illnessnonearn_yn deathearn_yn deathnonearn_yn emplleft_yn crime_yn compet_yn otherloss_yn jobgain_yn othergain_yn jobloss_ydec badharvest_ydec illnessearn_ydec illnessnonearn_ydec deathearn_ydec deathnonearn_ydec emplleft_ydec crime_ydec compet_ydec otherloss_ydec)
	merge 1:1 intervid using "data\Followup\SECTION 10 - Stress cl.dta", nogen
*	merge 1:1 intervid using "$location\DATA - Followup\Follow-up DATA\Tightening of bounds\incentive given.dta", nogen

*-- GLOBALS:
	#d ;
		global Xvar "b_resp_female b_resp_age b_resp_age2 b_resp_ms1 b_resp_ms4 b_resp_ms5  b_resp_ss b_resp_ul
			 b_kids_05 b_kids_610 b_kids_1116 b_hhmem_female  b_hhmem_employed b_hhmem_school b_hhmem_retired";
		global Edu "t_edul t_eduh respedu_l";
		global Busi "t_busi t_nobus b_bm_own";
		global Xvaredu "b_resp_female b_resp_age b_resp_age2 b_resp_ms1 b_resp_ms4 b_resp_ms5  
			 b_kids_05 b_kids_610 b_kids_1116 b_hhmem_female  b_hhmem_employed b_hhmem_school b_hhmem_retired";
	#d cr
	
	
*-- SOME DATA CLEANING/PREPARATION:
	gen bm_profitcalc=bm_revenue-bm_expenses
	* Income
	egen yval_wages=rowtotal(yval_agric yval_shop yval_manuf yval_privb yval_governmnt)
	* Consumption
	gen durablecTR=durable if durabl<=600000	// exlcudes one obs
	gen nondcTR=nondc if nond<=2800	// exluded one obs
	gen educ_yrTR=educ_yr if educ_yr<25000	//excludes one obs
		foreach x of varlist foodc_h foodc_o cigalcc nondc durablec durablecTR nondcTR recre_m{
		gen `x'temp=`x'
		replace `x'temp=0 if `x'temp==.
		}
	gen totalc=foodc_htemp*52 +foodc_otemp*52+ cigalcctemp*52 + nondctemp*12+ durablectemp
		lab var totalc "Total consumption expenditure in last year"
	gen totalcTR=foodc_htemp*52 +foodc_otemp*52+ cigalcctemp*52 + nondcTRtemp*12+ durablecTRtemp
	gen nondc_tot=nondc+foodc+cigalcc
	gen nondcTR_tot=nondcTR+foodc+cigalcc
	gen temptation_yr=cigalcc+recre_mtemp*12
	gen recre_yr=recre_m*12
	foreach x of varlist totalc totalcTR foodc_h foodc_o foodc educ_yr educ_yrTR temptation_yr cigalcc  nondc durablec durablecTR nondcTR nondc_tot nondcTR_tot recre_yr {
		replace `x'=. if followup==0 	
		gen miss_`x'=1 if `x'==. & followup==1
		}
	egen hhmem=rowtotal(hhmem_male hhmem_female)
	gen totalc_cap=totalc/hhmem
	* home durable good index:
	foreach x of varlist house_nr land_nr car_nr lorry_nr animals_nr motorbike_nr computer_nr tools_nr inventory_nr mobile_nr tv_nr video_nr radio_nr electrappl_nr generator_nr fridge_nr oven_nr washmachine_nr {
		gen `x'01=`x'!=0 & `x'!=.
		}
	factor *_nr01, pcf // Principal Component Factor analysis
	rotate
	predict HDGI 
	replace HDGI=. if followup==0
	*Savings
	replace savings_avg=0 if savings_avg==.	
	replace savings_avg=. if followup==0	

	global DollarV "assetvalue bm_revenue bm_expenses bm_profit bm_profitcalc yval_selfempl yval_wages yval_remit yval_benefit totalc_cap durablecTR nondcTR foodc educ_yrTR cigalcc recre_yr HDGI savings_av"
	
// Trimming
	foreach x of varlist $DollarV {
		replace `x'=0 if `x'==. & followup==1
		replace `x'=. if followup==0
		}
	foreach x of varlist $DollarV {
			su `x', d
			gen `x'TR1p=`x' if `x'<=r(p99)
			su `x'TR1p, d
			gen `x'TR2p=`x' if `x'<=r(p99)
			su `x'TR2p, d
			gen `x'TR3p=`x' if `x'<=r(p99)
			}

*++++++++++++++++++++++++++++*
* Asset & business outcomes  *
*++++++++++++++++++++++++++++*

	// Regressions 
	local table replace
	foreach x of varlist assetvalue* bm_revenue* bm_profit bm_profitT* {
		su `x' if followup==1 & treatment==0
		local meanC`x'=r(mean)
		qui reg `x' treat $Xvar if followup==1, robust  	// Overall
		outreg2 using "output\Impact Estimates - trimmed\Asset & Business (TA10).xls", addstat(Mean C, `meanC`x'') `table'
		local table append 
		}
		
*++++++++++*
* Income   *
*++++++++++*
	
	// Regressions 
	local table replace
	foreach x of varlist yval_wages* yval_remit* yval_benefit* {
		su `x' if followup==1 & treatment==0
		local meanC`x'=r(mean)
		qui reg `x' treat $Xvar if followup==1, robust  	// Overall
		outreg2 using "output\Impact Estimates - trimmed\Income (TA10).xls", addstat(Mean C, `meanC`x'') `table'
	local table append 
		}

*++++++++++++++*
* Consumption  *
*++++++++++++++*

	drop nondc_tot* foodc_h* foodc_o* nondcTRtemp nondcTR_tot durablectemp* durablecTRtemp // this is just for convenience in writing the below (and not to have unnecessary variables in the output)... 
	// Regressions 
	local table replace
	foreach x of varlist totalc_cap* durablec* nondcTR* foodc* educ_yr* cigalcc* recre_yr* {
		su `x' if followup==1 & treatment==0
		local meanC`x'=r(mean)
		qui reg `x' treat $Xvar if followup==1, robust  	// Overall
		outreg2 using "output\Impact Estimates - trimmed\Consumption (TA10).xls", addstat(Mean C, `meanC`x'') `table'
	local table append 
		}
