/*==========================================================*
Paper: 		"The impacts of microcredit: Evidence from B&H"

Purpose:		This do-file: 
				Estimates Attrition results, Table Ta5
\				
Code Author: 	IFS
Date created: 	Feb 2013
Last modified:  

Note:			XXX 
*===========================================================*/
capture log close
set more off
adopath+"C:\ado"
drop _all
global workdir "XXX"		
cap mkdir "${workdir}"	
cd "${workdir}"						

*-- PUT DATA SET TOGETHER: 
	use "data\Baseline\Covariates Bosnia Baseline.dta", clear
	merge 1:1 intervid using "data\Baseline\BL - SECTION 5 - Income cl.dta", keepusing(yval_selfempl yval_agric) nogen
	merge 1:1 intervid using "data\Baseline\BL - SECTION 2 - Loans cl.dta", keepusing(l3_amount) nogen
	merge 1:1 intervid using "data\indicator reinterviewed.dta", nogen	
	
*-- GLOBALS:
	#d ;
		global HHComp "b_hhmem b_adults b_children b_resp_male b_resp_age b_resp_ps";
		global CreditAccess "b_loan b_loans b_l_mfi b_l_bank b_l_percB"; //(we have data on 'other' but it is very very few...
		global CreditAmount "b_loanamount b_lamount_mfi b_lamount_bank";
		global SelfEmpl "y_sources b_y_tot yval_selfempl yval_agric b_hhmem_unemp b_hhmem_employed b_hhmem_retired b_resp_hrswork b_resp_hrsworkb ";
		global Consumption "b_foodc b_nondc b_durablec";
	#d cr

*-- SOME DATA CLEANING/PREPARATION:
	gen attrit=followup==0
	replace attrit=. if followup==.
	su attrit
	gen BLobsAT=r(N)
	su attrit if treatment==0 
	gen BLobsATC=r(N)
	gen BLmeanAT=r(mean)
	gen BLsdAT=r(sd)
	reg attrit treatment, robust
	gen betaAT =_b[treatment]
	gen p_AT=(2 * ttail(e(df_r), abs(_b[treatment]/_se[treatment])))

    rename l3_amount b_l3_amount
	gen b_resp_age2=b_resp_age*b_resp_age 
	gen resp_empl2060m=b_resp_es1 if b_resp_female==0 & b_resp_age>=20 & b_resp_age<=60
	gen resp_empl2060f=b_resp_es1 if b_resp_female==1 & b_resp_age>=20 & b_resp_age<=60
	egen b_hhmem=rowtotal(b_hhmem_male b_hhmem_female)
	gen b_resp_male=b_resp_gender==1
	replace b_loans=. if b_loans==999
	gen b_loan=b_loans!=0
	egen y_sources=rowtotal(b_y_selfempl b_y_agric b_y_shop b_y_bank b_y_manuf b_y_tourism b_y_privb b_y_governmnt b_y_remit b_y_benefit b_y_pension b_y_rent b_y_other)
	foreach x of varlist b_loanamount b_y_tot yval_selfempl yval_agric b_foodc b_nondc b_durablec{
		gen `x'_sc=`x'/1000
		}

		
*-- GLOBALS:
	#d ;
		global HHComp "b_hhmem b_adults b_resp_male b_resp_age b_resp_ps";
		global CreditAccess "b_loan b_loans"; //(we have data on 'other' but it is very very few...
		global CreditAmount "b_loanamount_sc";
		global SelfEmpl "y_sources b_y_tot_sc yval_selfempl_sc yval_agric_sc b_hhmem_unemp b_hhmem_employed b_hhmem_retired b_resp_hrswork b_resp_hrsworkb ";
		global Consumption "b_foodc_sc b_nondc_sc b_durablec_sc";
		global XAppl1 "appl_competent12 appl_clever12 appl_trustworthy12 appl_aggressive12";
		global XReq1 "eki_req_collateral eki_req_repcap eki_req_busicap";
		global XReqnotmet "ekireq_col ekireq_repcap ekireq_busicap";
		global XInt "eki_req_coll eki_req_repcap ";
		global Worry "mostworry_1 mostworry_2 mostworry_4 mostworry_5";
		global Judgement "appl_competent12 appl_reliable12 appl_trustworthy12 appl_knowledge12 appl_experience12 appl_integrated12 appl_clever12 appl_risktaker12 appl_fighter12 appl_aggressive12 appl_stable12 appl_insecure12";
	#d cr
	
	merge 1:1 intervid using "data\Baseline\LOs view of MCs.dta"
	foreach x of varlist appl_competent appl_trustworthy appl_reliable appl_knowledge appl_experience appl_integrated appl_clever appl_risktaker appl_fighter appl_aggressive appl_stable appl_insecure{
		gen `x'12=`x'==1
			replace `x'12=1 if `x'==2
			replace `x'12=. if `x'==.
		}
	
*-- ESTIMATION:

	reg attrit $Judgement, robust
		test $Judgement
		outreg2 using "output\Attrition\Additional - Attrition-LO.xls", replace  dec(3)
	reg attrit $Judgement  $HHComp, robust
		test $Judgement $HHComp
		outreg2 using "output\Attrition\Additional - Attrition-LO.xls", append  dec(3)
	reg  attrit treatment $Judgement, robust
		outreg2 using "output\Attrition\Additional - Attrition-LO.xls", append  dec(3)
		test $Judgement
		test $Judgement treatment
	reg  attrit treatment $Judgement $HHComp, robust
		outreg2 using "output\Attrition\Additional - Attrition-LO.xls", append  dec(3)
		test $Judgement $HHComp 
		test $Judgement treatment $HHComp 
	reg  attrit treatment $Judgement $HHComp $CreditAccess $CreditAmount $SelfEmpl $Consumption, robust
		outreg2 using "output\Attrition\Additional - Attrition-LO.xls", append  dec(3)
		test $Judgement $HHComp $CreditAccess $CreditAmount $SelfEmpl $Consumption
		test $Judgement treatment $HHComp $CreditAccess $CreditAmount $SelfEmpl $Consumption

		
*--------------------------------------------------------------------*
* (1a) Check characteristics - stayers versus attritors *
*--------------------------------------------------------------------*

	foreach x of varlist  $HHComp $CreditAccess $CreditAmount $SelfEmpl $Consumption {
		su `x' 
		gen BLobs`x'=r(N)
		su `x' if attrit==0 
		gen BLobs`x'C=r(N)
		gen BLmean`x'=r(mean)
		gen BLsd`x'=r(sd)
		reg `x' attrit, robust
		gen beta`x' =_b[attrit]
		gen t_`x'=(_b[attrit]/_se[attrit])
		gen p_`x'=(2 * ttail(e(df_r), abs(_b[attrit]/_se[attrit])))
		}

	** DISPLAY RESULTS
	noi di as txt "PANEL A"
	noi di as txt "{col 32}" "Stayers" as txt "{col 62}" "Sayers-Attritors"
	noi di as txt "{col 22}" "Obs" as txt "{col 32}" "Obs(C)" as txt "{col 42}" "Mean" as txt "{col 52}" "StdDev" as txt "{col 62}" "Coeff" as txt "{col 72}" "p-value" 
	noi di as txt ""
	noi di as txt "Household composition"
	foreach v of varlist $HHComp  {
	   	noi di as txt "`v'" "{col 22}" as res %6.0f  BLobs`v' "{col 32}" as res %6.0f  BLobs`v'C "{col 42}" as res %6.3f  BLmean`v' "{col 52}" as res %6.3f  BLsd`v' "{col 62}"  as res %6.3f  beta`v' "{col 72}"  as res %6.3f   p_`v' 
		}
	noi di as txt ""
	noi di as txt "Access to credit:"
	foreach v of varlist $CreditAccess  {
	   	noi di as txt "`v'" "{col 22}" as res %6.0f  BLobs`v' "{col 32}" as res %6.0f  BLobs`v'C "{col 42}" as res %6.3f  BLmean`v' "{col 52}" as res %6.3f  BLsd`v' "{col 62}"  as res %6.3f  beta`v' "{col 72}"  as res %6.3f   p_`v' 
		}
	noi di as txt ""
	noi di as txt "Amount borrowed from (in BAM):"
	foreach v of varlist $CreditAmount  {
	   	noi di as txt "`v'" "{col 22}" as res %6.0f  BLobs`v' "{col 32}" as res %6.0f  BLobs`v'C "{col 42}" as res %6.1f  BLmean`v' "{col 52}" as res %6.1f  BLsd`v' "{col 62}"  as res %6.1f  beta`v' "{col 72}"  as res %6.3f   p_`v' 
		}
	noi di as txt ""
	noi di as txt "Employment Activities:"
	foreach v of varlist $SelfEmpl  {
	   	noi di as txt "`v'" "{col 22}" as res %6.0f  BLobs`v' "{col 32}" as res %6.0f  BLobs`v'C "{col 42}" as res %6.3f  BLmean`v' "{col 52}" as res %6.3f  BLsd`v' "{col 62}"  as res %6.3f  beta`v' "{col 72}"  as res %6.3f   p_`v' 
	   	*noi di as txt "`v'" "{col 22}" as res %6.0f  BLobs`v' "{col 32}" as res %6.0f  BLobs`v'C "{col 42}" as res %6.0f  BLmean`v' "{col 52}" as res %6.0f  BLsd`v' "{col 62}"  as res %6.0f  beta`v' "{col 72}"  as res %6.3f   p_`v' 
		}
	noi di as txt ""
	noi di as txt "Consumption:"
	foreach v of varlist $Consumption  {
	   	noi di as txt "`v'" "{col 22}" as res %6.0f  BLobs`v' "{col 32}" as res %6.0f  BLobs`v'C "{col 42}" as res %6.2f  BLmean`v' "{col 52}" as res %6.2f  BLsd`v' "{col 62}"  as res %6.2f  beta`v' "{col 72}"  as res %6.2f   p_`v' 
		}

		
		