/*==========================================================*
Paper: 		"The impacts of microcredit: Evidence from B&H"

Purpose:		This do-file: 
				looks at heterogeneous effects by stated inteded
				loan use at baseline (specifically for consumption)

Code Author: 	IFS
Date created: 	May 2013
Last modified:  

Note:			XXX 
*===========================================================*/
capture log close
set more off
adopath+"C:\ado"
drop _all
global workdir "C:\Users\britta\Dropbox\Bosnia\Paper\AEJ Applied - Special issue\Analysis files"
cap mkdir "${workdir}"	
cd "${workdir}"						

*-- PUT DATA SET TOGETHER: 
	use "data\Baseline\Covariates Bosnia Baseline.dta", clear
	gen b_resp_age2=b_resp_age*b_resp_age 
	merge 1:1 intervid using "data\indicator reinterviewed.dta", nogen
	merge 1:1 intervid using "data\Followup\SECTION 6 - Business cl.dta", nogen keepusing(bm_own bm_expenses bm_revenue bm_profit bm_staff_FT bm_staff_PT bm_staff_T  bm_staffsalary   bm_staff_hhft bm_staff_hhpt bm_staff_hht bm_staff_hhpay bm_staff_outft bm_staff_outpt bm_staff_outt bm_staff_outpay bm_trade bm_service bm_agric bm_prod  bm_reg)

*-- GLOBALS:
	#d ;
		global Xvar "b_resp_female b_resp_age b_resp_age2 b_resp_ms1 b_resp_ms4 b_resp_ms5  b_resp_ss b_resp_ul
			 b_kids_05 b_kids_610 b_kids_1116 b_hhmem_female  b_hhmem_employed b_hhmem_school b_hhmem_retired";
		global ERConsFull "t_lfc_full t_lfc_fullN loanforcons_full";
	#d cr

*-- SOME DATA CLEANING/PREPARATION:
	* Respondents were  asked what percentage of the loan they would use for:
	/* main business	o6_11_1new
	secondary business	o6_11_2new
	new business		o6_11_3new
	consumption			o6_11_4new */
	gen loanforcons_full = o6_11_4 == 100
	*gen loanforcons_some = o6_11_4 > 0
	la var loanforcons_full "=1 if all of loan was intended for consumption purpose"
	la var loanforcons_full "=1 if all or some of loan was intended for consumption purpose"
	gen t_lfc_full=loanforcons_full*treatment
	gen loanforcons_fullN = loanforcons_full == 0
	gen t_lfc_fullN = loanforcons_fullN*treatment
	
/* --------------------------------------------------------------------------------------
   ---------------------------------------------------------------------------------------
   We next conduct the impact analysis -- heterogeneous impacts on profits based on the 
   respondent's intended loan use report at BL. The lower panel of TA7 reports these 
   estimates by whether the respondent said s(he) would use all of the loan for consumption
   versus just some of it. 
   ---------------------------------------------------------------------------------------
   ---------------------------------------------------------------------------------------*/

*-- Additional DATA CLEANING/PREPARATION:
	foreach x of varlist bm_expenses bm_revenue bm_profit bm_profitcalc {
			replace `x'=0 if `x'==. & followup==1
			replace `x'=. if followup==0
			su `x', d
			gen `x'TR1p=`x' if `x'<=r(p99)
			su `x'TR1p, d
			gen `x'TR2p=`x' if `x'<=r(p99)
			su `x'TR2p, d
			gen `x'TR3p=`x' if `x'<=r(p99)
			}

	// Impact estimate regressions:
	local table replace
	foreach x of varlist bm_revenue bm_revenueTR1p bm_profit bm_profitTR1p {
		su `x' if followup==1 & treatment==0
		local meanC`x'=r(mean)
		qui reg `x' treat $Xvar if followup==1, robust  	// Overall
		outreg2 using "output\Impact Estimates\TA7 lower panel (intended loan use).xls", addstat(Mean C, `meanC`x'') `table'
		qui reg `x' $ERConsFull $Xvar if followup==1, robust  	
		outreg2 using "output\Impact Estimates\TA7 lower panel (intended loan use).xls", addstat(Mean C, `meanC`x'') append
	local table append 
	}

