*******************************
* AUTHOR: Natalia Rigol
* Program Purpose: Creates Appendix Table 1- Randomization Check Panel B
* Date Created: 12/24/2012
***********************************


*GLOBAL DIRECTORY

global VFSROOT "C:\Users\Natalia\Dropbox\VWS Projects"

global cd	"$VFSROOT\graceperiodpaper\AER Resubmit\Publication Version"

*USING FILE


clear
use "$cd\New Files 20130415\Publication Data and Do Files\Grace Period Data.dta", clear


* ************************* Randomization check below **********************

local risk  Has_Business_Broad  Client_Manages Earns_Wage Wage SEI Has_Savings_Acc_Apr24 Non_VWS_Loan_Baseline Risk_Loving Impatient  shock_days_lost_D shock_money_spent_D Chronically_Ill 
foreach var of local risk{
gen miss_`var'=(`var'==.)
}

duplicates drop slid, force


* Merging in the respondents from 1st round of surveying


egen gtag=tag( sec_group_name)
local numvar = 1

//Generate variables for stacked regression for the number of outcomes

local risk  Has_Business_Broad  Client_Manages Earns_Wage Wage SEI Has_Savings_Acc_Apr24 Non_VWS_Loan_Baseline Risk_Loving Impatient  shock_days_lost_D shock_money_spent_D Chronically_Ill 
local numvars: list sizeof risk

expand `numvars'

//Labeling each observation so that each is used only for one category in the stacked regression

bys slid: egen subsample = seq()
gen outcome=.
gen missing=.


local risk  Has_Business_Broad  Client_Manages Earns_Wage Wage SEI Has_Savings_Acc_Apr24 Non_VWS_Loan_Baseline Risk_Loving Impatient  shock_days_lost_D shock_money_spent_D Chronically_Ill 
local i=1 
foreach var of local risk {
local rsk: word `i' of `risk'
gen indic_`i'=0
replace indic_`i' = 1 if subsample ==`i'
replace outcome = `rsk' if indic_`i' == 1
replace missing = miss_`rsk' if indic_`i' == 1
local i=`i'+1
}

local num_vars : list sizeof risk
foreach X of var indic_1- indic_`num_vars' {
		gen `X'_sec_treat = `X'*sec_treat
}
*gen indic_16_gtag=indic_16*gtag

foreach X of var indic_1- indic_`num_vars'  {
		gen missing_`X' = `X'*missing
}
foreach X of var indic_1- indic_`num_vars'  {
		gen Stratification_`X' = `X'*Stratification_Dummies
}
foreach X of var indic_1- indic_`num_vars'  {
		gen Loan_Officer_`X' = `X'*sec_loan_officer
}

g str40 varname = ""
local risk  Has_Business_Broad  Client_Manages Earns_Wage Wage SEI Has_Savings_Acc_Apr24 Non_VWS_Loan_Baseline Risk_Loving Impatient  shock_days_lost_D shock_money_spent_D Chronically_Ill 

forvalues i=1/`num_vars'{
local var: word `i' of `risk'
local g=2*`i'
replace varname="`var'" in `g'
}
local g=2*`num_vars'+3
replace varname = "Joint test"  in `g'


// Calculate mean

g Sec_Treat_Mean_1= .

g Sec_Treat_Mean = ""

g Sec_NonTreat_Mean_1= .

g Sec_NonTreat_Mean = ""


g Average_1=.

g Average=""
local risk  Has_Business_Broad  Client_Manages Earns_Wage Wage SEI Has_Savings_Acc_Apr24 Non_VWS_Loan_Baseline Risk_Loving Impatient  shock_days_lost_D shock_money_spent_D Chronically_Ill 

forvalues i = 1/`num_vars' {
	local numvar = `numvar' + 1	
	local numvarse = `numvar' + 1
	
	summ outcome if indic_`i' == 1 & sec_treat == 1 & missing==0
	replace Sec_Treat_Mean_1= r(mean) in `numvar' 
	replace Sec_Treat_Mean_1= r(sd)/((r(N)-1)^.5) in `numvarse' 

	summ outcome if indic_`i' == 1 & sec_treat == 0 & missing==0
	replace Sec_NonTreat_Mean_1= r(mean) in `numvar' 
	replace Sec_NonTreat_Mean_1= r(sd)/((r(N)-1)^.5) in `numvarse' 

	summ outcome if indic_`i' == 1 &  missing==0
	replace Average_1= r(mean) in `numvar' 
	replace Average_1= r(sd)/((r(N)-1)^.5) in `numvarse' 
	
	local numvar = `numvar' + 1	

}

local numvar = 1
tostring Sec_Treat_Mean_1 Sec_NonTreat_Mean_1 Average_1, replace format(%10.3f) force


forvalues i = 1/`num_vars' {
	local numvar = `numvar' + 1	
	local numvarse = `numvar' + 1
	
	replace Sec_Treat_Mean = Sec_Treat_Mean_1 in `numvar' 
	replace Sec_Treat_Mean = "(" + Sec_Treat_Mean_1+ ")" in `numvarse' 
	replace Sec_NonTreat_Mean = Sec_NonTreat_Mean_1 in `numvar' 
	replace Sec_NonTreat_Mean = "(" + Sec_NonTreat_Mean_1+ ")" in `numvarse' 
	replace Average= Average_1 in `numvar' 
	replace Average= "(" + Average_1+ ")" in `numvarse' 
	local numvar = `numvar' + 1	

}



** Fixed Effect

local numvar = 1

g commfe_1 = .

g pvalcommfe = .
g commfe = ""

local sec_treat "indic_?_sec_treat indic_??_sec_treat  "

local risk  Has_Business_Broad  Client_Manages Earns_Wage Wage SEI Has_Savings_Acc_Apr24 Non_VWS_Loan_Baseline Risk_Loving Impatient  shock_days_lost_D shock_money_spent_D Chronically_Ill 

local num_vars : list sizeof risk

gen indic_`num_vars'_gtag=indic_`num_vars'*gtag

reg outcome indic_? indic_??  `sec_treat' missing_* Stratification_indic_? Stratification_indic_?? , cluster(sec_group_name) 



local risk  Has_Business_Broad  Client_Manages Earns_Wage Wage SEI Has_Savings_Acc_Apr24 Non_VWS_Loan_Baseline Risk_Loving Impatient  shock_days_lost_D shock_money_spent_D Chronically_Ill 


local num_vars : list sizeof risk
forvalues i = 1/`num_vars' {
	local numvar = `numvar' + 1	
	local numvarse = `numvar' + 1
	
	test indic_`i'_sec_treat=0
	replace pvalcommfe = r(p) in `numvar'
	replace commfe_1 = _b[indic_`i'_sec_treat] in `numvar'
	replace commfe_1 = _se[indic_`i'_sec_treat] in `numvarse'



	local numvar = `numvar' + 1	

}

local numvar = `numvar' + 2	

testparm indic*_sec_treat
replace commfe_1 = r(p) in `numvar'



local numvar = 1
tostring commfe_1 , replace format(%10.4f) force

local risk  Has_Business_Broad  Client_Manages Earns_Wage Wage SEI Has_Savings_Acc_Apr24 Non_VWS_Loan_Baseline Risk_Loving Impatient  shock_days_lost_D shock_money_spent_D Chronically_Ill 


local num_vars : list sizeof risk

forvalues i = 1/`num_vars' {

	local numvar = `numvar' + 1	
	local numvarse = `numvar' + 1
	
	replace commfe = commfe_1 if pvalcommfe >=0.1 in `numvar' 
	replace commfe = commfe_1 + "*" if (pvalcommfe >=0.05 & pvalcommfe <0.1)  in `numvar' 
	replace commfe = commfe_1 + "**" if (pvalcommfe >=0.01 & pvalcommfe <0.05)  in `numvar' 
	replace commfe = commfe_1 + "***" if (pvalcommfe <0.01)  in `numvar' 

	replace commfe = "(" + commfe_1 + ")" in `numvarse' 

	local numvar = `numvar' + 1	

}


local numvar = `numvar' + 2	

replace commfe = commfe_1 in `numvar' 


keep varname Sec_Treat_Mean Sec_NonTreat_Mean  commfe Average
*keep in 1/45

replace Sec_Treat_Mean = "" if Sec_Treat_Mean == "."
replace Sec_NonTreat_Mean = "" if Sec_NonTreat_Mean == "."

foreach X in fe  {
	replace comm`X' = "" if comm`X' == "."

}

gen left_par="("
gen right_par=")"
gen none=""

gen No_Delay=subinstr( Sec_NonTreat_Mean, left_par,none,1)
replace No_Delay=subinstr(No_Delay, right_par,none,1)
gen Delay=subinstr( Sec_Treat_Mean, left_par,none,1)
replace Delay=subinstr(Delay, right_par,none,1)
gen Diff_Survey1=subinstr(commfe, left_par,none,1)
replace Diff_Survey1=subinstr(Diff, right_par,none,1)


gen Ave=subinstr(Average, left_par,none,1)
replace Ave=subinstr(Ave, right_par,none,1)
