*******************************
* AUTHOR: Natalia Rigol
* Program Purpose: Creates Appendix Table 3- Production Function
* Date Created: 12/24/2012
***********************************


*GLOBAL DIRECTORY

global cd  "C:\Users\Natalia\Dropbox\VWS Projects\graceperiodpaper\AER Resubmit\Publication Version"


*USING FILE

clear

use "$cd\Tables\Publication Data and Do Files\Grace Period Data.dta


egen capital=rowtotal( tot_durables_Q11R tot_bizstock_Q32),m

**************************************************************
*REGRESSIONS FOR FULL SAMPLE WITHOUT CONTROLS
**************************************************************
 

local defaultvars    Profit  
local specifications "(capital=sec_treat) Tot_Hours_Worked "
local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
		*GET MEAN, VAR OF DEPENDENT VAR FOR CONTROL
		 regress `defaultvar' if sec_treat== 0 , cluster(sec_group_name) 
		matrix control_mean = e(b)
		matrix control_var = e(V)
		
		 xi: ivreg `defaultvar' `specifications', cluster(sec_group_name) first
		
		*ADD MEAN OF DEPENDENT VARIABLE FOR CONTROL TO THE TABLE IN PLACE OF CONSTANT
		matrix V_temp = e(V)
		matrix b_temp = e(b)
		
		local numxvars = colsof(V_temp)

		local controls_used 1
	

		local colofcons = colnumb( V_temp, "_cons" )
		
		matrix V_temp[`colofcons', `colofcons'] = control_var[1,1]
		matrix b_temp[1, `colofcons'] = control_mean[1,1]
		
		erepost V = V_temp, rename
		erepost b = b_temp, rename
		
		eststo model`i'`j', addscalars(controls_used `controls_used')
	
}

local esttaboptions se title("New Business")  coeflabels(_cons "Mean for No Delay ") scalars(controls_used)

esttab model* using "$cd\Tables\Excel Files\App Table 3-ProductionNC.csv", `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01)

est clear


**************************************************************
*REGRESSIONS FOR TOP CODED SAMPLE WITHOUT CONTROLS
**************************************************************


local defaultvars    Profit_TopCode  
local specifications "(Capital_TopCode=sec_treat) Tot_Hours_Worked "
local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
		*GET MEAN, VAR OF DEPENDENT VAR FOR CONTROL
		 regress `defaultvar' if sec_treat== 0 , cluster(sec_group_name) 
		matrix control_mean = e(b)
		matrix control_var = e(V)
		
		 xi: ivreg `defaultvar' `specifications', cluster(sec_group_name) first
		
		*ADD MEAN OF DEPENDENT VARIABLE FOR CONTROL TO THE TABLE IN PLACE OF CONSTANT
		matrix V_temp = e(V)
		matrix b_temp = e(b)
		
		local numxvars = colsof(V_temp)

		local controls_used 1
	

		local colofcons = colnumb( V_temp, "_cons" )
		
		matrix V_temp[`colofcons', `colofcons'] = control_var[1,1]
		matrix b_temp[1, `colofcons'] = control_mean[1,1]
		
		erepost V = V_temp, rename
		erepost b = b_temp, rename
		
		eststo model`i'`j', addscalars(controls_used `controls_used')
	
}

local esttaboptions se title("New Business")  coeflabels(_cons "Mean for No Delay ") scalars(controls_used)

esttab model* using "$cd\Tables\Excel Files\App Table 3-ProductionTNC.csv", `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01)

est clear



**************************************************************
*REGRESSIONS FOR FULL SAMPLE WITH CONTROLS
**************************************************************

* Make sure missings are 0 not averages (missing controls coded as "." only in Table 1)
local controls Age_C Married_C  Muslim_C HH_Size_C Years_Education_C shock_any_C  Has_Business_C Financial_Control_C homeowner_C  sec_loanamount No_Drain_C


foreach var of local risk {
	replace `var' = 0 if miss_`var' == 1
	}
local controls Age_C Married_C  Muslim_C HH_Size_C Years_Education_C shock_any_C  Has_Business_C Financial_Control_C homeowner_C  sec_loanamount No_Drain_C

*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'




local defaultvars    Profit    
local specifications "(capital=sec_treat) Tot_Hours_Worked "
local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
		*GET MEAN, VAR OF DEPENDENT VAR FOR CONTROL
		 quietly regress `defaultvar' if sec_treat== 0 , cluster(sec_group_name)
		matrix control_mean = e(b)
		matrix control_var = e(V)
		
		 xi: ivreg `defaultvar' `specifications' `controls_and_miss' i.Stratification i.sec_loan_officer, cluster(sec_group_name) first
		
		*ADD MEAN OF DEPENDENT VARIABLE FOR CONTROL TO THE TABLE IN PLACE OF CONSTANT
		matrix V_temp = e(V)
		matrix b_temp = e(b)
		
		local numxvars = colsof(V_temp)

		local controls_used 1
	

		local colofcons = colnumb( V_temp, "_cons" )
		
		matrix V_temp[`colofcons', `colofcons'] = control_var[1,1]
		matrix b_temp[1, `colofcons'] = control_mean[1,1]
		
		erepost V = V_temp, rename
		erepost b = b_temp, rename
		
		eststo model`i'`j', addscalars(controls_used `controls_used')
	
}





local esttaboptions se title("New Business") drop( `controls_and_miss' ) coeflabels(_cons "Mean for No Delay ") scalars(controls_used)

esttab model* using "$cd\Tables\Excel Files\App Table 3-ProductionC.csv", `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01)

est clear


**************************************************************
*REGRESSIONS FOR TOP CODED SAMPLE WITH CONTROLS
**************************************************************


* Make sure missings are 0 not averages (missing controls coded as "." only in Table 1)
local controls Age_C Married_C  Muslim_C HH_Size_C Years_Education_C shock_any_C  Has_Business_C Financial_Control_C homeowner_C  sec_loanamount No_Drain_C


foreach var of local risk {
	replace `var' = 0 if miss_`var' == 1
	}
local controls Age_C Married_C  Muslim_C HH_Size_C Years_Education_C shock_any_C  Has_Business_C Financial_Control_C homeowner_C  sec_loanamount No_Drain_C

*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'




local defaultvars    Profit_TopCode 
local specifications "(Capital_TopCode=sec_treat) Tot_Hours_Worked "
local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
		*GET MEAN, VAR OF DEPENDENT VAR FOR CONTROL
		 quietly regress `defaultvar' if sec_treat== 0 , cluster(sec_group_name)
		matrix control_mean = e(b)
		matrix control_var = e(V)
		
		 xi: ivreg `defaultvar' `specifications' `controls_and_miss' i.Stratification i.sec_loan_officer, cluster(sec_group_name) first
		
		*ADD MEAN OF DEPENDENT VARIABLE FOR CONTROL TO THE TABLE IN PLACE OF CONSTANT
		matrix V_temp = e(V)
		matrix b_temp = e(b)
		
		local numxvars = colsof(V_temp)

		local controls_used 1
	

		local colofcons = colnumb( V_temp, "_cons" )
		
		matrix V_temp[`colofcons', `colofcons'] = control_var[1,1]
		matrix b_temp[1, `colofcons'] = control_mean[1,1]
		
		erepost V = V_temp, rename
		erepost b = b_temp, rename
		
		eststo model`i'`j', addscalars(controls_used `controls_used')
	
}





local esttaboptions se title("New Business") drop( `controls_and_miss' ) coeflabels(_cons "Mean for No Delay ") scalars(controls_used)

esttab model* using "$cd\Tables\Excel Files\App Table 3-ProductionTC.csv", `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01)

est clear

