*******************************
* AUTHOR: Natalia Rigol
* Program Purpose: Figure 4
* Date Created: 12/24/2012
***********************************



*GLOBAL DIRECTORY

global VFSROOT "C:\Users\Natalia\Dropbox\VWS Projects"

global cd	"$VFSROOT\graceperiodpaper\AER Resubmit\Publication Version"

*USING FILE


clear
use "$cd\New Files 20130415\Publication Data and Do Files\Grace Period Data.dta", clear



* IDEAL AMOUNT NPV FOR EACH INTEREST RATE 


forvalues j = 10/31 {			
* loop through flat interest rates j
	scalar Ideal_NPV_Treat_`j' = 0
	scalar Ideal_NPV_Control_`j' = 0
	
	forvalues i = 1/22 {		
* loop through fortnights i and add present value of each payment
		scalar Ideal_NPV_Treat_`j' = Ideal_NPV_Treat_`j' + (8000*1.`j'/22)/((Fortnightly_Interest_Rate)^(`i'+4))
		
		scalar Ideal_NPV_Control_`j' = Ideal_NPV_Control_`j' + (8000*1.`j'/22)/((Fortnightly_Interest_Rate)^(`i'))
	}
}


* NPV OF THE AMOUNT THAT THEY SHOULD'VE REPAID

gen Pay_Due_Each_Repayment_NPV_Treat=0
gen Pay_Due_Each_Repayment_NPV_Cont=0

forvalues j=4000(1000)10000{
	forvalues i = 1/22 {	
		replace Pay_Due_Each_Repayment_NPV_Treat=Pay_Due_Each_Repayment_NPV_Treat + (`j'*1.10/22)/((Fortnightly_Interest_Rate)^(`i'+4)) if sec_loanamount==`j' & sec_treat==1
		replace Pay_Due_Each_Repayment_NPV_Cont=Pay_Due_Each_Repayment_NPV_Cont + (`j'*1.10/22)/((Fortnightly_Interest_Rate)^(`i')) if sec_loanamount==`j' & sec_treat==0
		
		}
	}
gen Pay_Due_Each_Repayment_NPV=Pay_Due_Each_Repayment_NPV_Treat
replace Pay_Due_Each_Repayment_NPV=Pay_Due_Each_Repayment_NPV_Cont if Pay_Due_Each_Repayment_NPV==0
	



**************************************************************************************************
*************************************WITH SELECTION***********************************************
**************************************************************************************************

* REPAYMENT RATE PER PERSON
gen Repayment_Rate=Received_Amount_NPV/Pay_Due_Each_Repayment_NPV


* JP: ALTERNATIVE OF CODE ABOVE (POSSIBLY EASIER TO READ?)
forvalues j = 10/31 {
    * Compute average repayment rate conditional on preference and contract received
    * for treatment group
    qui: summ Repayment_Rate if Prefer_NoGrace == 0 & sec_treat == 1 & ///
        Interest_Rate >= 1.`j' & Interest_Rate != .
    scalar mean_Repayment_Rate_PT_GT_`j'=r(mean)

    * Compute average repayment rate conditional on preference and contract received
    * for control group
    qui: summ Repayment_Rate if Prefer_NoGrace == 0 & sec_treat == 0 & ///
        Interest_Rate >= 1.`j' & Interest_Rate != .
    scalar mean_Repayment_Rate_PT_GC_`j'=r(mean)
}



* THE NUMBER OF PEOPLE AT EACH INTEREST RATE
gen N=1 if Interest_Rate!=. & Prefer_NoGrace !=.
sum N
gen Total=r(N)
forvalues j = 10/31 {
    summ N if Interest_Rate >= 1.`j' & Interest_Rate != .
    scalar mean_Prefer_Grace_`j'=r(N)/Total
}


*PROFIT PER PERSON
matrix B=J(22,1,.)
forvalues j=10/31 {
    scalar Profit_Per_Person_PT_GT_`j'=mean_Repayment_Rate_PT_GT_`j'*Ideal_NPV_Treat_`j'-8000
    scalar Profit_Per_Person_PT_GC_`j'=mean_Repayment_Rate_PT_GC_`j'*Ideal_NPV_Control_10-8000
    scalar Difference_Profits_`j'=mean_Prefer_Grace_`j'*(Profit_Per_Person_PT_GT_`j'-Profit_Per_Person_PT_GC_`j')
    local n=`j'-9
    matrix B[`n',1]=Difference_Profits_`j'
}

*JP: I think we should multiply the above difference in profits by the fraction of clients who
*     prefer the grace period contract to the regular contract. (see page 31 of paper)

*DIFFERENCE IN PROFITS
sort slid
gen Number=_n
gen Difference_Profits=.
gen Interest=.
forvalues j=10/31 {
    local n=`j'-9
    replace Interest=`j' if Number==`n'
    replace Difference_Profits=B[`n',1] if Interest==`j'
}
label var Difference_Profits "Selection and No Moral Hazard"


twoway (line  Difference_Profits Interest)
**************************************************************************************************
*******************************************************NO SELECTION***************************
**************************************************************************************************

* JP: ALTERNATIVE OF CODE ABOVE (POSSIBLY EASIER TO READ -- AND ALSO DOES NOT CONDITION
*	ON INTEREST RATE)	
* Compute average repayment rate conditional on contract received for treatment group
qui: summ Repayment_Rate if sec_treat == 1 
scalar mean_Repayment_Rate_T_10=r(mean)

* Compute average repayment rate conditional on contract received for treatment group
qui: summ Repayment_Rate if sec_treat == 0 
scalar mean_Repayment_Rate_C_10=r(mean)

*PROFIT PER PERSON
matrix A=J(22,1,.)
forvalues j=10/31 {
	scalar Profit_Per_Person_T_`j'=mean_Repayment_Rate_T_10*Ideal_NPV_Treat_`j'-8000
	scalar Profit_Per_Person_C_`j'=mean_Repayment_Rate_C_10*Ideal_NPV_Control_10-8000
	scalar Difference_Profits_NS_`j'=Profit_Per_Person_T_`j'-Profit_Per_Person_C_`j'
	local n=`j'-9
	matrix A[`n',1]=Difference_Profits_NS_`j'
}

*Difference in Profits NO SELECTION
sort slid 
gen Difference_Profits_NS=.
gen Interest_NS=.
 forvalues j=10/31 {
 local n=`j'-9
replace Interest_NS=`j' if Number==`n'
replace Difference_Profits_NS=A[`n',1] if Interest_NS==`j'
}

twoway (line  Difference_Profits Interest) (line  Difference_Profits_NS Interest)



**************************************************************************************************
*******************************************************NO SELECTION BUT INCLUDING PREFERENCE***************************
**************************************************************************************************



* JP: ALTERNATIVE OF CODE ABOVE (POSSIBLY EASIER TO READ -- AND ALSO DOES NOT CONDITION
*	ON INTEREST RATE)	
* Compute average repayment rate conditional on contract received for treatment group
qui: summ Repayment_Rate if sec_treat == 1 
scalar mean_Repayment_Rate_T_10=r(mean)

* Compute average repayment rate conditional on contract received for treatment group
qui: summ Repayment_Rate if sec_treat == 0 
scalar mean_Repayment_Rate_C_10=r(mean)

*PROFIT PER PERSON
matrix A=J(22,1,.)
forvalues j=10/31 {
	scalar Profit_Per_Person_T_`j'=mean_Repayment_Rate_T_10*Ideal_NPV_Treat_`j'-8000
	scalar Profit_Per_Person_C_`j'=mean_Repayment_Rate_C_10*Ideal_NPV_Control_10-8000
	scalar Difference_Profits_NSP_`j'=mean_Prefer_Grace_`j'*(Profit_Per_Person_T_`j'-Profit_Per_Person_C_`j')
	local n=`j'-9
	matrix A[`n',1]=Difference_Profits_NSP_`j'
}

*Difference in Profits NO SELECTION
sort slid 
gen Difference_Profits_NSP=.
 forvalues j=10/31 {
 local n=`j'-9
replace Difference_Profits_NSP=A[`n',1] if Interest_NS==`j'
}


**************************************************************************************************
*************************************WITH MORAL HAZARD AND SELECTION***********************************************
**************************************************************************************************
gen k=0.46
gen Repayment_Rate_10=((Received_Amount_NPV)/Pay_Due_Each_Repayment_NPV)
gen Repayment_Rate_11=(((Received_Amount_NPV)/Pay_Due_Each_Repayment_NPV)*(100-k))/100


forvalues i=12/31{
	local m=`i'-1
	gen Repayment_Rate_`i'=((Repayment_Rate_`m')*(100-k))/100
}




forvalues j = 10/31 {
	* Compute average repayment rate conditional on preference and contract received
	* for treatment group USING THE REPAYMENT RATES WITH MORAL HAZARD
	 summ Repayment_Rate_`j' if Prefer_NoGrace == 0 & sec_treat == 1 & ///
		Interest_Rate >= 1.`j' & Interest_Rate != .
	scalar mean_Repayment_Rate_PT_GT_MH_`j'=r(mean)

	* Compute average repayment rate conditional on preference and contract received
	* for control group USING THE REPAYMENT RATE WITHOUT MORAL HAZARD
	 summ Repayment_Rate if Prefer_NoGrace == 0 & sec_treat == 0 & ///
		Interest_Rate >= 1.`j' & Interest_Rate != .
	scalar mean_Repayment_Rate_PT_GC_MH_`j'=r(mean)
}


*PROFIT PER PERSON
matrix B=J(22,1,.)
forvalues j=10/31 {
	scalar Profit_Per_Person_PT_GT_MH_`j'=mean_Repayment_Rate_PT_GT_MH_`j'*Ideal_NPV_Treat_`j'-8000
	scalar Profit_Per_Person_PT_GC_MH_`j'=mean_Repayment_Rate_PT_GC_MH_`j'*Ideal_NPV_Control_10-8000
	scalar Difference_Profits_MH_`j'=mean_Prefer_Grace_`j'*(Profit_Per_Person_PT_GT_MH_`j'-Profit_Per_Person_PT_GC_MH_`j')
	local n=`j'-9
	matrix B[`n',1]=Difference_Profits_MH_`j'
}


*DIFFERENCE IN PROFITS
sort slid 

gen Difference_Profits_MH=.

forvalues j=10/31 {
	local n=`j'-9
	
	replace Difference_Profits_MH=B[`n',1] if Interest==`j'

}




local APRInt 0.175 0.195 0.21 0.23 0.25	0.268 0.287	0.306 0.325	0.345 0.364	0.384 0.404	0.424 0.444	0.465 0.485	0.506 0.527	0.547 0.568	0.59
forvalues j=10/31 {
	local n=`j'-9
local APR: word `n' of `APRInt'

	replace Interest=`APR' if Interest==`j'

}
replace Interest=Interest*100
label var Interest "Percent APR"
label var Difference_Profits_NSP "No Selection and No Moral Hazard but with Preferences"
label var Difference_Profits_MH "Selection and Moral Hazard"
label var Difference_Profits "Selection and No Moral Hazard"

twoway  (line  Difference_Profits_NSP Interest) (line  Difference_Profits_MH Interest, lpattern(dash) ) (line  Difference_Profits Interest, legend(symxsize(20)  cols(2) rows(2)) lpattern(longdash_dot) xtick(15(5)60) xmtick(15(5)60) ytick(-140(20)80) yline(0) ytitle("Difference in Profits per Client") )
