*******************************
* AUTHOR: Natalia Rigol
* Program Purpose: Creates table 1- Loan Use 
* Date Created: 12/24/2012
***********************************


*GLOBAL DIRECTORY

global VFSROOT "C:\Users\Natalia\Dropbox\VWS Projects"

global cd	"$VFSROOT\graceperiodpaper\AER Resubmit\Publication Version"

*USING FILE


clear
use "$cd\New Files 20130415\Publication Data and Do Files\Grace Period Data.dta", clear



* GENERATES A SEPARATE VARIABLE FOR EACH LOAN AMOUNT

tab sec_loanamount, gen(sec_loanamount)

forvalues i=1/7{
gen miss_sec_loanamount`i' = 0
replace miss_sec_loanamount`i' = 1 if sec_loanamount == .
}


**************************************************************
*REGRESSION WITHOUT CONTROLS BUT WITH LOAN AMOUNT
**************************************************************

*CONTROLS
local controls sec_loanamount1 sec_loanamount2 sec_loanamount3 sec_loanamount4 sec_loanamount5 sec_loanamount6 



*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
	local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'

*BASE SPECIFICATION

local defaultvars Business_Expenditures  Inventory_Raw_Mat Equipment  Other_Bus_Cost Non_Business_Exp  Repairs_Repair_Only Utilities_Taxes_Rent    Human_Capital Re_Lent Savings   Food_And_Durable  New_Business_Ap15
local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
		
		*GET MEAN, VAR OF DEPENDENT VAR FOR CONTROL
		 quietly regress `defaultvar' if sec_treat== 0 & Match3rd_in3rd ==0 , cluster(sec_group_name)
		matrix control_mean = e(b)
		matrix control_var = e(V)
		
		 xi: regress `defaultvar' sec_treat Match3rd_in3rd i.Stratification_Dummies `controls_and_miss', cluster(sec_group_name)
		
		*ADD MEAN OF DEPENDENT VARIABLE FOR CONTROL TO THE TABLE IN PLACE OF CONSTANT
		matrix V_temp = e(V)
		matrix b_temp = e(b)
		
		local numxvars = colsof(V_temp)

		local controls_used 0
	
		local colofcons = colnumb( V_temp, "_cons" )
		
		matrix V_temp[`colofcons', `colofcons'] = control_var[1,1]
		matrix b_temp[1, `colofcons'] = control_mean[1,1]
		
		erepost V = V_temp, rename
		erepost b = b_temp, rename
		
		eststo model`i'`j', addscalars(controls_used `controls_used')
	}


* OUTPUT
local esttaboptions se label title("Loan Use") drop(_I*  Match3rd_in3rd sec_loanamount* miss_*) coeflabels(_cons "Avg(Y) for No Delay and Matched") scalars(controls_used)
esttab model* using "$cd\Tables\Excel Files\Table 1-Loan Use NC.csv", `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01)

eststo clear


**************************************************************
*REGRESSION WITH CONTROLS 
**************************************************************
*CONTROLS

* Make sure missings are 0 not averages (missing controls coded as "." only in Table 1)
local controls Age_C Married_C  Muslim_C HH_Size_C Years_Education_C shock_any_C  Has_Business_C Financial_Control_C homeowner_C  sec_loanamount1 sec_loanamount2 sec_loanamount3  sec_loanamount5 sec_loanamount6 sec_loanamount7 No_Drain_C
foreach var in `controls' {
replace `var' = 0 if miss_`var' == 1
}

*CONTROLS
local controls Age_C Married_C  Muslim_C HH_Size_C Years_Education_C shock_any_C  Has_Business_C Financial_Control_C homeowner_C  sec_loanamount1 sec_loanamount2 sec_loanamount3  sec_loanamount5 sec_loanamount6 sec_loanamount7 No_Drain_C


*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
	local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'

*BASE SPECIFICATION

local defaultvars Business_Expenditures  Inventory_Raw_Mat Equipment     Other_Bus_Cost Non_Business_Exp  Repairs_Repair_Only Utilities_Taxes_Rent    Human_Capital Re_Lent Savings   Food_And_Durable  New_Business_Ap15
local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
		
		*GET MEAN, VAR OF DEPENDENT VAR FOR CONTROL
		 quietly regress `defaultvar' if sec_treat== 0 & Match3rd_in3rd ==0 , cluster(sec_group_name)
		matrix control_mean = e(b)
		matrix control_var = e(V)
		
		 xi: regress `defaultvar' sec_treat Match3rd_in3rd i.Stratification_Dummies `controls_and_miss', cluster(sec_group_name)
		
		*ADD MEAN OF DEPENDENT VARIABLE FOR CONTROL TO THE TABLE IN PLACE OF CONSTANT
		matrix V_temp = e(V)
		matrix b_temp = e(b)
		
		local numxvars = colsof(V_temp)

		local controls_used 1
	
		local colofcons = colnumb( V_temp, "_cons" )
		
		matrix V_temp[`colofcons', `colofcons'] = control_var[1,1]
		matrix b_temp[1, `colofcons'] = control_mean[1,1]
		
		erepost V = V_temp, rename
		erepost b = b_temp, rename
		
		eststo model`i'`j', addscalars(controls_used `controls_used')
	}


local esttaboptions se label title("Loan Use") drop(_I*  Match3rd_in3rd  `controls_and_miss') coeflabels(_cons "Avg(Y) for No Delay and Matched") scalars(controls_used)

esttab model* using "$cd\Tables\Excel Files\Table 1-Loan Use C.csv", `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01)




eststo clear
