*******************************
* AUTHOR: Natalia Rigol
* Program Purpose: Creates Table 3- Default
* Date Created: 12/24/2012
***********************************

version 10

*GLOBAL DIRECTORY

global VFSROOT "C:\Users\Natalia\Dropbox\VWS Projects"

global cd	"$VFSROOT\graceperiodpaper\AER Resubmit\Publication Version"

*USING FILE


clear
use "$cd\New Files 20130415\Publication Data and Do Files\Grace Period Data.dta", clear



set linesize 200
di "$cd"


**************************************************************
*REGRESSIONS WITHOUT CONTROLS
**************************************************************

*BASE SPECIFICATION
* 
local defaultvars  Late_Days_364  Late_Days_476 not_finished_aug19 Outstanding Fifty_Percent_Loan_Paid  Made_First_11_Pay_On_Time Made_First_Pay
local specifications  "sec_treat i.Stratification"
local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'

		
		*GET MEAN, VAR OF DEPENDENT VAR FOR CONTROL
		quietly regress `defaultvar' if sec_treat == 0, cluster(sec_group_name)
		matrix control_mean = e(b)
		matrix control_var = e(V)
		
		 xi: regress `defaultvar' `specifications' , cluster(sec_group_name)
		
		*ADD MEAN OF DEPENDENT VARIABLE FOR CONTROL TO THE TABLE IN PLACE OF CONSTANT
		matrix V_temp = e(V)
		matrix b_temp = e(b)
		
		local numxvars = colsof(V_temp)
	
		local controls_used 0

		local colofcons = colnumb( V_temp, "_cons" )
		
		matrix V_temp[`colofcons', `colofcons'] = control_var[1,1]
		matrix b_temp[1, `colofcons'] = control_mean[1,1]
		
		erepost V = V_temp, rename
		erepost b = b_temp, rename
		
		eststo model`i'`j', addscalars(controls_used `controls_used')
	}


local esttaboptions se label title("Impact of Delay on Default") drop(_I*) coeflabels(_cons "Avg(Y) for No Delay") scalars(controls_used)

esttab model* using "$cd\Table 3-Default NC.csv", `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01)

eststo clear





**************************************************************
*REGRESSIONS WITH CONTROLS
**************************************************************

tab sec_loanamount, gen(sec_loanamount)

forvalues i=1/7{
gen miss_sec_loanamount`i' = 0
replace miss_sec_loanamount`i' = 1 if sec_loanamount == .
}



duplicates drop slid, force

* Make sure missings are 0 not averages (missing controls coded as "." only in Table 1)
local risk Age_C Married_C Literate_C Muslim_C HH_Size_C Years_Education_C shock_any_C  Has_Business_C Financial_Control_C homeowner_C  sec_loanamount1 sec_loanamount2 sec_loanamount3  sec_loanamount5 sec_loanamount6 sec_loanamount7 No_Drain_C
foreach var in `risk' {
replace `var' = 0 if miss_`var' == 1
}

*FIRST STAGE TABLE
	
*CONTROLS
local controls Age_C Married_C Literate_C Muslim_C HH_Size_C Years_Education_C shock_any_C  Has_Business_C Financial_Control_C homeowner_C  sec_loanamount1 sec_loanamount2 sec_loanamount3  sec_loanamount5 sec_loanamount6 sec_loanamount7 No_Drain_C



*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'



	
*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
	local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'

*BASE SPECIFICATION
local defaultvars  Late_Days_364  Late_Days_476 not_finished_aug19 Outstanding Fifty_Percent_Loan_Paid  Made_First_11_Pay_On_Time Made_First_Pay
local specifications  "sec_treat i.Stratification i.sec_loan_officer `controls_and_miss'"
local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
	
		*GET MEAN, VAR OF DEPENDENT VAR FOR CONTROL
		quietly regress `defaultvar' if sec_treat == 0, cluster(sec_group_name)
		matrix control_mean = e(b)
		matrix control_var = e(V)
		
		 xi: regress `defaultvar' `specifications' , cluster(sec_group_name)
		
		*ADD MEAN OF DEPENDENT VARIABLE FOR CONTROL TO THE TABLE IN PLACE OF CONSTANT
		matrix V_temp = e(V)
		matrix b_temp = e(b)
		
		local numxvars = colsof(V_temp)
	
		local controls_used 1
		
		
		local colofcons = colnumb( V_temp, "_cons" )
		
		matrix V_temp[`colofcons', `colofcons'] = control_var[1,1]
		matrix b_temp[1, `colofcons'] = control_mean[1,1]
		
		erepost V = V_temp, rename
		erepost b = b_temp, rename
		
		eststo model`i'`j', addscalars(controls_used `controls_used')
	}


local esttaboptions se label title("Impact of Delay on Default") drop(_I* `controls_and_miss' ) coeflabels(_cons "Avg(Y) for No Delay") scalars(controls_used)


esttab model* using "$cd\Table 3-Default C.csv", `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01)

eststo clear
