*******************************
* AUTHOR: Natalia Rigol
* Program Purpose: Table 4- Business Size and Behavior
* Date Created: 12/24/2012
***********************************


*GLOBAL DIRECTORY

global VFSROOT "C:\Users\Natalia\Dropbox\VWS Projects"

global cd	"$VFSROOT\graceperiodpaper\AER Resubmit\Publication Version"

*USING FILE


clear
use "$cd\New Files 20130415\Publication Data and Do Files\Grace Period Data.dta", clear




**************************************************************
*REGRESSIONS WITHOUT CONTROLS
**************************************************************

local defaultvars atleastone_bizshutdown_alt Max_Min     Q68 Q35_ Q37  Q11_Together_max


local specifications  "sec_treat i.Stratification_Dummies"
local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
		*GET MEAN, VAR OF DEPENDENT VAR FOR CONTROL
		 quietly regress `defaultvar' if sec_treat== 0 , cluster(sec_group_name)
		matrix control_mean = e(b)
		matrix control_var = e(V)
		
		 xi: regress `defaultvar' `specifications', cluster(sec_group_name)
		
		*ADD MEAN OF DEPENDENT VARIABLE FOR CONTROL TO THE TABLE IN PLACE OF CONSTANT
		matrix V_temp = e(V)
		matrix b_temp = e(b)
		
		local numxvars = colsof(V_temp)

		local controls_used 0
	

		local colofcons = colnumb( V_temp, "_cons" )
		
		matrix V_temp[`colofcons', `colofcons'] = control_var[1,1]
		matrix b_temp[1, `colofcons'] = control_mean[1,1]
		
		erepost V = V_temp, rename
		erepost b = b_temp, rename
		
		eststo model`i'`j', addscalars(controls_used `controls_used')
	
}

local esttaboptions se title("New Business")  coeflabels(_cons "Mean for No Delay ") scalars(controls_used) drop (_I*)

esttab model* using "$cd\Tables\Excel Files\Table 4- Business Size NC.csv", `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01)

est clear



**************************************************************
*REGRESSIONS WITH CONTROLS
**************************************************************

* getting full set of controls together, for all 845 individuals in the second intervention

tab sec_loanamount, gen(sec_loanamount)

forvalues i=1/7{
gen miss_sec_loanamount`i' = 0
replace miss_sec_loanamount`i' = 1 if sec_loanamount == .
}



duplicates drop slid, force

* Make sure missings are 0 not averages (missing controls coded as "." only in Table 1)
local controls Age_C Married_C Literate_C Muslim_C HH_Size_C Years_Education_C shock_any_C  Has_Business_C Financial_Control_C homeowner_C  sec_loanamount1 sec_loanamount2 sec_loanamount3  sec_loanamount5 sec_loanamount6 sec_loanamount7 No_Drain_C
foreach var in `controls' {
replace `var' = 0 if miss_`var' == 1
}


	
*CONTROLS
local controls Age_C Married_C Literate_C Muslim_C HH_Size_C Years_Education_C shock_any_C  Has_Business_C Financial_Control_C homeowner_C  sec_loanamount1 sec_loanamount2 sec_loanamount3  sec_loanamount5 sec_loanamount6 sec_loanamount7 No_Drain_C



*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'



local defaultvars atleastone_bizshutdown_alt Max_Min     Q68 Q35_ Q37  Q11_Together_max

local specifications "sec_treat i.Stratification_Dummies i.sec_loan_officer `controls_and_miss'"
local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'

		
		*GET MEAN, VAR OF DEPENDENT VAR FOR CONTROL
		 quietly regress `defaultvar' if sec_treat== 0 , cluster(sec_group_name)
		matrix control_mean = e(b)
		matrix control_var = e(V)
		
		 xi: regress `defaultvar' `specifications', cluster(sec_group_name)
		
		*ADD MEAN OF DEPENDENT VARIABLE FOR CONTROL TO THE TABLE IN PLACE OF CONSTANT
		matrix V_temp = e(V)
		matrix b_temp = e(b)
		
		local numxvars = colsof(V_temp)

		local controls_used 1
	

		local colofcons = colnumb( V_temp, "_cons" )
		
		matrix V_temp[`colofcons', `colofcons'] = control_var[1,1]
		matrix b_temp[1, `colofcons'] = control_mean[1,1]
		
		erepost V = V_temp, rename
		erepost b = b_temp, rename
		
		eststo model`i'`j', addscalars(controls_used `controls_used')
	}


local esttaboptions se title("New Business") drop(_I* `controls_and_miss' ) coeflabels(_cons "Mean for No Delay ") scalars(controls_used)

esttab model* using "$cd\Tables\Excel Files\Table 4- Business Size C.csv", `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01)

est clear

