*******************************
* AUTHOR: Natalia Rigol
* Program Purpose: Table 5- Heterogeneous Business
* Date Created: 12/24/2012
***********************************



*GLOBAL DIRECTORY

global VFSROOT "C:\Users\Natalia\Dropbox\VWS Projects"

global cd	"$VFSROOT\graceperiodpaper\AER Resubmit\Publication Version"

*USING FILE


clear
use "$cd\New Files 20130415\Publication Data and Do Files\Grace Period Data.dta", clear



* GENEATING DUMMY VARIABLES


 
local variables2 Impatient Risk_Loving  Earns_Wage Chronically_Ill No_Business_Broad Has_Savings_Acc_Apr24
forvalues i=1/6 {
local var2: word `i' of `variables2'
	gen sec_treat_`var2'=sec_treat*`var2'
}


egen Heterogeneous=rowtotal(No_Business_Broad Impatient  Earns_Wage    Risk_Loving  Has_Savings_Acc_Apr24),m  


***********************************************************************************************************************************************
***************************************************IMPATIENT*****************************************************************************
***********************************************************************************************************************************************

* Make sure missings are 0 not averages (missing controls coded as "." only in Table 1)
local risk  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain


foreach var of local risk {
	replace `var' = 0 if miss_`var' == 1
	}
local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain




local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C  Has_Business_C homeowner_C   Financial_Control_C  sec_loanamount   No_Drain


*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'

local defaultvars    Profit  
local interaction Impatient
local specifications  " sec_treat sec_treat_`interaction' `interaction'  i.Stratification_Dummies "
local specifications ""`specifications'" " sec_treat sec_treat_Impatient Impatient i.Stratification_Dummies i.sec_loan_officer `controls_and_miss'""

local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
	local j 0
	foreach specification in `specifications' {
		local j = `j' + 1
		local m=`j'-1

		
		*REGRESSION
		 xi: regress  `defaultvar'  `specification' , cluster(sec_group_name)
		 
		*F TEST
		 lincom sec_treat_`interaction'+sec_treat
		 
		*SAVE RESULTS OF F TEST
		 estadd scalar Estimate = r(estimate)
		estadd scalar SE = r(se)

		*GET MEAN OF INTERACTION VARIABLE
		summ `interaction'
		
		*SAVE RESULTS
		estadd scalar Mean_of_Characteristic=r(mean)
		estadd scalar SD_of_Characteristic=r(sd)
	
		*CONTROLS USED
		estadd scalar Controls_Used=`m'
		
		eststo model`i'`j'
	
}
}




local esttaboptions se title("default") drop(_I* *miss_*  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain_C _cons)  


esttab model* using "$cd\Tables\Excel Files\Table5- HeteroDumImpatient.csv", stats(Estimate SE Mean_of_Characteristic SD_of_Characteristic Controls_Used) `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01) 


eststo clear



***********************************************************************************************************************************************
***************************************************SAVINGS ACCOUNT*****************************************************************************
***********************************************************************************************************************************************


* Make sure missings are 0 not averages (missing controls coded as "." only in Table 1)
local risk  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain


foreach var of local risk {
	replace `var' = 0 if miss_`var' == 1
	}
local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain




local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C  Has_Business_C homeowner_C   Financial_Control_C  sec_loanamount   No_Drain


*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'

local defaultvars    Profit  
local interaction Has_Savings_Acc_Apr24
local specifications  " sec_treat sec_treat_`interaction' `interaction'  i.Stratification_Dummies "
local specifications ""`specifications'" " sec_treat sec_treat_`interaction' `interaction' i.Stratification_Dummies i.sec_loan_officer `controls_and_miss'""

local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
	local j 0
	foreach specification in `specifications' {
		local j = `j' + 1
		local m=`j'-1

		
		*REGRESSION
		 xi: regress  `defaultvar'  `specification' , cluster(sec_group_name)
		 
		*F TEST
		 lincom sec_treat_`interaction'+sec_treat
		 
		*SAVE RESULTS OF F TEST
		 estadd scalar Estimate = r(estimate)
		estadd scalar SE = r(se)

		*GET MEAN OF INTERACTION VARIABLE
		summ `interaction'
		
		*SAVE RESULTS
		estadd scalar Mean_of_Characteristic=r(mean)
		estadd scalar SD_of_Characteristic=r(sd)
	
		*CONTROLS USED
		estadd scalar Controls_Used=`m'
		
		eststo model`i'`j'
	
}
}




local esttaboptions se title("default") drop(_I* *miss_*  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain_C _cons)  


esttab model* using "$cd\Tables\Excel Files\Table5- HeteroDumSavings.csv", stats(Estimate SE Mean_of_Characteristic SD_of_Characteristic Controls_Used) `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01) 
 eststo clear 



***********************************************************************************************************************************************
***************************************************RISK LOVING*****************************************************************************
***********************************************************************************************************************************************


* Make sure missings are 0 not averages (missing controls coded as "." only in Table 1)
local risk  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain


foreach var of local risk {
	replace `var' = 0 if miss_`var' == 1
	}
local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain




local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C  Has_Business_C homeowner_C   Financial_Control_C  sec_loanamount   No_Drain


*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'

local defaultvars    Profit  
local interaction Risk_Loving
local specifications  " sec_treat sec_treat_`interaction' `interaction'  i.Stratification_Dummies "
local specifications ""`specifications'" " sec_treat sec_treat_`interaction' `interaction' i.Stratification_Dummies i.sec_loan_officer `controls_and_miss'""

local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
	local j 0
	foreach specification in `specifications' {
		local j = `j' + 1
		local m=`j'-1

		
		*REGRESSION
		 xi: regress  `defaultvar'  `specification' , cluster(sec_group_name)
		 
		*F TEST
		 lincom sec_treat_`interaction'+sec_treat
		 
		*SAVE RESULTS OF F TEST
		 estadd scalar Estimate = r(estimate)
		estadd scalar SE = r(se)

		*GET MEAN OF INTERACTION VARIABLE
		summ `interaction'
		
		*SAVE RESULTS
		estadd scalar Mean_of_Characteristic=r(mean)
		estadd scalar SD_of_Characteristic=r(sd)
	
		*CONTROLS USED
		estadd scalar Controls_Used=`m'
		
		eststo model`i'`j'
	
}
}




local esttaboptions se title("default") drop(_I* *miss_*  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain_C _cons)  


esttab model* using "$cd\Tables\Excel Files\Table5- HeteroDumRiskLoving.csv", stats(Estimate SE Mean_of_Characteristic SD_of_Characteristic Controls_Used) `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01) 


eststo clear



***********************************************************************************************************************************************
************************************AT LEAST ONE HH MEMBER OF SPOUSE AND WIFE EARNS A WAGE****************************************
***********************************************************************************************************************************************



* Make sure missings are 0 not averages (missing controls coded as "." only in Table 1)
local risk  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain


foreach var of local risk {
	replace `var' = 0 if miss_`var' == 1
	}
local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain




local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C  Has_Business_C homeowner_C   Financial_Control_C  sec_loanamount   No_Drain


*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'

local defaultvars    Profit  
local interaction Earns_Wage
local specifications  " sec_treat sec_treat_`interaction' `interaction'  i.Stratification_Dummies "
local specifications ""`specifications'" " sec_treat sec_treat_`interaction' `interaction' i.Stratification_Dummies i.sec_loan_officer `controls_and_miss'""

local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
	local j 0
	foreach specification in `specifications' {
		local j = `j' + 1
		local m=`j'-1

		
		*REGRESSION
		 xi: regress  `defaultvar'  `specification' , cluster(sec_group_name)
		 
		*F TEST
		 lincom sec_treat_`interaction'+sec_treat
		 
		*SAVE RESULTS OF F TEST
		 estadd scalar Estimate = r(estimate)
		estadd scalar SE = r(se)

		*GET MEAN OF INTERACTION VARIABLE
		summ `interaction'
		
		*SAVE RESULTS
		estadd scalar Mean_of_Characteristic=r(mean)
		estadd scalar SD_of_Characteristic=r(sd)
	
		*CONTROLS USED
		estadd scalar Controls_Used=`m'
		
		eststo model`i'`j'
	
}
}




local esttaboptions se title("default") drop(_I* *miss_*  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain_C _cons)  


esttab model* using "$cd\Tables\Excel Files\Table5- HeteroDumEarnsWage.csv", stats(Estimate SE Mean_of_Characteristic SD_of_Characteristic Controls_Used) `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01) 

eststo clear


***********************************************************************************************************************************************
************************************NU CHRONIC ILL*********************************************************************************************
***********************************************************************************************************************************************




* Make sure missings are 0 not averages (missing controls coded as "." only in Table 1)
local risk  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain


foreach var of local risk {
	replace `var' = 0 if miss_`var' == 1
	}
local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain




local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C  Has_Business_C homeowner_C   Financial_Control_C  sec_loanamount   No_Drain


*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'

local defaultvars    Profit  
local interaction Chronically_Ill
local specifications  " sec_treat sec_treat_`interaction' `interaction'  i.Stratification_Dummies "
local specifications ""`specifications'" " sec_treat sec_treat_`interaction' `interaction' i.Stratification_Dummies i.sec_loan_officer `controls_and_miss'""

local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
	local j 0
	foreach specification in `specifications' {
		local j = `j' + 1
		local m=`j'-1

		
		*REGRESSION
		 xi: regress  `defaultvar'  `specification'    , cluster(sec_group_name)
		 
		*F TEST
		 lincom sec_treat_`interaction'+sec_treat
		 
		*SAVE RESULTS OF F TEST
		 estadd scalar Estimate = r(estimate)
		estadd scalar SE = r(se)

		*GET MEAN OF INTERACTION VARIABLE
		summ `interaction'
		
		*SAVE RESULTS
		estadd scalar Mean_of_Characteristic=r(mean)
		estadd scalar SD_of_Characteristic=r(sd)
	
		*CONTROLS USED
		estadd scalar Controls_Used=`m'
		
		eststo model`i'`j'
	
}
}




local esttaboptions se title("default") drop(_I* *miss_*  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain_C _cons)  


esttab model* using "$cd\Tables\Excel Files\Table5- HeteroDumChronicSick.csv", stats(Estimate SE Mean_of_Characteristic SD_of_Characteristic Controls_Used) `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01) 

eststo clear




***********************************************************************************************************************************************
************************************NO BUSINESS*********************************************************************************
***********************************************************************************************************************************************

* Make sure missings are 0 not averages (missing controls coded as "." only in Table 1)
local risk  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain


foreach var of local risk {
	replace `var' = 0 if miss_`var' == 1
	}
local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C  homeowner_C  Financial_Control_C  sec_loanamount   No_Drain




local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C   homeowner_C   Financial_Control_C  sec_loanamount   No_Drain


*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'

local defaultvars    Profit  
local interaction No_Business_Broad
local specifications  " sec_treat sec_treat_`interaction' `interaction'  i.Stratification_Dummies "
local specifications ""`specifications'" " sec_treat sec_treat_`interaction' `interaction' i.Stratification_Dummies i.sec_loan_officer `controls_and_miss'""

local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
	local j 0
	foreach specification in `specifications' {
		local j = `j' + 1
		local m=`j'-1

		
		*REGRESSION
		 xi: regress  `defaultvar'  `specification' , cluster(sec_group_name)
		 
		*F TEST
		 lincom sec_treat_`interaction'+sec_treat
		 
		*SAVE RESULTS OF F TEST
		 estadd scalar Estimate = r(estimate)
		estadd scalar SE = r(se)

		*GET MEAN OF INTERACTION VARIABLE
		summ `interaction'
		
		*SAVE RESULTS
		estadd scalar Mean_of_Characteristic=r(mean)
		estadd scalar SD_of_Characteristic=r(sd)
	
		*CONTROLS USED
		estadd scalar Controls_Used=`m'
		
		eststo model`i'`j'
	
}
}




local esttaboptions se title("default") drop(_I* *miss_*  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C  homeowner_C  Financial_Control_C  sec_loanamount   No_Drain_C _cons)  


esttab model* using "$cd\Tables\Excel Files\Table5- HeteroDumNoBusBroad.csv", stats(Estimate SE Mean_of_Characteristic SD_of_Characteristic Controls_Used) `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01) 


eststo clear





***********************************************************************************************************************************************
************************************HETEROGENEOUS RISK INDEX*********************************************************************************
***********************************************************************************************************************************************


gen sec_treat_Heterogeneous=sec_treat*Heterogeneous




* Make sure missings are 0 not averages (missing controls coded as "." only in Table 1)
local risk  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain


foreach var of local risk {
	replace `var' = 0 if miss_`var' == 1
	}
local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain




local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C  Has_Business_C homeowner_C   Financial_Control_C  sec_loanamount   No_Drain


*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'

local defaultvars    Profit   
local interaction Heterogeneous
local specifications  " sec_treat sec_treat_`interaction' `interaction'  i.Stratification_Dummies "
local specifications ""`specifications'" " sec_treat sec_treat_`interaction' `interaction' i.Stratification_Dummies i.sec_loan_officer `controls_and_miss'""

local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
	local j 0
	foreach specification in `specifications' {
		local j = `j' + 1
		local m=`j'-1

		
		*REGRESSION
		 xi: regress  `defaultvar'  `specification'  , cluster(sec_group_name)
		 
		*F TEST
		 lincom sec_treat_`interaction'+sec_treat
		 
		*SAVE RESULTS OF F TEST
		 estadd scalar Estimate = r(estimate)
		estadd scalar SE = r(se)

		*GET MEAN OF INTERACTION VARIABLE
		summ `interaction'
		
		*SAVE RESULTS
		estadd scalar Mean_of_Characteristic=r(mean)
		estadd scalar SD_of_Characteristic=r(sd)
	
		*CONTROLS USED
		estadd scalar Controls_Used=`m'
		
		eststo model`i'`j'
	
}
}




local esttaboptions se title("default") drop(_I* *miss_*  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain_C _cons)  


esttab model* using "$cd\Tables\Excel Files\Table5- HeteroDumHeterogeneous1.csv", stats(Estimate SE Mean_of_Characteristic SD_of_Characteristic Controls_Used) `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01) 


eststo clear




***********************************************************************************************************************************************
***************************************************IMPATIENT*****************************************************************************
***********************************************************************************************************************************************






***********************************************************************************************************************************************
***************************************************IMPATIENT*****************************************************************************
***********************************************************************************************************************************************

* Make sure missings are 0 not averages (missing controls coded as "." only in Table 1)
local risk  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain


foreach var of local risk {
	replace `var' = 0 if miss_`var' == 1
	}
local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain




local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C  Has_Business_C homeowner_C   Financial_Control_C  sec_loanamount   No_Drain


*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'

local defaultvars     Profit_TopCode  
local interaction Impatient
local specifications  " sec_treat sec_treat_`interaction' `interaction'  i.Stratification_Dummies "
local specifications ""`specifications'" " sec_treat sec_treat_Impatient Impatient i.Stratification_Dummies i.sec_loan_officer `controls_and_miss'""

local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
	local j 0
	foreach specification in `specifications' {
		local j = `j' + 1
		local m=`j'-1

		
		*REGRESSION
		 xi: regress  `defaultvar'  `specification' , cluster(sec_group_name)
		 
		*F TEST
		 lincom sec_treat_`interaction'+sec_treat
		 
		*SAVE RESULTS OF F TEST
		 estadd scalar Estimate = r(estimate)
		estadd scalar SE = r(se)

		*GET MEAN OF INTERACTION VARIABLE
		summ `interaction'
		
		*SAVE RESULTS
		estadd scalar Mean_of_Characteristic=r(mean)
		estadd scalar SD_of_Characteristic=r(sd)
	
		*CONTROLS USED
		estadd scalar Controls_Used=`m'
		
		eststo model`i'`j'
	
}
}




local esttaboptions se title("default") drop(_I* *miss_*  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain_C _cons)  


esttab model* using "$cd\Tables\Excel Files\Table5- HeteroDumTCImpatient.csv", stats(Estimate SE Mean_of_Characteristic SD_of_Characteristic Controls_Used) `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01) 


eststo clear



***********************************************************************************************************************************************
***************************************************SAVINGS ACCOUNT*****************************************************************************
***********************************************************************************************************************************************


* Make sure missings are 0 not averages (missing controls coded as "." only in Table 1)
local risk  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain


foreach var of local risk {
	replace `var' = 0 if miss_`var' == 1
	}
local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain




local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C  Has_Business_C homeowner_C   Financial_Control_C  sec_loanamount   No_Drain


*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'

local defaultvars     Profit_TopCode  
local interaction Has_Savings_Acc_Apr24
local specifications  " sec_treat sec_treat_`interaction' `interaction'  i.Stratification_Dummies "
local specifications ""`specifications'" " sec_treat sec_treat_`interaction' `interaction' i.Stratification_Dummies i.sec_loan_officer `controls_and_miss'""

local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
	local j 0
	foreach specification in `specifications' {
		local j = `j' + 1
		local m=`j'-1

		
		*REGRESSION
		 xi: regress  `defaultvar'  `specification' , cluster(sec_group_name)
		 
		*F TEST
		 lincom sec_treat_`interaction'+sec_treat
		 
		*SAVE RESULTS OF F TEST
		 estadd scalar Estimate = r(estimate)
		estadd scalar SE = r(se)

		*GET MEAN OF INTERACTION VARIABLE
		summ `interaction'
		
		*SAVE RESULTS
		estadd scalar Mean_of_Characteristic=r(mean)
		estadd scalar SD_of_Characteristic=r(sd)
	
		*CONTROLS USED
		estadd scalar Controls_Used=`m'
		
		eststo model`i'`j'
	
}
}




local esttaboptions se title("default") drop(_I* *miss_*  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain_C _cons)  


esttab model* using "$cd\Tables\Excel Files\Table5- HeteroDumTCSavings.csv", stats(Estimate SE Mean_of_Characteristic SD_of_Characteristic Controls_Used) `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01) 
 eststo clear 



***********************************************************************************************************************************************
***************************************************RISK LOVING*****************************************************************************
***********************************************************************************************************************************************


* Make sure missings are 0 not averages (missing controls coded as "." only in Table 1)
local risk  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain


foreach var of local risk {
	replace `var' = 0 if miss_`var' == 1
	}
local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain




local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C  Has_Business_C homeowner_C   Financial_Control_C  sec_loanamount   No_Drain


*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'

local defaultvars     Profit_TopCode  
local interaction Risk_Loving
local specifications  " sec_treat sec_treat_`interaction' `interaction'  i.Stratification_Dummies "
local specifications ""`specifications'" " sec_treat sec_treat_`interaction' `interaction' i.Stratification_Dummies i.sec_loan_officer `controls_and_miss'""

local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
	local j 0
	foreach specification in `specifications' {
		local j = `j' + 1
		local m=`j'-1

		
		*REGRESSION
		 xi: regress  `defaultvar'  `specification' , cluster(sec_group_name)
		 
		*F TEST
		 lincom sec_treat_`interaction'+sec_treat
		 
		*SAVE RESULTS OF F TEST
		 estadd scalar Estimate = r(estimate)
		estadd scalar SE = r(se)

		*GET MEAN OF INTERACTION VARIABLE
		summ `interaction'
		
		*SAVE RESULTS
		estadd scalar Mean_of_Characteristic=r(mean)
		estadd scalar SD_of_Characteristic=r(sd)
	
		*CONTROLS USED
		estadd scalar Controls_Used=`m'
		
		eststo model`i'`j'
	
}
}




local esttaboptions se title("default") drop(_I* *miss_*  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain_C _cons)  


esttab model* using "$cd\Tables\Excel Files\Table5- HeteroDumTCRiskLoving.csv", stats(Estimate SE Mean_of_Characteristic SD_of_Characteristic Controls_Used) `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01) 


eststo clear



***********************************************************************************************************************************************
************************************AT LEAST ONE HH MEMBER OF SPOUSE AND WIFE EARNS A WAGE****************************************
***********************************************************************************************************************************************



* Make sure missings are 0 not averages (missing controls coded as "." only in Table 1)
local risk  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain


foreach var of local risk {
	replace `var' = 0 if miss_`var' == 1
	}
local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain




local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C  Has_Business_C homeowner_C   Financial_Control_C  sec_loanamount   No_Drain


*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'

local defaultvars     Profit_TopCode  
local interaction Earns_Wage
local specifications  " sec_treat sec_treat_`interaction' `interaction'  i.Stratification_Dummies "
local specifications ""`specifications'" " sec_treat sec_treat_`interaction' `interaction' i.Stratification_Dummies i.sec_loan_officer `controls_and_miss'""

local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
	local j 0
	foreach specification in `specifications' {
		local j = `j' + 1
		local m=`j'-1

		
		*REGRESSION
		 xi: regress  `defaultvar'  `specification' , cluster(sec_group_name)
		 
		*F TEST
		 lincom sec_treat_`interaction'+sec_treat
		 
		*SAVE RESULTS OF F TEST
		 estadd scalar Estimate = r(estimate)
		estadd scalar SE = r(se)

		*GET MEAN OF INTERACTION VARIABLE
		summ `interaction'
		
		*SAVE RESULTS
		estadd scalar Mean_of_Characteristic=r(mean)
		estadd scalar SD_of_Characteristic=r(sd)
	
		*CONTROLS USED
		estadd scalar Controls_Used=`m'
		
		eststo model`i'`j'
	
}
}




local esttaboptions se title("default") drop(_I* *miss_*  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain_C _cons)  


esttab model* using "$cd\Tables\Excel Files\Table5- HeteroDumTCEarnsWage.csv", stats(Estimate SE Mean_of_Characteristic SD_of_Characteristic Controls_Used) `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01) 

eststo clear


***********************************************************************************************************************************************
************************************NU CHRONIC ILL*********************************************************************************************
***********************************************************************************************************************************************




* Make sure missings are 0 not averages (missing controls coded as "." only in Table 1)
local risk  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain


foreach var of local risk {
	replace `var' = 0 if miss_`var' == 1
	}
local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain




local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C  Has_Business_C homeowner_C   Financial_Control_C  sec_loanamount   No_Drain


*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'

local defaultvars     Profit_TopCode  
local interaction Chronically_Ill
local specifications  " sec_treat sec_treat_`interaction' `interaction'  i.Stratification_Dummies "
local specifications ""`specifications'" " sec_treat sec_treat_`interaction' `interaction' i.Stratification_Dummies i.sec_loan_officer `controls_and_miss'""

local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
	local j 0
	foreach specification in `specifications' {
		local j = `j' + 1
		local m=`j'-1

		
		*REGRESSION
		 xi: regress  `defaultvar'  `specification'    , cluster(sec_group_name)
		 
		*F TEST
		 lincom sec_treat_`interaction'+sec_treat
		 
		*SAVE RESULTS OF F TEST
		 estadd scalar Estimate = r(estimate)
		estadd scalar SE = r(se)

		*GET MEAN OF INTERACTION VARIABLE
		summ `interaction'
		
		*SAVE RESULTS
		estadd scalar Mean_of_Characteristic=r(mean)
		estadd scalar SD_of_Characteristic=r(sd)
	
		*CONTROLS USED
		estadd scalar Controls_Used=`m'
		
		eststo model`i'`j'
	
}
}




local esttaboptions se title("default") drop(_I* *miss_*  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain_C _cons)  


esttab model* using "$cd\Tables\Excel Files\Table5- HeteroDumTCChronicSick.csv", stats(Estimate SE Mean_of_Characteristic SD_of_Characteristic Controls_Used) `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01) 

eststo clear




***********************************************************************************************************************************************
************************************NO BUSINESS*********************************************************************************
***********************************************************************************************************************************************

* Make sure missings are 0 not averages (missing controls coded as "." only in Table 1)
local risk  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain


foreach var of local risk {
	replace `var' = 0 if miss_`var' == 1
	}
local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C  homeowner_C  Financial_Control_C  sec_loanamount   No_Drain




local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C   homeowner_C   Financial_Control_C  sec_loanamount   No_Drain


*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'

local defaultvars     Profit_TopCode  
local interaction No_Business_Broad
local specifications  " sec_treat sec_treat_`interaction' `interaction'  i.Stratification_Dummies "
local specifications ""`specifications'" " sec_treat sec_treat_`interaction' `interaction' i.Stratification_Dummies i.sec_loan_officer `controls_and_miss'""

local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
	local j 0
	foreach specification in `specifications' {
		local j = `j' + 1
		local m=`j'-1

		
		*REGRESSION
		 xi: regress  `defaultvar'  `specification' , cluster(sec_group_name)
		 
		*F TEST
		 lincom sec_treat_`interaction'+sec_treat
		 
		*SAVE RESULTS OF F TEST
		 estadd scalar Estimate = r(estimate)
		estadd scalar SE = r(se)

		*GET MEAN OF INTERACTION VARIABLE
		summ `interaction'
		
		*SAVE RESULTS
		estadd scalar Mean_of_Characteristic=r(mean)
		estadd scalar SD_of_Characteristic=r(sd)
	
		*CONTROLS USED
		estadd scalar Controls_Used=`m'
		
		eststo model`i'`j'
	
}
}




local esttaboptions se title("default") drop(_I* *miss_*  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C  homeowner_C  Financial_Control_C  sec_loanamount   No_Drain_C _cons)  


esttab model* using "$cd\Tables\Excel Files\Table5- HeteroDumTCNoBusBroad.csv", stats(Estimate SE Mean_of_Characteristic SD_of_Characteristic Controls_Used) `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01) 


eststo clear





***********************************************************************************************************************************************
************************************HETEROGENEOUS RISK INDEX*********************************************************************************
***********************************************************************************************************************************************



*gen sec_treat_Heterogeneous=sec_treat*Heterogeneous




* Make sure missings are 0 not averages (missing controls coded as "." only in Table 1)
local risk  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain


foreach var of local risk {
	replace `var' = 0 if miss_`var' == 1
	}
local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain




local controls  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C  Has_Business_C homeowner_C   Financial_Control_C  sec_loanamount   No_Drain


*REPLACE MISSINGS WITH ZERO AND ADD SEPARATE DUMMY FOR EACH VARIABLE TO SOAK UP MISSINGS
local miss_controls
foreach var of varlist `controls' {
local miss_controls `miss_controls' miss_`var'
}

*ADD MISSINGS DUMMIES TO CONTROLS
local controls_and_miss `controls' `miss_controls'

local defaultvars     Profit_TopCode  
local interaction Heterogeneous
local specifications  " sec_treat sec_treat_`interaction' `interaction'  i.Stratification_Dummies "
local specifications ""`specifications'" " sec_treat sec_treat_`interaction' `interaction' i.Stratification_Dummies i.sec_loan_officer `controls_and_miss'""

local num_vars : list sizeof defaultvars

forvalues i = 1/`num_vars' {
	local defaultvar : word `i' of `defaultvars'
	
	local j 0
	foreach specification in `specifications' {
		local j = `j' + 1
		local m=`j'-1

		
		*REGRESSION
		 xi: regress  `defaultvar'  `specification'  , cluster(sec_group_name)
		 
		*F TEST
		 lincom sec_treat_`interaction'+sec_treat
		 
		*SAVE RESULTS OF F TEST
		 estadd scalar Estimate = r(estimate)
		estadd scalar SE = r(se)

		*GET MEAN OF INTERACTION VARIABLE
		summ `interaction'
		
		*SAVE RESULTS
		estadd scalar Mean_of_Characteristic=r(mean)
		estadd scalar SD_of_Characteristic=r(sd)
	
		*CONTROLS USED
		estadd scalar Controls_Used=`m'
		
		eststo model`i'`j'
	
}
}




local esttaboptions se title("default") drop(_I* *miss_*  Age_C Married_C  Muslim_C Years_Education_C  HH_Size_C shock_any_C Has_Business_C homeowner_C  Financial_Control_C  sec_loanamount   No_Drain_C _cons)  


esttab model* using "$cd\Tables\Excel Files\Table5- HeteroDumTCHeterogeneous.csv", stats(Estimate SE Mean_of_Characteristic SD_of_Characteristic Controls_Used) `esttaboptions' replace csv star (* 0.1 ** 0.05 *** 0.01) 


eststo clear



