# delimit;
set more off;
drop _all;
matrix drop _all;
capture log close;
set logtype text;
pause on;
* This was all estimated with Stata 11;
version 11.2;

* Generates the results in Table 1 of the paper (baseline summary statistics and randomization checks);

capture log using "Table1randomization", replace;

use "data" if time==0;

* Check randomization based on whether microcredit was assigned to be present in a given PA;
tab D;

local demog = "";
local loans = "";
local loans_tot = "";
local econ_agric = "";
local econ_other = "";

qui foreach var of varlist 	

	hhsize hh_adults hh_children male_head head_age head_noeduc 
	loans_rca loans_ngo loans_formal loans_informal loans loans_woman
	loanstot_rca loanstot_ngo loanstot_formal loanstot_informal loanstot loanstot_woman
	mainecon cropsales cropcosts anim_big_n anim_total anim_totsales
	bsns_sales bsns_costs bsns_n bsns_f inc_trans inc_wage assets surface nofood dist_health dist_market {;

	sum `var' if D==0 [w=fwt];
	matrix temp = [r(N),r(mean),r(sd)];
	reg `var' D [pw=fwt], cluster(pa);
	matrix temp = e(N),.,temp,.,_b[D];
	test D;
	matrix temp = temp,r(p);
	matrix rowname temp = `var';
	cap matrix results = results\temp;
		if _rc>0 {;
			matrix results=temp;
		};
	};
matrix colname results = n space n_control control control_se space difference pvalue;
mat list results, format(%8.3g);

*** Now do the joint test;

* Note that we do not use hhsize any more because that's collinear with other variables that describe household composition;

svyset pa [pw=fwt_hh];

qui foreach var of varlist 	
	hh_adults hh_children male_head head_age head_noeduc 
	loans_rca loans_ngo loans_formal loans_informal loans loans_woman
	loanstot_rca loanstot_ngo loanstot_formal loanstot_informal loanstot loanstot_woman
	mainecon cropsales cropcosts anim_big_n anim_total anim_totsales
	bsns_sales bsns_costs bsns_n bsns_f inc_trans inc_wage assets surface nofood dist_health dist_market  {;
	
	svy: reg `var' D;
	estimates store `var';
	
	};

	suest 	hh_adults hh_children male_head head_age head_noeduc 
		loans_rca loans_ngo loans_formal loans_informal loans loans_woman
		loanstot_rca loanstot_ngo loanstot_formal loanstot_informal loanstot loanstot_woman
		mainecon cropsales cropcosts anim_big_n anim_total anim_totsales
		bsns_sales bsns_costs bsns_n bsns_f inc_trans inc_wage assets surface nofood dist_health dist_market , svy;

test D;
	
log close;
