# delimit ;
set more off;
drop _all;
matrix drop _all;
capture log close;
set logtype text;
pause on;
* This was all estimated with Stata 11;
version 11.2;

**** ESTIMATE RESULTS IN TABLE 2 (BORROWING) AS WELL AS IN APPENDIX TABLE D.1;
**** Requires the file data.dta in the working directory;

log using "Table2borrowing", replace;

cap matrix drop result;
cap matrix drop results;

use "data";

***********************************;
**** PROGRAM FOR BASE SPECIFICATION;
***********************************;
cap program drop onereg;
program define onereg;
	syntax varname [if], [FIRST];
	qui sum `varlist' if t_D_None==1 [w=fwt];
	local mean_control = r(mean);
	qui reg `varlist' time t_D t_D_Both t_D_FP _FE* [pw=fwt], cluster(pa);
	qui test t_D;
	local p_D = r(p);
	qui test t_D_FP;
	local p_FP = r(p);
	qui test t_D_Both;
	local p_Both = r(p);
	matrix result = _b[t_D]\(_se[t_D])\ `p_D' \_b[t_D_FP]\(_se[t_D_FP])\ `p_FP' \ _b[t_D_Both]\(_se[t_D_Both])\ `p_Both'\e(N)\ `mean_control';
	matrix colnames result = `varlist';
	if "`first'" ~= "" {;
		mat results = result;
		mat rownames results =  b_t_D "s.e." "p-value" b_t_D_FP "s.e." "p-value" b_t_D_Both "s.e." "p-value" "Obs" "Control mean";
		};
	else {;
		mat results = results,result;
		};
end;

*** TABLE 2, PANEL A, Columns 1-6 (THE COMPLETE RESULTS ARE REPORTED IN APPENDIX TABLE D.1);

qui onereg loans_rca, first;
foreach var of varlist loans_ngo loans_formal loans_informal loans loans_w {;
	qui onereg `var';
	};
mat list results, format(%8.3g);

*** Now rescale the outcomes for composite measure;
foreach var of varlist loans_rca loans_ngo loans_formal loans_informal loans loans_w {;
	sum `var' if t_D_None==1 [w=fwt];
	gen norm_`var' = ( `var' - r(mean) )/r(sd);
};
egen index = rowmean(norm_*);
* This gives the estimate labeled "Any loan" in Panel C of Table 2;
areg index time t_D t_D_Both t_D_FP [pw=fwt], cluster(pa) absorb(pa); 
drop index norm_*;

*** TABLE 2, PANEL B, Columns 1-6 (THE COMPLETE RESULTS ARE REPORTED IN APPENDIX TABLE D.1);

qui onereg loanstot_rca, first;
foreach var of varlist loanstot_ngo loanstot_formal loanstot_informal loanstot loanstot_w {;
	qui onereg `var';
	};
mat list results, format(%8.3g);

*** Now rescale the outcomes for composite measure;
foreach var of varlist loanstot_rca loanstot_ngo loanstot_formal loanstot_informal loanstot loanstot_w {;
	sum `var' if t_D_None==1 [w=fwt];
	gen norm_`var' = ( `var' - r(mean) )/r(sd);
};
egen index = rowmean(norm_*);
* This gives the estimate labeled "Loan Amounts" in Panel C of Table 2;
areg index time t_D t_D_Both t_D_FP [pw=fwt], cluster(pa) absorb(pa); 
drop index norm_*;

* Estimate median loan for borrowers from ACSI/ACSSC in (actual) treatment area;
sum loanstot_rca if time==1 & T==1 & loanstot_rca>0 [w=fwt], d;

* Estimate mean loan for borrowers from any source at baseline, all areas;
sum loanstot if time==0 & loanstot>0 [w=fwt];

***************************************************************************;
**** PROGRAM FOR SPECIFICATION WITH NO FP CONTROLS, APPENDIX TABLE D.1 ****;
***************************************************************************;
cap program drop onereg;
program define onereg;
	syntax varname [if], [FIRST];
	qui sum `varlist' if t_D_None==1 [w=fwt];
	local mean_control = r(mean);
	qui reg `varlist' time t_D [pw=fwt], cluster(pa);
	qui test t_D;
	local p_D = r(p);
	matrix result = _b[t_D]\(_se[t_D])\ `p_D' \e(N)\ `mean_control';
	matrix colnames result = `varlist';
	if "`first'" ~= "" {;
		mat results = result;
		mat rownames results =  b_t_D "s.e." "p-value" "Obs" "Control mean";
		};
	else {;
		mat results = results,result;
		};
end;

**** Panel A: borrowing prevalence;
qui onereg loans_rca, first;
foreach var of varlist loans_ngo loans_formal loans_informal loans loans_w {;
	qui onereg `var';
	};
mat list results, format(%8.3g);

**** Panel B: borrowing amounts;
qui onereg loanstot_rca, first;
foreach var of varlist loanstot_ngo loanstot_formal loanstot_informal loanstot loanstot_w {;
	qui onereg `var';
	};
mat list results, format(%8.3g);


***********************************************************************;
**** PROGRAM FOR SPECIFICATION WITH VILLAGE FE, APPENDIX TABLE D.1 ****;
***********************************************************************;
cap program drop onereg;
program define onereg;
	syntax varname [if], [FIRST];
	qui sum `varlist' if t_D_None==1 [w=fwt];
	local mean_control = r(mean);
	qui areg `varlist' time t_D t_D_Both t_D_FP [pw=fwt], cluster(pa) absorb(id_v);
	qui test t_D;
	local p_D = r(p);
	qui test t_D_FP;
	local p_FP = r(p);
	qui test t_D_Both;
	local p_Both = r(p);
	matrix result = _b[t_D]\(_se[t_D])\ `p_D' \_b[t_D_FP]\(_se[t_D_FP])\ `p_FP' \ _b[t_D_Both]\(_se[t_D_Both])\ `p_Both'\e(N)\ `mean_control';
	matrix colnames result = `varlist';
	if "`first'" ~= "" {;
		mat results = result;
		mat rownames results =  b_t_D "s.e." "p-value" b_t_D_FP "s.e." "p-value" b_t_D_Both "s.e." "p-value" "Obs" "Control mean";
		};
	else {;
		mat results = results,result;
		};
end;

**** Panel A: borrowing prevalence;
qui onereg loans_rca, first;
foreach var of varlist loans_ngo loans_formal loans_informal loans loans_w {;
	qui onereg `var';
	};
mat list results, format(%8.3g);

**** Panel B: borrowing amounts;
qui onereg loanstot_rca, first;
foreach var of varlist loanstot_ngo loanstot_formal loanstot_informal loanstot loanstot_w {;
	qui onereg `var';
	};
mat list results, format(%8.3g);

************************************************************************;
**** PROGRAM FOR 2SLS SPECIFICATION, TABLE 2 AND APPENDIX TABLE D.1 ****;
************************************************************************;
cap program drop onereg;
program define onereg;
	syntax varname, [FIRST];
	qui sum `varlist' if time==0 & T==0 [w=fwt];
	local mean_control = r(mean);
	ivreg `varlist' time (t_T t_T_Both t_T_FP = t_D t_D_Both t_D_FP) _FE* [pw=fwt], cluster(pa) first;
	qui test t_T;
	local p_T = r(p);
	qui test t_T_FP;
	local p_FP = r(p);
	qui test t_T_Both;
	local p_Both = r(p);
	matrix result = _b[t_T]\(_se[t_T])\ `p_T' \_b[t_T_FP]\(_se[t_T_FP])\ `p_FP' \ _b[t_T_Both]\(_se[t_T_Both])\ `p_Both';
	matrix colnames result = `varlist';
	if "`first'" ~= "" {;
		mat results = result;
		mat rownames results = b_t_T "s.e." "p-value" b_t_T_FP "s.e." "p-value" b_t_T_Both "s.e." "p-value";
		};
	else {;
		mat results = results,result;
		};
end;

* Estimate the 2SLS for borrowing from ACSI/OCSSC, for Table 2, panels A and B;

* Show the first stage estimates for column 7, Table 2;
areg t_T time t_D t_D_Both t_D_FP [pw=fwt], cluster(pa) absorb(pa);

*** Now estimate all the beta_MF for the Appendix;

qui onereg loans_rca, first;
qui foreach var of varlist loans_ngo loans_formal loans_informal loans loans_w {;
	onereg `var';
	};
mat list results, format(%8.3g);

qui onereg loanstot_rca, first;
qui foreach var of varlist loanstot_ngo loanstot_formal loanstot_informal loanstot loanstot_w {;
	onereg `var';
	};
mat list results, format(%8.3g);


log close;
