# delimit ;
set more off;
drop _all;
matrix drop _all;
capture log close;
set logtype text;
pause on;

**** ESTIMATE RESULTS IN TABLE 4 (INCOME INDICATORS) AS WELL AS IN APPENDIX TABLE D.3;

log using "Table4income", replace;

cap matrix drop result;
cap matrix drop results;

use "data";

***********************************;
**** PROGRAM FOR BASE SPECIFICATION;
***********************************;
cap program drop onereg;
program define onereg;
	syntax varname [if], [FIRST];
	qui sum `varlist' if t_D_None==1 [w=fwt];
	local mean_control = r(mean);
	qui reg `varlist' time t_D t_D_Both t_D_FP _FE* [pw=fwt], cluster(pa);
	qui test t_D;
	local p_D = r(p);
	qui test t_D_FP;
	local p_FP = r(p);
	qui test t_D_Both;
	local p_Both = r(p);
	matrix result = _b[t_D]\(_se[t_D])\ `p_D' \_b[t_D_FP]\(_se[t_D_FP])\ `p_FP' \ _b[t_D_Both]\(_se[t_D_Both])\ `p_Both'\e(N)\ `mean_control';
	matrix colnames result = `varlist';
	if "`first'" ~= "" {;
		mat results = result;
		mat rownames results =  b_t_D "s.e." "p-value" b_t_D_FP "s.e." "p-value" b_t_D_Both "s.e." "p-value" "Obs" "Control mean";
		};
	else {;
		mat results = results,result;
		};
end;

*******************************************************************************;
***** INCOME: TABLE 4 AND TABLE D.3 ("Base estimates");
qui onereg revenues, first;
foreach var of varlist costs net inc_wage inc_trans inc_other {;
	qui onereg `var';
	};
mat list results, format(%8.3g);
*** Now rescale the outcomes for composite measure;
foreach var of varlist revenues costs net inc_wage inc_trans inc_other {;
	sum `var' if t_D_None==1 [w=fwt];
	gen norm_`var' = ( `var' - r(mean) )/r(sd);
};
egen index = rowmean(norm_*);
areg index time t_D t_D_Both t_D_FP [pw=fwt], cluster(pa) absorb(pa);
drop index norm_*;

**************************************************;
**** PROGRAM FOR SPECIFICATION WITH NO FP CONTROLS;
**************************************************;
cap program drop onereg;
program define onereg;
	syntax varname [if], [FIRST];
	qui sum `varlist' if t_D_None==1 [w=fwt];
	local mean_control = r(mean);
	qui reg `varlist' time t_D [pw=fwt], cluster(pa);
	qui test t_D;
	local p_D = r(p);
	matrix result = _b[t_D]\(_se[t_D])\ `p_D' \e(N)\ `mean_control';
	matrix colnames result = `varlist';
	if "`first'" ~= "" {;
		mat results = result;
		mat rownames results =  b_t_D "s.e." "p-value" "Obs" "Control mean";
		};
	else {;
		mat results = results,result;
		};
end;

*** TABLE D.3;
qui onereg revenues, first;
foreach var of varlist costs net inc_wage inc_trans inc_other {;
	qui onereg `var';
	};
mat list results, format(%8.3g);

***********************************;
**** PROGRAM FOR 2SLS SPECIFICATION;
***********************************;
cap program drop onereg;
program define onereg;
	syntax varname, [FIRST];
	qui ivreg `varlist' time (t_T t_T_Both t_T_FP = t_D t_D_Both t_D_FP) _FE* [pw=fwt], cluster(pa);
	qui test t_T;
	local p_T = r(p);
	qui test t_T_FP;
	local p_FP = r(p);
	qui test t_T_Both;
	local p_Both = r(p);
	matrix result = _b[t_T]\(_se[t_T])\ `p_T' \_b[t_T_FP]\(_se[t_T_FP])\ `p_FP' \ _b[t_T_Both]\(_se[t_T_Both])\ `p_Both';
	matrix colnames result = `varlist';
	if "`first'" ~= "" {;
		mat results = result;
		mat rownames results = b_t_T "s.e." "p-value" b_t_T_FP "s.e." "p-value" b_t_T_Both "s.e." "p-value";
		};
	else {;
		mat results = results,result;
		};
end;

*** TABLE D.3;
qui onereg revenues, first;
foreach var of varlist costs net inc_wage inc_trans inc_other {;
	qui onereg `var';
	};
mat list results, format(%8.3g);


log close;
