# delimit ;
set more off;
drop _all;
matrix drop _all;
capture log close;
set logtype text;
pause on;

*** GENERATES RESULTS IN TABLE 6 (LABOR SUPPLY) AND TABLE D.4;

log using "Table6Labor", replace;

cap matrix drop result;
cap matrix drop results;

* Import individual-level time use data;

use "timeuse";

***********************************;
**** PROGRAM FOR BASE SPECIFICATION;
***********************************;
cap program drop onereg;
program define onereg;
	syntax varname [if], [FIRST];
	tempvar touse;
	gen `touse'=0;
	qui replace `touse'=1 `if';
	qui sum `varlist' if t_D_None==1 & `touse' [w=fwt];
	local mean_control = r(mean);
	qui reg `varlist' time t_D t_D_Both t_D_FP _FE* [pw=fwt] if `touse', cluster(pa);
	qui test t_D;
	local p_D = r(p);
	qui test t_D_FP;
	local p_FP = r(p);
	qui test t_D_Both;
	local p_Both = r(p);
	matrix result = _b[t_D]\(_se[t_D])\ `p_D' \_b[t_D_FP]\(_se[t_D_FP])\ `p_FP' \ _b[t_D_Both]\(_se[t_D_Both])\ `p_Both'\e(N)\ `mean_control';
	matrix colnames result = `varlist';
	if "`first'" ~= "" {;
		mat results = result;
		mat rownames results =  b_t_D "s.e." "p-value" b_t_D_FP "s.e." "p-value" b_t_D_Both "s.e." "p-value" "Obs" "Control mean";
		};
	else {;
		mat results = results,result;
		};
end;

*** TABLE D.4 (COMPLETE RESULTS) AND TABLE 5 (BETA_MF ONLY);

***** Now look at adults: beta_MF in Table 5, Panel A, columns 1-3;
qui onereg hw_wk if inrange(age,16,75), first;
qui onereg hw_wk_self if inrange(age,16,75);
qui onereg hw_wk_outside if inrange(age,16,75);
mat list results, format(%8.3g);

***** Now look at women only: beta_MF in Table 5, Panel A, columns 4-5;
qui onereg hw_wk_self if inrange(age,16,75) & sex==2;
qui onereg hw_wk_outside if inrange(age,16,75) & sex==2;
mat list results, format(%8.3g);

***** And finally look at teenagers: beta_MF in Table 5, Panel B, columns 1-5;
qui onereg hw_wk if inrange(age,13,19), first;
qui onereg hw_wk_self if inrange(age,13,19);
qui onereg hw_wk_outside if inrange(age,13,19);
qui onereg hw_wk_self if inrange(age,13,19) & sex==2;
qui onereg hw_wk_outside if inrange(age,13,19) & sex==2;
mat list results, format(%8.3g);

**************************************************************;
**** PROGRAM FOR SPECIFICATION WITH NO FP CONTROLS, TABLE D.4;
**************************************************************;
cap program drop onereg;
program define onereg;
	syntax varname [if], [FIRST];
	tempvar touse;
	gen `touse'=0;
	qui replace `touse'=1 `if';
	qui reg `varlist' time t_D [pw=fwt] if `touse', cluster(pa);
	qui test t_D;
	local p_D = r(p);
	matrix result = _b[t_D]\(_se[t_D])\ `p_D';
	matrix colnames result = `varlist';
	if "`first'" ~= "" {;
		mat results = result;
		mat rownames results =  b_t_D "s.e." "p-value";
		};
	else {;
		mat results = results,result;
		};
end;

***** Now look at adults;
qui onereg hw_wk if inrange(age,16,75), first;
qui onereg hw_wk_self if inrange(age,16,75);
qui onereg hw_wk_outside if inrange(age,16,75);
***** Now look at women only;
qui onereg hw_wk_self if inrange(age,16,75) & sex==2;
qui onereg hw_wk_outside if inrange(age,16,75) & sex==2;
mat list results, format(%8.3g);

***** And finally look at teenagers;
qui onereg hw_wk if inrange(age,13,19), first;
qui onereg hw_wk_self if inrange(age,13,19);
qui onereg hw_wk_outside if inrange(age,13,19);
qui onereg hw_wk_self if inrange(age,13,19) & sex==2;
qui onereg hw_wk_outside if inrange(age,13,19) & sex==2;
mat list results, format(%8.3g);

*** Calculate the average # of hours worked for individuals for whom work was the primary activity, by gender;
sum hw_wk if t_D_None==1 & inrange(age,16,75) & act_work==1 & sex==1 [w=fwt];
sum hw_wk if t_D_None==1 & inrange(age,16,75) & act_work==1 & sex==2 [w=fwt];

************************************************;
**** PROGRAM FOR 2SLS SPECIFICATION, TABLE D.4 ;
************************************************;
cap program drop onereg;
program define onereg;
	syntax varname [if], [FIRST];
	tempvar touse;
	gen `touse'=0;
	qui replace `touse'=1 `if';
	qui ivreg `varlist' time (t_T t_T_Both t_T_FP = t_D t_D_Both t_D_FP) _FE* [pw=fwt] if `touse', cluster(pa);
	qui test t_T;
	local p_T = r(p);
	matrix result = _b[t_T]\(_se[t_T])\ `p_T';
	matrix colnames result = `varlist';
	if "`first'" ~= "" {;
		mat results = result;
		mat rownames results = b_t_T "s.e." "p-value";
		};
	else {;
		mat results = results,result;
		};
end;

***** Now look at adults;
qui onereg hw_wk if inrange(age,16,75), first;
qui onereg hw_wk_self if inrange(age,16,75);
qui onereg hw_wk_outside if inrange(age,16,75);
***** Now look at women only;
qui onereg hw_wk_self if inrange(age,16,75) & sex==2;
qui onereg hw_wk_outside if inrange(age,16,75) & sex==2;
mat list results, format(%8.3g);

***** And finally look at teenagers;
qui onereg hw_wk if inrange(age,13,19), first;
qui onereg hw_wk_self if inrange(age,13,19);
qui onereg hw_wk_outside if inrange(age,13,19);
qui onereg hw_wk_self if inrange(age,13,19) & sex==2;
qui onereg hw_wk_outside if inrange(age,13,19) & sex==2;
mat list results, format(%8.3g);

***** FINALLY CONSTRUCT THE INDEX OF OUTCOMES
* Note that in this regression all outcomes are at the household level (NOT at the individual level),
* so I need first to generate such household-level variables;
* Note also that, for consistency with Banerjee et al. in this same AEJ issue, when a household does not have 
* individuals in the specific age/gender group relevant for the dependent variable we impute a value equal to 
* the group-specific mean in the same experimental arm and in the same time period;
* No information for individuals of age<10;
sum hw* if age<10, sep(0);
* Generate variables specific to each demographic group;
gen hhw_ad = hw_wk if inrange(age,16,75);
gen hhw_self = hw_wk_self if inrange(age,16,75);
gen hhw_out = hw_wk_outside if inrange(age,16,75);
gen hhw_f_self = hw_wk_self if inrange(age,16,75) & (sex==2);
gen hhw_f_out = hw_wk_outside if inrange(age,16,75) & (sex==2);
gen hhw_t = - hw_wk if inrange(age,13,19);
gen hhw_t_self = - hw_wk_self if inrange(age,13,19);
gen hhw_t_out = - hw_wk_outside if inrange(age,13,19);
gen hhw_ft_self = - hw_wk_self if inrange(age,13,19) & (sex==2);
gen hhw_ft_out = - hw_wk_outside if inrange(age,13,19) & (sex==2);
* Generate the means and standard deviations for the standardization from CONTROL AREAS (t_D_None=1) AT ENDLINE, 
* BEFORE the imputation, so the imputed values are not included in the calculations of the mean and sd;
foreach x in _ad _self _out _f_self _f_out _t _t_self _t_out _ft_self _ft_out {;
		qui sum hhw`x' if t_D_None==1 [w=fwt];
		gen m`x' = r(mean);
		gen sd`x' = r(sd);
		};
* Now generate the time/arm-specific means for the imputation;
preserve;
collapse hhw* m_* sd_* [w=fwt], by(time patypen);
renpfix hhw mean;
tempfile temp;
save `temp';
restore;
merge m:1 time patypen using `temp';
* Now do the imputation;
foreach x in _ad _self _out _f_self _f_out _t _t_self _t_out _ft_self _ft_out {;
		replace hhw`x' = mean`x' if mi(hhw`x');
		};
* Generate household-specific means;
collapse hhw* m_* sd_* time t_D* _FE* fwt pa, by(hid);
* Check that we have one observation per household (should be n = 12,675);
count;

*** Now rescale the outcomes for the construction of the composite measures, 
* using the means and standard deviations for the control group at
* endline, estimated BEFORE the imputation;
foreach x in _ad _self _out _f_self _f_out _t _t_self _t_out _ft_self _ft_out {;
	gen norm`x' = ( hhw`x' - m`x' )/sd`x';
};
egen index = rowmean(norm_*);
* Finally estimate the results for Panel C of Table 6;
areg index time t_D t_D_Both t_D_FP [pw=fwt], cluster(pa) absorb(pa);

log close;
