# delimit ;
set more off;
drop _all;
matrix drop _all;
capture log close;
set logtype text;
pause on;

log using "Table7Other", replace;

*** GENERATES RESULTS IN TABLE 7 (CHILD SCHOOLING AND OTHER SOCIO-ECONOMIC INDICATORS) 
* AND ONLINE APPENDIX TABLE D5;

**************************************;
**** PROGRAM FOR BASE SPECIFICATION  *;
**************************************;
cap program drop onereg;
program define onereg;
	syntax varname [if], [FIRST];
	tempvar touse;
	gen `touse'=0;
	qui replace `touse'=1 `if';
	qui sum `varlist' if t_D_None==1 & `touse' [w=fwt];
	local mean_control = r(mean);
	qui reg `varlist' time t_D t_D_Both t_D_FP _FE* [pw=fwt] if `touse', cluster(pa);
	qui test t_D;
	local p_D = r(p);
	qui test t_D_FP;
	local p_FP = r(p);
	qui test t_D_Both;
	local p_Both = r(p);
	matrix result = _b[t_D]\(_se[t_D])\ `p_D' \_b[t_D_FP]\(_se[t_D_FP])\ `p_FP' \ _b[t_D_Both]\(_se[t_D_Both])\ `p_Both'\e(N)\ `mean_control';
	matrix colnames result = `varlist';
	if "`first'" ~= "" {;
		mat results = result;
		mat rownames results =  b_t_D "s.e." "p-value" b_t_D_FP "s.e." "p-value" b_t_D_Both "s.e." "p-value" "Obs" "Control mean";
		};
	else {;
		mat results = results,result;
		};
end;

**************************************;
***** SCHOOLING AND CHILD LABOR  *****;
**************************************;

* Table 7, Panel A and Table D.5;
use "timeuse";
qui onereg ed_attend if inrange(age,6,15), first;
qui onereg hw_wk_self if inrange(age,10,15);
qui onereg hw_wk_outside if inrange(age,10,15);
qui onereg act_hswk if inrange(age,10,15) & sex==2;
qui onereg ed_attend if inrange(age,16,20);
mat list results, format(%8.3g);

***** Now construct the household-level variables to be used later in the Index of Dependent Variables;
* Note that # hours worked and prevalence of housework as primary activity are treated as "bad" and hence
* their sign is inverted for the construction of the index;
gen hh_ed_6_15 = ed_attend*inrange(age,6,15);
gen hh_w_self = - hw_wk_self*inrange(age,10,15);
gen hh_w_out = - hw_wk_outside*inrange(age,10,15);
gen hh_hswk = - act_hswk*inrange(age,10,15)*(sex==2);
gen hh_ed_16_20 = ed_attend*inrange(age,16,20);
* Generate the means and standard deviations for the standardization, before the imputation, so the imputed
* values are not included in the calculations. These are estimated from CONTROL AREAS (t_D_None=1) AT ENDLINE;
foreach x in _ed_6_15 _w_self _w_out _hswk _ed_16_20 {;
		qui sum hh`x' if t_D_None==1 [w=fwt];
		gen m`x' = r(mean);
		gen sd`x' = r(sd);
		};
* Now generate the time/arm-specific means for the imputation;
preserve;
collapse hh* m_* sd_* [w=fwt], by(time patypen);
renpfix hh mean;
tempfile temp;
save `temp';
restore;
merge m:1 time patypen using `temp';
* Now do the imputation;
foreach x in _ed_6_15 _w_self _w_out _hswk _ed_16_20 {;
		replace hh`x' = mean`x' if mi(hh`x');
		};
collapse hh* m_* sd_* time t_D* _FE* fwt pa patypen, by(hid);
* Check that we have one observation per household (should be n=12,675);
count;
*** Now rescale the outcomes for composite measure, using the means and standard deviations for the control group at
* endline, estimated BEFORE the imputation;
foreach x in _ed_6_15 _w_self _w_out _hswk _ed_16_20 {;
	gen norm`x' = ( hh`x' - m`x' )/sd`x';
};
keep hid norm* time patypen;
save `temp', replace;


**************************************;
***** WOMEN'S EMPOWERMENT MEASURES  **;
**************************************;

use "empowerment", clear;

* Table 7, Panel B, columns 1-2 and Table D.5;
qui onereg dec_self, first;
qui onereg dec_self_ec;

***** Now construct the household-level variables to be used later in the Index of Dependent Variables;
* Merge the previously created standardized variables;
merge 1:1 hid using `temp';
drop _merge;
* Generate the means and standard deviations for the standardization, before the imputation, so the imputed
* values are not included in the calculations. These are estimated from CONTROL AREAS (t_D_None=1) AT ENDLINE;
foreach x in _self _self_ec {;
		qui sum dec`x' if t_D_None==1 [w=fwt];
		gen m`x' = r(mean);
		gen sd`x' = r(sd);
		};
* Now generate the time/arm-specific means for the imputation;
preserve;
collapse dec_* m_* sd_* [w=fwt], by(time patypen);
renpfix dec mean;
tempfile temp1;
save `temp1';
restore;
merge m:1 time patypen using `temp1';
* Now do the imputation;
foreach x in _self _self_ec {;
		replace dec`x' = mean`x' if mi(dec`x');
		};
collapse dec_* m_* sd_* norm* time t_D* _FE* fwt pa, by(hid);
* Check that we have one observation per household (should be n = 12,675);
count;
*** Now rescale the outcomes for composite measure, using the means and standard deviations for the control group at
* endline, estimated BEFORE the imputation;
foreach x in _self _self_ec {;
	gen norm`x' = ( dec`x' - m`x' )/sd`x';
};
keep hid norm*;
save `temp', replace;



**************************************;
*****  ASSETS, HEALTH, FOOD      *****;
**************************************;

use "data", clear;

* Table 7, Panel B, columns 3 and 5 and Table D.5;
qui onereg assets;
qui onereg nofood;
mat list results, format(%8.3g);

*** Now rescale the outcomes for the Index of Dependent Variables, after changing sign of "nofood" variable;
replace nofood = - nofood;
foreach var of varlist assets nofood {;
	qui sum `var' if t_D_None==1 [w=fwt];
	gen norm_`var' = ( `var' - r(mean) )/r(sd);
};

* Someone seriously ill last 3 years;
* Table 7, Panel B, columns 4 and Table D.5;
* NOTE: This outcome will be excluded from the index because no data were collected at baseline;   
qui sum sick if t_D_None==1 [w=fwt];
gen amhara = region==1;
reg sick D D_Both D_FP amhara [pw=fwt], cluster(pa);

* Merge the previously created standardized variables;
merge 1:1 hid using `temp';
sum norm*, sep(0);
egen index = rowmean(norm_*);
* Finally estimate the results for Panel C of Table 7;
areg index time t_D t_D_Both t_D_FP [pw=fwt], cluster(pa) absorb(pa);



**************************************************;
**** PROGRAM FOR SPECIFICATION WITH NO FP CONTROLS;
**************************************************;

* Table D.5;

cap program drop onereg;
program define onereg;
	syntax varname [if], [FIRST];
	tempvar touse;
	gen `touse'=0;
	qui replace `touse'=1 `if';
	qui reg `varlist' time t_D [pw=fwt] if `touse', cluster(pa);
	qui test t_D;
	local p_D = r(p);
	matrix result = _b[t_D]\(_se[t_D])\ `p_D';
	matrix colnames result = `varlist';
	if "`first'" ~= "" {;
		mat results = result;
		mat rownames results =  b_t_D "s.e." "p-value";
		};
	else {;
		mat results = results,result;
		};
end;

**************************************;
***** SCHOOLING AND CHILD LABOR  *****;
**************************************;

use "timeuse", clear;
qui onereg ed_attend if inrange(age,6,15), first;
qui onereg hw_wk_self if inrange(age,10,15);
qui onereg hw_wk_outside if inrange(age,10,15);
qui onereg act_hswk if inrange(age,10,15) & sex==2;
qui onereg ed_attend if inrange(age,16,20);
mat list results, format(%8.3g);

**************************************;
***** WOMEN'S EMPOWERMENT MEASURES  **;
**************************************;

use "empowerment", clear;

qui onereg dec_self, first;
qui onereg dec_self_ec;

**************************************;
*****  ASSETS, HEALTH, FOOD      *****;
**************************************;

use "data", clear;
qui onereg assets;
qui onereg nofood;
mat list results, format(%8.3g);

* Someone seriously ill last 3 years;
qui sum sick if t_D_None==1 [w=fwt];
gen amhara = region==1;
reg sick D amhara [pw=fwt], cluster(pa);

***********************************;
**** PROGRAM FOR 2SLS SPECIFICATION;
***********************************;

* Table D.5;

cap program drop onereg;
program define onereg;
	syntax varname [if], [FIRST];
	tempvar touse;
	gen `touse'=0;
	qui replace `touse'=1 `if';
	qui ivreg `varlist' time (t_T t_T_Both t_T_FP = t_D t_D_Both t_D_FP) _FE* [pw=fwt] if `touse', cluster(pa);
	qui test t_T;
	local p_T = r(p);
	matrix result = _b[t_T]\(_se[t_T])\ `p_T';
	matrix colnames result = `varlist';
	if "`first'" ~= "" {;
		mat results = result;
		mat rownames results = b_t_T "s.e." "p-value";
		};
	else {;
		mat results = results,result;
		};
end;

**************************************;
***** SCHOOLING AND CHILD LABOR  *****;
**************************************;

use "timeuse", clear;
qui onereg ed_attend if inrange(age,6,15), first;
qui onereg hw_wk_self if inrange(age,10,15);
qui onereg hw_wk_outside if inrange(age,10,15);
qui onereg act_hswk if inrange(age,10,15) & sex==2;
qui onereg ed_attend if inrange(age,16,20);
mat list results, format(%8.3g);

**************************************;
***** WOMEN'S EMPOWERMENT MEASURES  **;
**************************************;

use "empowerment", clear;

qui onereg dec_self, first;
qui onereg dec_self_ec;

**************************************;
*****  ASSETS, HEALTH, FOOD      *****;
**************************************;

use "data", clear;
qui onereg assets;
qui onereg nofood;
mat list results, format(%8.3g);

* Someone seriously ill last 3 years;
qui sum sick if t_D_None==1 [w=fwt];
gen amhara = region==1;
ivreg sick (T T_Both T_FP = D D_Both D_FP) amhara [pw=fwt], cluster(pa);

    
log close;
