# graphics for all parent mean observations
# Rachael Meager
# First Version: Sept 2015

### Notes ###

# Analysis needs to be done before you can run this, obviously

#### 1. Preliminaries and Data Intake ####
rm(list = ls())

chooseCRANmirror(ind=90)
installer <- FALSE
if (installer==TRUE) {
  install.packages('foreign')
  install.packages('Hmisc')
  install.packages('xtable')
  install.packages('coda')
  install.packages('stargazer')
  install.packages('sandwich')
  install.packages('multiwayvcov')
  install.packages('parallel')
  install.packages("ggplot2")
  install.packages("gridExtra")
  install.packages('coda')
}

library(multiwayvcov)
library(sandwich)
library(stargazer)
library(foreign)
library(Hmisc)
library(xtable)
library(coda)
library(parallel)
library(ggplot2)
library(gridExtra)
library(coda)
library(dummies)
library(zoo)
library(Matrix)

library(dplyr)



# Load data
rm(list = ls())



load("microcredit_joint_model_profit_output.RData")
ols_pooled_profit <- ols_pooled
ols_pooled_profit_cluster_sd <- summary(ols_pooled)$coef[2,2]
rm(ols_pooled, ols_pooled_cluster_sd)
load("microcredit_joint_model_expenditures_output.RData")
ols_pooled_expenditures <- ols_pooled
ols_pooled_expenditures_cluster_sd <- summary(ols_pooled)$coef[2,2]
rm(ols_pooled, ols_pooled_cluster_sd)
load("microcredit_joint_model_revenues_output.RData")
ols_pooled_revenues <- ols_pooled
ols_pooled_revenues_cluster_sd <- summary(ols_pooled)$coef[2,2]
rm(ols_pooled, ols_pooled_cluster_sd)
load("microcredit_joint_model_consumption_output.RData")
ols_pooled_consumption <- ols_pooled
ols_pooled_consumption_cluster_sd <- summary(ols_pooled)$coef[2,2]
rm(ols_pooled, ols_pooled_cluster_sd)
load("microcredit_joint_model_consumerdurables_output.RData")
ols_pooled_consumerdurables <- ols_pooled
ols_pooled_consumerdurables_cluster_sd <- summary(ols_pooled)$coef[2,2]
rm(ols_pooled, ols_pooled_cluster_sd)
load("microcredit_joint_model_temptation_output.RData")
ols_pooled_temptation <- ols_pooled
ols_pooled_temptation_cluster_sd <- summary(ols_pooled)$coef[2,2]
rm(ols_pooled, ols_pooled_cluster_sd)


tau_name <- c("mutau[2]")
outcome_variable <- c("Profit", "Expenditure", "Revenue", "Consumption", "Consumer Durables", "Temptation Goods")
textable_tau_set <- rbind(textable_profit_joint[tau_name,],
                      textable_expenditures_joint[tau_name,],
                      textable_revenues_joint[tau_name,],
                      textable_consumption_joint[tau_name,],
                      textable_consumerdurables_joint[tau_name,],
                      textable_temptation_joint[tau_name,])


tau_k_df_profit  <- data.frame(outcome_variable, textable_tau_set)

tau_k_plot <- ggplot(data=tau_k_df_profit, aes(x=outcome_variable, y=mean, colour=outcome_variable, fill = outcome_variable), alpha= 0.2, width=.2) + coord_cartesian(ylim = c(-30,30)) 
tau_k_plot_fancy <- tau_k_plot +  geom_boxplot(aes(ymax=X97.5., ymin=X2.5., lower =X25. , upper = X75., middle = mean,  alpha= 0.2, width=.2), stat=('identity'))


ols_tau_means <- c(ols_pooled_profit$coef[2],
                   ols_pooled_expenditures$coef[2],
                   ols_pooled_revenues$coef[2],
                   ols_pooled_consumption$coef[2],
                   ols_pooled_consumerdurables$coef[2],
                   ols_pooled_temptation$coef[2])
                   
                   
                   
ols_tau_sd_robust <- c(ols_pooled_profit_cluster_sd,
                       ols_pooled_expenditures_cluster_sd,
                       ols_pooled_revenues_cluster_sd,
                       ols_pooled_consumption_cluster_sd,
                       ols_pooled_consumerdurables_cluster_sd,
                       ols_pooled_temptation_cluster_sd)


ols_output_df <- data.frame(outcome_variable, ols_tau_means, ols_tau_sd_robust)

ols_plot <- ggplot(data=ols_output_df, aes(x=outcome_variable, y=ols_tau_means, colour=outcome_variable)) 

ols_plot + geom_boxplot(aes(ymax=ols_tau_means+1.96*ols_tau_sd_robust, ymin=ols_tau_means-1.96*ols_tau_sd_robust, lower = ols_tau_means + ols_tau_sd_robust*qnorm(0.25, mean=0, sd=1), upper = ols_tau_means + ols_tau_sd_robust*qnorm(0.75, mean=0, sd=1), middle = ols_tau_means), stat=('identity'))

estimate_type <- c(rep("BHM Posterior",length(outcome_variable)), rep("Pooled OLS",length(outcome_variable)))
estimate_outcome_variable <- rep(outcome_variable,2)
estimate_means <- c(tau_k_df_profit$mean, ols_tau_means)
estimate_X2.5. <- c(tau_k_df_profit$X2.5., ols_tau_means-1.96*ols_tau_sd_robust)
estimate_X97.5. <- c(tau_k_df_profit$X97.5., ols_tau_means+1.96*ols_tau_sd_robust)
estimate_X25. <- c(tau_k_df_profit$X25., ols_tau_means + ols_tau_sd_robust*qnorm(0.25, mean=0, sd=1))
estimate_X75. <- c(tau_k_df_profit$X75., ols_tau_means + ols_tau_sd_robust*qnorm(0.75, mean=0, sd=1))

estimates_df <- data.frame(estimate_type, estimate_outcome_variable, estimate_means, estimate_X2.5., estimate_X97.5., estimate_X25., estimate_X75.)

bhm_ols_plot <- ggplot(data=estimates_df, aes(x=factor(estimate_outcome_variable), y=estimate_means, color = factor(estimate_type), fill  = factor(estimate_type), width=.4,  alpha= 0.25))

bhm_ols_fancy_plot <- bhm_ols_plot +  geom_boxplot(aes(ymax=estimate_X97.5., ymin=estimate_X2.5., lower=estimate_X25. , upper = estimate_X75., middle = estimate_means), stat=('identity'))


pdf(file="tau_posteriors_all_outcome_variables.pdf",width = 10, height = 5)
bhm_ols_fancy_plot + coord_flip(ylim=c(-30,40))  +ylab("Posterior mean, 50% interval (box), and 95% interval (line) \n for each Treatment Effect (USD PPP per 2 weeks)") + xlab("") + theme(legend.title=element_blank()) + scale_alpha_identity() + theme(text = element_text(size=17,color="black"), axis.text.y = element_text(size=17,color="grey40"),axis.text.x = element_text(size=17,color="grey40"))
dev.off()

### Now we do the parent distributions ###

tau_name <- c("mutau[2]")
outcome_variable <- c("Profit", "Expenditure", "Revenue", "Consumption", "Consumer Durables", "Temptation Goods")

tau_mean_profit <- textable_profit_joint["mutau[2]",1]
tau_sd_profit <- sqrt(textable_profit_joint["sigma_mutau[2,2]",1])
tau_mean_expenditures <- textable_expenditures_joint["mutau[2]",1]
tau_sd_expenditures <- sqrt(textable_expenditures_joint["sigma_mutau[2,2]",1])
tau_mean_revenues <- textable_revenues_joint["mutau[2]",1]
tau_sd_revenues <- sqrt(textable_revenues_joint["sigma_mutau[2,2]",1])
tau_mean_consumption <- textable_consumption_joint["mutau[2]",1]
tau_sd_consumption <- sqrt(textable_consumption_joint["sigma_mutau[2,2]",1])
tau_mean_consumerdurables <- textable_consumerdurables_joint["mutau[2]",1]
tau_sd_consumerdurables <- sqrt(textable_consumerdurables_joint["sigma_mutau[2,2]",1])
tau_mean_temptation <- textable_temptation_joint["mutau[2]",1]
tau_sd_temptation <- sqrt(textable_temptation_joint["sigma_mutau[2,2]",1])


textable_tau_set <- 
estimate_parent_means <- c(tau_mean)
estimate_parent_X2.5. <- c(tau_mean-1.96*tau_sd)
estimate_parent_X97.5. <- c(tau_mean+1.96*tau_sd)
estimate_parent_X25. <- c(tau_mean+qnorm(0.25, mean=0, sd=1)*tau_sd)
estimate_parent_X75. <- c(tau_mean+qnorm(0.75, mean=0, sd=1)*tau_sd


tau_k_df_profit  <- data.frame(outcome_variable, textable_tau_set)

tau_k_plot <- ggplot(data=tau_k_df_profit, aes(x=outcome_variable, y=mean, colour=outcome_variable, fill = outcome_variable), alpha= 0.2, width=.2) + coord_cartesian(ylim = c(-30,30)) 
tau_k_plot_fancy <- tau_k_plot +  geom_boxplot(aes(ymax=X97.5., ymin=X2.5., lower =X25. , upper = X75., middle = mean,  alpha= 0.2, width=.2), stat=('identity'))


ols_tau_means <- c(ols_pooled_profit$coef[2],
                   ols_pooled_expenditures$coef[2],
                   ols_pooled_revenues$coef[2],
                   ols_pooled_consumption$coef[2],
                   ols_pooled_consumerdurables$coef[2],
                   ols_pooled_temptation$coef[2])



ols_tau_sd_robust <- c(ols_pooled_profit_cluster_sd,
                       ols_pooled_expenditures_cluster_sd,
                       ols_pooled_revenues_cluster_sd,
                       ols_pooled_consumption_cluster_sd,
                       ols_pooled_consumerdurables_cluster_sd,
                       ols_pooled_temptation_cluster_sd)


ols_output_df <- data.frame(outcome_variable, ols_tau_means, ols_tau_sd_robust)

ols_plot <- ggplot(data=ols_output_df, aes(x=outcome_variable, y=ols_tau_means, colour=outcome_variable)) 

ols_plot + geom_boxplot(aes(ymax=ols_tau_means+1.96*ols_tau_sd_robust, ymin=ols_tau_means-1.96*ols_tau_sd_robust, lower = ols_tau_means + ols_tau_sd_robust*qnorm(0.25, mean=0, sd=1), upper = ols_tau_means + ols_tau_sd_robust*qnorm(0.75, mean=0, sd=1), middle = ols_tau_means), stat=('identity'))

estimate_type <- c(rep("BHM Posterior",length(outcome_variable)), rep("Pooled OLS",length(outcome_variable)))
estimate_outcome_variable <- rep(outcome_variable,2)
estimate_means <- c(tau_k_df_profit$mean, ols_tau_means)
estimate_X2.5. <- c(tau_k_df_profit$X2.5., ols_tau_means-1.96*ols_tau_sd_robust)
estimate_X97.5. <- c(tau_k_df_profit$X97.5., ols_tau_means+1.96*ols_tau_sd_robust)
estimate_X25. <- c(tau_k_df_profit$X25., ols_tau_means + ols_tau_sd_robust*qnorm(0.25, mean=0, sd=1))
estimate_X75. <- c(tau_k_df_profit$X75., ols_tau_means + ols_tau_sd_robust*qnorm(0.75, mean=0, sd=1))

estimates_df <- data.frame(estimate_type, estimate_outcome_variable, estimate_means, estimate_X2.5., estimate_X97.5., estimate_X25., estimate_X75.)

bhm_ols_plot <- ggplot(data=estimates_df, aes(x=factor(estimate_outcome_variable), y=estimate_means, color = factor(estimate_type), fill  = factor(estimate_type), width=.4,  alpha= 0.25))

bhm_ols_fancy_plot <- bhm_ols_plot +  geom_boxplot(aes(ymax=estimate_X97.5., ymin=estimate_X2.5., lower=estimate_X25. , upper = estimate_X75., middle = estimate_means), stat=('identity'))


pdf(file="tau_posteriors_all_outcome_variables.pdf",width = 10, height = 5)
bhm_ols_fancy_plot + coord_flip(ylim=c(-30,40))  +ylab("Posterior mean, 50% interval (box), and 95% interval (line) \n for each Treatment Effect (USD PPP per 2 weeks)") + xlab("") + theme(legend.title=element_blank()) + scale_alpha_identity() + theme(text = element_text(size=17,color="black"), axis.text.y = element_text(size=17,color="grey40"),axis.text.x = element_text(size=17,color="grey40"))
dev.off()
