# FULL BASIC ANALYSIS FOR THE MICROCREDIT BAYES PAPER IN 1 PLACE :
# This one is for consumerdurables but serves as the general template
# Rachael Meager
# First Version: August 2015

### Notes ###

# Data needs to be taken in and prepped before this code is run
# Replication file must be run before this code is run
# RStan must be installed and functional before running this code.


#### Preliminaries ####
rm(list = ls())

chooseCRANmirror(ind=90)
installer <- FALSE
if (installer==TRUE) {
  install.packages('foreign')
  install.packages('Hmisc')
  install.packages('xtable')
  install.packages('coda')
  install.packages('stargazer')
  install.packages('sandwich')
  install.packages('multiwayvcov')
  install.packages('parallel')
  install.packages("ggplot2")
  install.packages("gridExtra")
  install.packages('coda')
}

library(multiwayvcov)
library(sandwich)
library(stargazer)
library(foreign)
library(Hmisc)
library(xtable)
library(coda)
library(parallel)
library(ggplot2)
library(gridExtra)
library(coda)
library(dummies)
library(zoo)
library(Matrix)

library(dplyr)

# Call RStan
library(rstan)




#### Rubin model on reported and replicated coefficients #### 

# Load data
rm(list = ls())
load("microcredit_project_data_with_replication_consumerdurables.RData")
if( exists("USD_convert_to_2009_dollars")=="FALSE"){stop("OLD DATA FILE LOADED! RELOAD CORRECT FILE!")}


# Set the model file and Stan parameters

model_file <- file.path('rubin-model-code.stan')
model <- stan_model(model_file)

# some knobs we can tweak
chains <- 4
iters <- 20000
control <- list(adapt_t0 = 10,       # default = 10
                stepsize = 1,        # default = 1
                max_treedepth = 6)   # default = 10
seed <- 42



### original studies reported coefficients ###

reported_coefs_exist <- FALSE
if(reported_coefs_exist == TRUE) {
reported_coefs_data_consumerdurables <- list(K = length(standardised_reported_coefficients_consumerdurables), 
                            tau_hat_k = standardised_reported_coefficients_consumerdurables,
                            se_k = standardised_reported_coefficients_consumerdurables_sds)


sflist <-
  mclapply(1:chains, mc.cores = chains,
           function(i) sampling(model, data = reported_coefs_data_consumerdurables, seed = seed,
                                chains = 1, chain_id = i, # refresh = -1,
                                iter = iters, control = control))
stan_fit_reported_coefs_consumerdurables <- sflist2stanfit(sflist)

# This will display the posterior inference directly
print(stan_fit_reported_coefs_consumerdurables)

#now latex it
summary_reported_coefs_consumerdurables <- summary(stan_fit_reported_coefs_consumerdurables )
textable_reported_coefs_consumerdurables <- xtable(summary_reported_coefs_consumerdurables$summary)
print.xtable(textable_reported_coefs_consumerdurables)

#now save the table for easy access
sink("textable_stan_fit_consumerdurables_rubin_model_reported_coefs.txt")
print.xtable(textable_reported_coefs_consumerdurables)
sink()

#codafit it
codafit_stan_fit_reported_coefs_consumerdurables <- stan2coda(stan_fit_reported_coefs_consumerdurables)
summary(codafit_stan_fit_reported_coefs_consumerdurables)
#plot(codafit)
codafitmatrix_stan_fit_reported_coefs_consumerdurables <- as.matrix(codafit_stan_fit_reported_coefs_consumerdurables)

}

### RM ols coefficients "best match" set of regressions ###


ols_best_match_coefs_data_consumerdurables <- list(K = length(standardised_ols_best_match_output_consumerdurables_coefficients), 
                                   tau_hat_k = standardised_ols_best_match_output_consumerdurables_coefficients,
                                   se_k = standardised_ols_best_match_output_consumerdurables_coefficients_sds)


sflist <-
  mclapply(1:chains, mc.cores = chains,
           function(i) sampling(model, data = ols_best_match_coefs_data_consumerdurables, seed = seed,
                                chains = 1, chain_id = i, # refresh = -1,
                                iter = iters, control = control))
stan_fit_ols_best_match_coefs_consumerdurables <- sflist2stanfit(sflist)



#now latex it
summary_ols_best_match_coefs_consumerdurables <- summary(stan_fit_ols_best_match_coefs_consumerdurables )
textable_ols_best_match_coefs_consumerdurables <- xtable(summary_ols_best_match_coefs_consumerdurables$summary)
print.xtable(textable_ols_best_match_coefs_consumerdurables)

#now save the table for easy access
sink("textable_stan_fit_consumerdurables_rubin_model_best_match.txt")
print.xtable(textable_ols_best_match_coefs_consumerdurables)
sink()

#codafit it
codafit_stan_fit_ols_best_match_coefs_consumerdurables <- stan2coda(stan_fit_ols_best_match_coefs_consumerdurables)
summary(codafit_stan_fit_ols_best_match_coefs_consumerdurables)
#plot(codafit)
codafitmatrix_stan_fit_ols_best_match_coefs_consumerdurables <- as.matrix(codafit_stan_fit_ols_best_match_coefs_consumerdurables)


save.image(file = "microcredit_rubin_model_consumerdurables_output.RData")

#### Reduced Data Model: Independent Mu and Tau ####
# Load data
rm(list = ls())
load("microcredit_project_data_with_replication_consumerdurables.RData")
if( exists("USD_convert_to_2009_dollars")=="FALSE"){stop("OLD DATA FILE LOADED! RELOAD CORRECT FILE!")}


model_file <- file.path('microcredit-independent-model-reduced-data.stan') 

model <- stan_model(model_file)
consumerdurables_data <- list(K = length(standardised_ols_best_match_output_consumerdurables_coefficients),
                    
                    mu_k_hat = standardised_ols_best_match_output_consumerdurables_means, 
                    tau_k_hat = standardised_ols_best_match_output_consumerdurables_coefficients,
                    se_mu_k = standardised_ols_best_match_output_consumerdurables_means_sds, 
                    se_tau_k = standardised_ols_best_match_output_consumerdurables_coefficients_sds)




# some knobs we can tweak
chains <- 4
iters <- 20000
control <- list(adapt_t0 = 10,       # default = 10
                stepsize = 1,        # default = 1
                max_treedepth = 6)   # default = 10
seed <- 42

# Run HMC

sflist <-
  mclapply(1:chains, mc.cores = chains,
           function(i) sampling(model, data = consumerdurables_data, seed = seed,
                                chains = 1, chain_id = i, # refresh = -1,
                                iter = iters, control = control))
stan_fit_consumerdurables_independent_reduced <- sflist2stanfit(sflist)

# This will display the posterior inference directly
print(stan_fit_consumerdurables_independent_reduced)

#now latex it
output_consumerdurables_independent_reduced <- summary(stan_fit_consumerdurables_independent_reduced)
textable_consumerdurables_independent_reduced <- xtable(output_consumerdurables_independent_reduced$summary)
print.xtable(textable_consumerdurables_independent_reduced)

#now save the table for easy access
sink("textable_consumerdurables_flat_het_mutau_point_estimates_independent.txt")
print.xtable(textable_consumerdurables_independent_reduced)
sink()

#now save every object we created (saved here just in case)

save.image(file = "microcredit_optimised_independent_dist_model_output.RData")


# codafit object! 
codafit_stan_fit_consumerdurables_independent_reduced <- stan2coda(stan_fit_consumerdurables_independent_reduced)
summary(codafit_stan_fit_consumerdurables_independent_reduced)
#plot(codafit)
codafitmatrix_stan_fit_consumerdurables_independent_reduced <- as.matrix(codafit_stan_fit_consumerdurables_independent_reduced)




#now save every object we created (saved here just in case)

save.image(file = "microcredit_optimised_independent_dist_model_consumerdurables_output.RData")



#### Reduced Data Model: Jointly distributed Mu and Tau #### 

# Load data
rm(list = ls())
load("microcredit_project_data_with_replication_consumerdurables.RData")
if( exists("USD_convert_to_2009_dollars")=="FALSE"){stop("OLD DATA FILE LOADED! RELOAD CORRECT FILE!")}


### Impact of Microcredit on consumerdurables with Heteroskedasticity ###
P <- 2


model_file <- file.path('basic-microcredit-uninformative-ss-point-estimates.stan') 

model <- stan_model(model_file)
consumerdurables_data <- list(K = length(standardised_ols_best_match_output_consumerdurables_coefficients),
                    P = P,    
                    mu_k_hat = standardised_ols_best_match_output_consumerdurables_means, 
                    tau_k_hat = standardised_ols_best_match_output_consumerdurables_coefficients,
                    se_mu_k = standardised_ols_best_match_output_consumerdurables_means_sds, 
                    se_tau_k = standardised_ols_best_match_output_consumerdurables_coefficients_sds, 
                    mutau_prior_sigma = (1000^2)*diag(P),
                    mutau_prior_mean = rep(0,P))



# some knobs we can tweak
chains <- 4
iters <- 20000
control <- list(adapt_t0 = 10,       # default = 10
                stepsize = 1,        # default = 1
                max_treedepth = 6)   # default = 10
seed <- 42

# Run HMC

sflist <-
  mclapply(1:chains, mc.cores = chains,
           function(i) sampling(model, data = consumerdurables_data, seed = seed,
                                chains = 1, chain_id = i, # refresh = -1,
                                iter = iters, control = control))
stan_fit_consumerdurables_joint_reduced <- sflist2stanfit(sflist)

# This will display the posterior inference directly
print(stan_fit_consumerdurables_joint_reduced)

#now latex it
output_consumerdurables_joint_reduced <- summary(stan_fit_consumerdurables_joint_reduced)
textable_consumerdurables_joint_reduced <- xtable(output_consumerdurables_joint_reduced$summary)
print.xtable(textable_consumerdurables_joint_reduced)

#now save the table for easy access
sink("textable_consumerdurables_flat_het_mutau_point_estimates.txt")
print.xtable(textable_consumerdurables_joint_reduced)
sink()

#now save every object we created (saved here just in case)


# codafit object! 
codafit_stan_fit_consumerdurables_joint_reduced <- stan2coda(stan_fit_consumerdurables_joint_reduced)
summary(codafit_stan_fit_consumerdurables_joint_reduced)
#plot(codafit)
codafitmatrix_stan_fit_consumerdurables_joint_reduced <- as.matrix(codafit_stan_fit_consumerdurables_joint_reduced)



save.image(file = "microcredit_joint_model_reduced_data_consumerdurables.RData")






#### Full Data Model:  Independent Mu and Tau ####

# Load data
rm(list = ls())
load("microcredit_project_data_with_replication_consumerdurables.RData")
if( exists("USD_convert_to_2009_dollars")=="FALSE"){stop("OLD DATA FILE LOADED! RELOAD CORRECT FILE!")}

### VARIABLE STACKING PROCEDURE FOR RSTAN INTAKE ###

# This preps data so that the model can be written efficiently - it's not necessary but it's the best way I know to code it in STAN
site <- c( attanasio_indicator, augsberg_indicator,banerjee_indicator, crepon_indicator)
site <- site-1
consumerdurables <- c( attanasio_consumerdurables, augsberg_consumerdurables,banerjee_consumerdurables, crepon_consumerdurables)
treatment <- c( attanasio_treatment, augsberg_treatment,banerjee_treatment, crepon_treatment)

# Now we have to standardise any variables which are in local currency units to USD PPP per fortnight in 2009 dollars


expanded_standardiser_USD_PPP_per_fortnight <- c( 
                                                  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[1],length(attanasio_indicator)),
                                                  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[2],length(augsberg_indicator)),
                                                  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[3],length(banerjee_indicator)),
                                                  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[4],length(crepon_indicator)))

consumerdurables <- consumerdurables*expanded_standardiser_USD_PPP_per_fortnight

# bind everything into a data frame
data <- data.frame(site, consumerdurables, treatment)

# We gotta remove the NA values
data <- data[complete.cases(data),]



# Set the model file and Stan parameters

model_file <- file.path('microcredit-independent-model-ss.stan')
model <- stan_model(model_file)

# some knobs we can tweak
chains <- 4
iters <- 20000
control <- list(adapt_t0 = 10,       # default = 10
                stepsize = 1,        # default = 1
                max_treedepth = 6)   # default = 10
seed <- 40 # it was 42 before, i'm testing for something



### organise data ###

P <- 2
consumerdurables_data <- list(K = length(unique(data$site)),
                    N = length(data$treatment),
                    P = P,
                    site = data$site,
                    y = data$consumerdurables,
                    ITT = data$treatment)


sflist <-
  mclapply(1:chains, mc.cores = chains,
           function(i) sampling(model, data = consumerdurables_data, seed = seed,
                                chains = 1, chain_id = i, # refresh = -1,
                                iter = iters, control = control))
stan_fit_consumerdurables_independent <- sflist2stanfit(sflist)

# This will display the posterior inference directly
print(stan_fit_consumerdurables_independent)

#now latex it
summary_stan_fit_consumerdurables_independent <- summary(stan_fit_consumerdurables_independent)
textable_consumerdurables_independent <- xtable(summary_stan_fit_consumerdurables_independent$summary)
print.xtable(textable_consumerdurables_independent)

#now save the table for easy access
sink("textable_stan_fit_consumerdurables_independent.txt")
print.xtable(textable_consumerdurables_independent)
sink()

# now codafit it


codafit_consumerdurables_independent <- stan2coda(stan_fit_consumerdurables_independent)
summary(codafit_consumerdurables_independent)
codafitmatrix_consumerdurables_independent <- as.matrix(codafit_consumerdurables_independent)

save.image(file = "microcredit_independent_model_consumerdurables_output.RData")





#### Full Data Model: Allows covariation between Mu and Tau ####
# Load data
rm(list = ls())
load("microcredit_project_data_with_replication_consumerdurables.RData")
if( exists("USD_convert_to_2009_dollars")=="FALSE"){stop("OLD DATA FILE LOADED! RELOAD CORRECT FILE!")}

# This preps data so that the model can be written efficiently - it's not necessary but it's the best way I know to code it in STAN
site <- c( attanasio_indicator, augsberg_indicator,banerjee_indicator, crepon_indicator)
site <- site - 1
consumerdurables <- c( attanasio_consumerdurables, augsberg_consumerdurables,banerjee_consumerdurables, crepon_consumerdurables)
treatment <- c( attanasio_treatment, augsberg_treatment,banerjee_treatment, crepon_treatment)

# Now we have to standardise any variables which are in local currency units to USD PPP per fortnight in 2009 dollars


expanded_standardiser_USD_PPP_per_fortnight <- c( 
  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[1],length(attanasio_indicator)),
  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[2],length(augsberg_indicator)),
  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[3],length(banerjee_indicator)),
  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[4],length(crepon_indicator)))

consumerdurables <- consumerdurables*expanded_standardiser_USD_PPP_per_fortnight

# bind everything into a data frame
data <- data.frame(site, consumerdurables, treatment)

# We gotta remove the NA values
data <- data[complete.cases(data),]




P <- 2
model_file <- file.path('basic-microcredit-uninformative-ss.stan') 
model <- stan_model(model_file)

consumerdurables_data <- list(K = length(unique(data$site)),
                   N = length(data$treatment),
                   P = P,
                   site = data$site,
                   y = data$consumerdurables,
                   ITT = data$treatment,
                   mutau_prior_sigma = (1000^2)*diag(P),
                   mutau_prior_mean = rep(0,P))

# some knobs we can tweak
chains <- 4
iters <- 20000
control <- list(adapt_t0 = 10,       # default = 10
                stepsize = 1,        # default = 1
                max_treedepth = 6)   # default = 10
seed <- 42


sflist <-
  mclapply(1:chains, mc.cores = chains,
           function(i) sampling(model, data = consumerdurables_data, seed = seed,
                                chains = 1, chain_id = i, # refresh = -1,
                                iter = iters, control = control))
stan_fit_consumerdurables_joint <- sflist2stanfit(sflist)

# This will display the posterior inference directly
print(stan_fit_consumerdurables_joint)

#now latex it
output_consumerdurables_joint <- summary(stan_fit_consumerdurables_joint)
textable_consumerdurables_joint <- xtable(output_consumerdurables_joint$summary)
print.xtable(textable_consumerdurables_joint)

#now save the table for easy access
sink("textable_stan_fit_consumerdurables_joint.txt")
print.xtable(textable_consumerdurables_joint)
sink()

#codafit it

codafit_consumerdurables_joint <- stan2coda(stan_fit_consumerdurables_joint)
summary(codafit_consumerdurables_joint)
codafitmatrix_consumerdurables_joint <- as.matrix(codafit_consumerdurables_joint)

save.image(file = "microcredit_joint_model_consumerdurables_output.RData")


#### Full Data Model: Independent but split by prior business ####

# Load data
rm(list = ls())
load("microcredit_project_data_with_replication_consumerdurables.RData")
if( exists("USD_convert_to_2009_dollars")=="FALSE"){stop("OLD DATA FILE LOADED! RELOAD CORRECT FILE!")}


# This preps data so that the model can be written efficiently - it's not necessary but it's the best way I know to code it in STAN 
priorbiz <- c(attanasio_existingbusiness, augsberg_existingbusiness,banerjee_existingbusiness, crepon_existingbusiness)
site <- c( attanasio_indicator, augsberg_indicator,banerjee_indicator, crepon_indicator)
site <- site - 1
consumerdurables <- c( attanasio_consumerdurables, augsberg_consumerdurables,banerjee_consumerdurables, crepon_consumerdurables)
treatment <- c( attanasio_treatment, augsberg_treatment,banerjee_treatment, crepon_treatment)

# Now we have to standardise any variables which are in local currency units to USD PPP per fortnight in 2009 dollars


expanded_standardiser_USD_PPP_per_fortnight <- c( 
  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[1],length(attanasio_indicator)),
  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[2],length(augsberg_indicator)),
  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[3],length(banerjee_indicator)),
  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[4],length(crepon_indicator)))

consumerdurables <- consumerdurables*expanded_standardiser_USD_PPP_per_fortnight

# bind everything into a data frame
data <- data.frame(site, consumerdurables, treatment)

# We gotta remove the NA values
data <- data[complete.cases(data),]


# now reformat so the stan code can take the data in as a buncha vectors 

X_mu <- data.frame(rep(1, length(priorbiz)), priorbiz)
X_tau <- data.frame(treatment, treatment*priorbiz)

# bind everything into a data frame

data <- data.frame(site, consumerdurables, X_mu, X_tau)
# We gotta remove the NA values
data <- data[complete.cases(data),]


Q = 2 # number of subgroups
consumerdurables_data <- list(K = length(unique(data$site)) ,
                   N = length(data$consumerdurables),
                   Q = Q,
                   P = 2*Q,
                   site = data$site,
                   y = data$consumerdurables,
                   X_mu = data[,3:4],
                   X_tau = data[,5:6])


## this bit of code is from Jonathan Huggins ##

# some knobs we can tweak
chains <- 4
iters <- 300000
control <- list(adapt_t0 = 10,       # default = 10
                stepsize = 1,        # default = 1
                max_treedepth = 6)   # default = 10
seed <- 42

# Run HMC

model_file <- file.path('microcredit-interactions-model-ss.stan') #this is ss
model <- stan_model(model_file)


  sflist <-
    mclapply(1:chains, mc.cores = chains,
             function(i) sampling(model, data = consumerdurables_data, seed = seed,
                                  chains = 1, chain_id = i, # refresh = -1,
                                  iter = iters, control = control))
  stan_fit_consumerdurables_priorbiz_split <- sflist2stanfit(sflist)
  



#now latex it 
summary_stan_fit_consumerdurables_priorbiz_split <- summary(stan_fit_consumerdurables_priorbiz_split)
textable_stan_fit_consumerdurables_priorbiz_split <- xtable(summary_stan_fit_consumerdurables_priorbiz_split$summary)
print.xtable(textable_stan_fit_consumerdurables_priorbiz_split)

#now save all that good stuff

sink("textable_stan_fit_consumerdurables_priorbiz_split.txt")
print.xtable(textable_stan_fit_consumerdurables_priorbiz_split)
sink()

codafit_consumerdurables_priorbiz_split <- stan2coda(stan_fit_consumerdurables_priorbiz_split)
summary(codafit_consumerdurables_priorbiz_split)
codafitmatrix_consumerdurables_priorbiz_split <- as.matrix(codafit_consumerdurables_priorbiz_split)


save.image(file = "microcredit_independent_model_priorbiz_split_consumerdurables_output.RData")

#### Full Data Model: Independent with ridge layer on contextual variables ####

# Load data
rm(list = ls())
load("microcredit_project_data_with_replication_consumerdurables.RData")
if( exists("USD_convert_to_2009_dollars")=="FALSE"){stop("OLD DATA FILE LOADED! RELOAD CORRECT FILE!")}


# This preps data so that the model can be written efficiently - it's not necessary but it's the best way I know to code it in STAN
site <- c( attanasio_indicator, augsberg_indicator,banerjee_indicator, crepon_indicator)
consumerdurables <- c( attanasio_consumerdurables, augsberg_consumerdurables,banerjee_consumerdurables, crepon_consumerdurables)
treatment <- c( attanasio_treatment, augsberg_treatment,banerjee_treatment, crepon_treatment)
site <- site - 1
# Now we have to standardise any variables which are in local currency units to USD PPP per fortnight in 2009 dollars


expanded_standardiser_USD_PPP_per_fortnight <- c( 
  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[1],length(attanasio_indicator)),
  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[2],length(augsberg_indicator)),
  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[3],length(banerjee_indicator)),
  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[4],length(crepon_indicator)))

consumerdurables <- consumerdurables*expanded_standardiser_USD_PPP_per_fortnight

# bind everything into a data frame
data <- data.frame(site, consumerdurables, treatment)

# We gotta remove the NA values
data <- data[complete.cases(data),]

# here's the set of contextual variables
targetwomen <- c(angelucci_targetwomen, attanasio_targetwomen, augsberg_targetwomen,banerjee_targetwomen, crepon_targetwomen, karlan_targetwomen, tarozzi_targetwomen)
village_rand <- c(angelucci_village_rand, attanasio_village_rand, augsberg_village_rand,banerjee_village_rand, crepon_village_rand, karlan_village_rand, tarozzi_village_rand)
individual_rand <- 1-village_rand
APR <- c(angelucci_APR, attanasio_APR, augsberg_APR,banerjee_APR, crepon_APR, karlan_APR, tarozzi_APR)
market_saturation <- c(angelucci_currentmarket, attanasio_currentmarket, augsberg_currentmarket,banerjee_currentmarket, crepon_currentmarket, karlan_currentmarket, tarozzi_currentmarket)
promotion <- c(angelucci_promotion, attanasio_promotion, augsberg_promotion,banerjee_promotion, crepon_promotion, karlan_promotion, tarozzi_promotion)
collateralised <- c(angelucci_collateralised, attanasio_collateralised, augsberg_collateralised,banerjee_collateralised, crepon_collateralised, karlan_collateralised, tarozzi_collateralised)
loansize_percentincome <- c(angelucci_loansize_percentincome, attanasio_loansize_percentincome, augsberg_loansize_percentincome,banerjee_loansize_percentincome, crepon_loansize_percentincome, karlan_loansize_percentincome, tarozzi_loansize_percentincome)

X_data <- cbind(individual_rand, targetwomen, APR, market_saturation, promotion, collateralised, loansize_percentincome)
L = dim(X_data)[2]

X_data <- X_data[2:5,]



### Impact of Microcredit on consumerdurables: with ridge ###

model_file <- file.path('microcredit-independent-model-with-ridge-ss.stan')
model <- stan_model(model_file)


consumerdurables_data <- list(K = length(unique(data$site)) ,
                    N = length(data$treatment),
                    L = dim(X_data)[2],
                    P = 2,
                    site = data$site,
                    y = data$consumerdurables,
                    ITT = data$treatment, 
                    X = X_data, 
                    prior_mean_beta = rep(0, L),
                    prior_var_beta = diag(rep(1,L),L,L)
)



# some knobs we can tweak
chains <- 4
iters <- 500000
control <- list(adapt_t0 = 10,       # default = 10
                stepsize = 1,        # default = 1
                max_treedepth = 6)   # default = 10
seed <- 42

sflist <-
  mclapply(1:chains, mc.cores = chains,
           function(i) sampling(model, data = consumerdurables_data, seed = seed,
                                chains = 1, chain_id = i, # refresh = -1,
                                iter = iters, control = control))
stan_fit_ridge_independent_consumerdurables <- sflist2stanfit(sflist)

#now latex it 
summary_stan_fit_ridge_independent_consumerdurables <- summary(stan_fit_ridge_independent_consumerdurables)
textable_stan_fit_ridge_independent_consumerdurables <- xtable(summary_stan_fit_ridge_independent_consumerdurables$summary)
print.xtable(textable_stan_fit_ridge_independent_consumerdurables)

#now save all that good stuff

sink("texable_stan_fit_ridge_independent_consumerdurables.txt")
print.xtable(textable_stan_fit_ridge_independent_consumerdurables)
sink()



codafit_stan_fit_ridge_independent_consumerdurables <- stan2coda(stan_fit_ridge_independent_consumerdurables)
summary(codafit_stan_fit_ridge_independent_consumerdurables)
#plot(codafit)
codafitmatrix_ridge_independent_consumerdurables <- as.matrix(codafit_stan_fit_ridge_independent_consumerdurables)

#now save every object we created 
save.image(file = "microcredit_independent_model_ridge_consumerdurables_output.RData")


## Now robustness check: do it with binaries ##

# Load data
rm(list = ls())
load("microcredit_project_data_with_replication_consumerdurables.RData")
if( exists("USD_convert_to_2009_dollars")=="FALSE"){stop("OLD DATA FILE LOADED! RELOAD CORRECT FILE!")}

# This preps data so that the model can be written efficiently - it's not necessary but it's the best way I know to code it in STAN
site <- c( attanasio_indicator, augsberg_indicator,banerjee_indicator, crepon_indicator)
consumerdurables <- c( attanasio_consumerdurables, augsberg_consumerdurables,banerjee_consumerdurables, crepon_consumerdurables)
treatment <- c( attanasio_treatment, augsberg_treatment,banerjee_treatment, crepon_treatment)
site <- site - 1
# Now we have to standardise any variables which are in local currency units to USD PPP per fortnight in 2009 dollars


expanded_standardiser_USD_PPP_per_fortnight <- c( 
  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[1],length(attanasio_indicator)),
  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[2],length(augsberg_indicator)),
  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[3],length(banerjee_indicator)),
  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[4],length(crepon_indicator)))

consumerdurables <- consumerdurables*expanded_standardiser_USD_PPP_per_fortnight

# bind everything into a data frame
data <- data.frame(site, consumerdurables, treatment)

# We gotta remove the NA values
data <- data[complete.cases(data),]

# here's the set of contextual variables
targetwomen <- c(angelucci_targetwomen, attanasio_targetwomen, augsberg_targetwomen,banerjee_targetwomen, crepon_targetwomen, karlan_targetwomen, tarozzi_targetwomen)
village_rand <- c(angelucci_village_rand, attanasio_village_rand, augsberg_village_rand,banerjee_village_rand, crepon_village_rand, karlan_village_rand, tarozzi_village_rand)
individual_rand <- 1-village_rand
APR <- c(angelucci_APR, attanasio_APR, augsberg_APR,banerjee_APR, crepon_APR, karlan_APR, tarozzi_APR)
market_saturation <- c(angelucci_currentmarket, attanasio_currentmarket, augsberg_currentmarket,banerjee_currentmarket, crepon_currentmarket, karlan_currentmarket, tarozzi_currentmarket)
promotion <- c(angelucci_promotion, attanasio_promotion, augsberg_promotion,banerjee_promotion, crepon_promotion, karlan_promotion, tarozzi_promotion)
collateralised <- c(angelucci_collateralised, attanasio_collateralised, augsberg_collateralised,banerjee_collateralised, crepon_collateralised, karlan_collateralised, tarozzi_collateralised)
loansize_percentincome <- c(angelucci_loansize_percentincome, attanasio_loansize_percentincome, augsberg_loansize_percentincome,banerjee_loansize_percentincome, crepon_loansize_percentincome, karlan_loansize_percentincome, tarozzi_loansize_percentincome)

market_saturation[market_saturation < 2] <- 0
market_saturation[market_saturation >= 2] <- 1

APR[APR <= median(APR)] <- 0
APR[APR > median(APR)] <- 1

loansize_percentincome[loansize_percentincome <= median(loansize_percentincome)] <- 0
loansize_percentincome[loansize_percentincome > median(loansize_percentincome)] <- 1


X_data <- cbind(individual_rand, targetwomen, APR, market_saturation, promotion, collateralised, loansize_percentincome)
L = dim(X_data)[2]

X_data <- X_data[2:5,]

### Impact of Microcredit on consumerdurables: with ridge ###

model_file <- file.path('microcredit-independent-model-with-ridge-ss.stan')
model <- stan_model(model_file)


consumerdurables_data <- list(K = length(unique(data$site)) ,
                   N = length(data$treatment),
                   L = dim(X_data)[2],
                   P = 2,
                   site = data$site,
                   y = data$consumerdurables,
                   ITT = data$treatment, 
                   X = X_data, 
                   prior_mean_beta = rep(0, L),
                   prior_var_beta = diag(rep(1,L),L,L)
)



# some knobs we can tweak
chains <- 4
iters <- 500000
control <- list(adapt_t0 = 10,       # default = 10
                stepsize = 1,        # default = 1
                max_treedepth = 6)   # default = 10
seed <- 42

sflist <-
  mclapply(1:chains, mc.cores = chains,
           function(i) sampling(model, data = consumerdurables_data, seed = seed,
                                chains = 1, chain_id = i, # refresh = -1,
                                iter = iters, control = control))
stan_fit_ridge_independent_binary_consumerdurables <- sflist2stanfit(sflist)

#now latex it 
summary_stan_fit_ridge_independent_binary_consumerdurables <- summary(stan_fit_ridge_independent_binary_consumerdurables)
textable_stan_fit_ridge_independent_binary_consumerdurables <- xtable(summary_stan_fit_ridge_independent_binary_consumerdurables$summary)
print.xtable(textable_stan_fit_ridge_independent_binary_consumerdurables)

#now save all that good stuff

sink("texable_stan_fit_ridge_independent_binary_consumerdurables.txt")
print.xtable(textable_stan_fit_ridge_independent_binary_consumerdurables)
sink()



codafit_stan_fit_ridge_independent_binary_consumerdurables <- stan2coda(stan_fit_ridge_independent_binary_consumerdurables)
summary(codafit_stan_fit_ridge_independent_binary_consumerdurables)
#plot(codafit)
codafitmatrix_ridge_independent_binary_consumerdurables <- as.matrix(codafit_stan_fit_ridge_independent_binary_consumerdurables)

#now save every object we created 
save.image(file = "microcredit_independent_model_ridge_binary_consumerdurables_output.RData")



