
# Check Replications in Microcredit Meta-Analysis Project consumerdurables 
# Rachael Meager
# First Version: August 2015
# This Version: August 2015

### Notes ###

# This code loads variables from .dta files from 7 RCTs of microcredit
# All data was publicly available from the authors and journals, without whom this project would not be possible. Hooray for open science!
# I use "i" as the general index for household-level variables and "k" as the index for site-level variables


# A note about NAs: I have tried to keep NAs as NAs, except in TWO CASES. 
# 1. consumerdurables/Business expenses/consumerdurables. An NA in here can indicate not operating a business and we want to capture that in a zero.
# 2. Variables constructed by summing other variables should not be NA unless *ALL* of the constituent variables are NA.


### Preliminaries ###

rm(list = ls())

chooseCRANmirror(ind=90)

setwd("//bbkinghome/rmeager/winprofile/mydocs/Research work/bayesian meta analysis/microcredit analysis")
installer <- FALSE
if(installer == TRUE){
  install.packages('foreign')
  install.packages('Hmisc')
  install.packages('xtable')
  install.packages('coda')
  install.packages('stargazer')
  install.packages('dummies')
  install.packages('zoo')
  install.packages('lmtest')
  install.packages('plm')
  install.packages('sandwich')
  install.packages('Matrix')
  install.packages("ggplot2")
  install.packages("gridExtra")}


library(dummies)
library(multiwayvcov)
library(stargazer)
library(foreign)
library(Hmisc)
library(xtable)
library(coda)
library(zoo)
library(plm)
library(lmtest)
library(sandwich)
library(ggplot2)
library(gridExtra)
library(Matrix)

## load data ##

load("microcredit_project_data.RData")


attanasio_consumerdurables_regression <- summary(lm(attanasio_consumerdurables ~ attanasio_treatment))
print(attanasio_consumerdurables_regression)
augsberg_consumerdurables_regression <- summary(lm(augsberg_consumerdurables ~ augsberg_treatment))
print(augsberg_consumerdurables_regression)
banerjee_consumerdurables_regression <- summary(lm(banerjee_consumerdurables ~ banerjee_treatment))
print(banerjee_consumerdurables_regression)
crepon_consumerdurables_regression <- summary(lm(crepon_consumerdurables ~ crepon_treatment))
print(crepon_consumerdurables_regression)


ols_output_consumerdurables <- list( attanasio_consumerdurables_regression, augsberg_consumerdurables_regression,
                          banerjee_consumerdurables_regression, crepon_consumerdurables_regression)

pick.coefficient.from.summary <- function(lm_summary_object){  return(lm_summary_object$coef[2,1])}
pick.coefficient.sd.from.summary <- function(lm_summary_object){  return(lm_summary_object$coef[2,2])}
pick.mean.from.summary <- function(lm_summary_object){  return(lm_summary_object$coef[1,1])}
pick.mean.sd.from.summary <- function(lm_summary_object){  return(lm_summary_object$coef[1,2])}

ols_output_consumerdurables_coefficients <- unlist(lapply(ols_output_consumerdurables, pick.coefficient.from.summary))
ols_output_consumerdurables_coefficients_sds <- unlist(lapply(ols_output_consumerdurables, pick.coefficient.sd.from.summary))

standardised_ols_output_consumerdurables_coefficients <- the_consumerdurables_standardiser_USD_PPP_per_fortnight*ols_output_consumerdurables_coefficients
standardised_ols_output_consumerdurables_coefficients_sds <- the_consumerdurables_standardiser_USD_PPP_per_fortnight*ols_output_consumerdurables_coefficients_sds

ols_output_consumerdurables_means <- unlist(lapply(ols_output_consumerdurables, pick.mean.from.summary))
ols_output_consumerdurables_means_sds <- unlist(lapply(ols_output_consumerdurables, pick.mean.sd.from.summary))

standardised_ols_output_consumerdurables_means <- the_consumerdurables_standardiser_USD_PPP_per_fortnight*ols_output_consumerdurables_means
standardised_ols_output_consumerdurables_means_sds <- the_consumerdurables_standardiser_USD_PPP_per_fortnight*ols_output_consumerdurables_means_sds



## BEST MATCH TABLE ##

ols_sep_best_match_list <- list (
                             lm(attanasio_consumerdurables*the_consumerdurables_standardiser_USD_PPP_per_fortnight[1] ~ attanasio_treatment),
                              lm(augsberg_consumerdurables*the_consumerdurables_standardiser_USD_PPP_per_fortnight[2] ~ augsberg_treatment), 
                             lm(banerjee_consumerdurables*the_consumerdurables_standardiser_USD_PPP_per_fortnight[3] ~ banerjee_treatment),
                              lm(crepon_consumerdurables*the_consumerdurables_standardiser_USD_PPP_per_fortnight[4] ~ crepon_treatment))

ols_sep_se_best_match_list <- lapply(ols_sep_best_match_list, vcovHC,type = "HC")

sqrt.diag <- function(x){sqrt(diag(x))}

ols_sep_robust_se <- lapply(ols_sep_se_best_match_list, sqrt.diag)

pick.se.from.robust.se <- function(robust_se_object){robust_se_object[2]}
pick.mean.se.from.robust.se <- function(robust_se_object){robust_se_object[1]}

sink("microcredit_ols_sep_basic_consumerdurables_regressions.txt")
stargazer(ols_sep_best_match_list, se=ols_sep_robust_se,
          
          #ci=TRUE,
          colnames = NULL,
          column.labels = study_country)
sink()



### NOW RE-ENTER consumerdurables DATA IN ORDER TO HAVE THE BEST MATCH NAMED AS "consumerdurables" IN THE DATA ###

# no change needed


# and re-name the coefficients output


attanasio_consumerdurables_regression <- summary(lm(attanasio_consumerdurables ~ attanasio_treatment))
augsberg_consumerdurables_regression <- summary(lm(augsberg_consumerdurables ~ augsberg_treatment))
banerjee_consumerdurables_regression <- summary(lm(banerjee_consumerdurables ~ banerjee_treatment))
crepon_consumerdurables_regression <- summary(lm(crepon_consumerdurables ~ crepon_treatment))


ols_best_match_output_consumerdurables <- list(attanasio_consumerdurables_regression, augsberg_consumerdurables_regression,
                          banerjee_consumerdurables_regression, crepon_consumerdurables_regression)

ols_output_consumerdurables_coefficients <- unlist(lapply(ols_best_match_output_consumerdurables, pick.coefficient.from.summary))
ols_output_consumerdurables_coefficients_sds <- unlist(lapply(ols_sep_robust_se, pick.se.from.robust.se))

ols_output_consumerdurables_means <- unlist(lapply(ols_best_match_output_consumerdurables, pick.mean.from.summary))
ols_output_consumerdurables_means_sds <- unlist(lapply(ols_sep_robust_se, pick.mean.se.from.robust.se))

standardised_ols_best_match_output_consumerdurables_coefficients <- the_consumerdurables_standardiser_USD_PPP_per_fortnight*ols_output_consumerdurables_coefficients
standardised_ols_best_match_output_consumerdurables_coefficients_sds <- ols_output_consumerdurables_coefficients_sds # do not re-standardise! already standardised!! 

standardised_ols_best_match_output_consumerdurables_means <- the_consumerdurables_standardiser_USD_PPP_per_fortnight*ols_output_consumerdurables_means
standardised_ols_best_match_output_consumerdurables_means_sds <- ols_output_consumerdurables_means_sds # do not re-standardise! already standardised!! 


# and now write the pooled regression because we will want it later

## POOLED OLS REGRESSION ##

# This preps data so that the model can be written efficiently - it's not necessary but it's the best way I know to code it in STAN
site <- c(attanasio_indicator, augsberg_indicator,banerjee_indicator, crepon_indicator)
consumerdurables <- c( attanasio_consumerdurables, augsberg_consumerdurables,banerjee_consumerdurables, crepon_consumerdurables)
treatment <- c( attanasio_treatment, augsberg_treatment,banerjee_treatment, crepon_treatment)

# Now we have to standardise any variables which are in local currency units to USD PPP per fortnight in 2009 dollars


expanded_standardiser_USD_PPP_per_fortnight <- c( 
                                                  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[1],length(attanasio_indicator)),
                                                  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[2],length(augsberg_indicator)),
                                                  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[3],length(banerjee_indicator)),
                                                  rep(the_consumerdurables_standardiser_USD_PPP_per_fortnight[4],length(crepon_indicator))
                                                 )

consumerdurables <- consumerdurables*expanded_standardiser_USD_PPP_per_fortnight

# bind everything into a data frame
data <- data.frame(site, consumerdurables, treatment)

# We gotta remove the NA values
data <- data[complete.cases(data),]

ols_pooled <- lm(data$consumerdurables ~ data$treatment + factor(data$site))
summary(ols_pooled)
# now we cluster the standard errors! 

ols_cluster_wild_boot <- cluster.boot(ols_pooled, data$site, parallel = FALSE, use_white = NULL,
                                      force_posdef = FALSE, R = 1000, boot_type = "wild",
                                      wild_type = "rademacher", debug = FALSE)
ols_clustered_vcov <- cluster.vcov(ols_pooled, data$site)

ols_pooled_cluster_sd <- sqrt(diag(ols_cluster_wild_boot))


sink("ols_pooled_regression_consumerdurables_best_match_cluster_ses.txt")
stargazer(ols_pooled, se = list(ols_pooled_cluster_sd, NULL)) 
sink()

sink("ols_pooled_regression_consumerdurables_best_match.txt")
stargazer(ols_pooled)
sink()

# now extract coefficinets from the big regression, which I need to compare to bayes

library(dummies)
site_dummies <- dummy(data$site)
data_with_dummies <- data.frame(data, site_dummies)

standardised_ols_best_match_results_from_pooled_data <- lm(data$consumerdurables ~ factor(data$site) + data$treatment + factor(data$site)*data$treatment )

summary(lm(data$consumerdurables ~ site_dummies + data$treatment + site_dummies*data$treatment ))
# now we cluster the standard errors! 

ols_cluster_wild_boot <- cluster.boot(ols_pooled, data$site, parallel = FALSE, use_white = NULL,
                                      force_posdef = FALSE, R = 1000, boot_type = "wild",
                                      wild_type = "rademacher", debug = FALSE)
ols_clustered_vcov <- cluster.vcov(ols_pooled, data$site)

ols_pooled_cluster_sd <- sqrt(diag(ols_cluster_wild_boot))


save.image(file = "microcredit_project_data_with_replication_consumerdurables.RData")
