
# Check Replications in Microcredit Meta-Analysis Project revenues 
# Rachael Meager
# First Version: August 2015
# This Version: August 2015

### Notes ###

# This code loads variables from .dta files from 7 RCTs of microcredit
# All data was publicly available from the authors and journals, without whom this project would not be possible. Hooray for open science!
# I use "i" as the general index for household-level variables and "k" as the index for site-level variables


# A note about NAs: I have tried to keep NAs as NAs, except in TWO CASES. 
# 1. revenues/Business expenses/Revenues. An NA in here can indicate not operating a business and we want to capture that in a zero.
# 2. Variables constructed by summing other variables should not be NA unless *ALL* of the constituent variables are NA.


### Preliminaries ###

rm(list = ls())

chooseCRANmirror(ind=90)

setwd("//bbkinghome/rmeager/winprofile/mydocs/Research work/bayesian meta analysis/microcredit analysis")
installer <- FALSE
if(installer == TRUE){
  install.packages('foreign')
  install.packages('Hmisc')
  install.packages('xtable')
  install.packages('coda')
  install.packages('stargazer')
  install.packages('dummies')
  install.packages('zoo')
  install.packages('lmtest')
  install.packages('plm')
  install.packages('sandwich')
  install.packages('Matrix')
  install.packages("ggplot2")
  install.packages("gridExtra")}


library(dummies)
library(multiwayvcov)
library(stargazer)
library(foreign)
library(Hmisc)
library(xtable)
library(coda)
library(zoo)
library(plm)
library(lmtest)
library(sandwich)
library(ggplot2)
library(gridExtra)
library(Matrix)

## load data ##

load("microcredit_project_data.RData")

angelucci_revenues_regression <- summary(lm(angelucci_revenues ~ angelucci_treatment))
print(angelucci_revenues_regression)
attanasio_revenues_regression <- summary(lm(attanasio_revenues ~ attanasio_treatment))
print(attanasio_revenues_regression)
augsberg_revenues_regression <- summary(lm(augsberg_revenues ~ augsberg_treatment))
print(augsberg_revenues_regression)
banerjee_revenues_regression <- summary(lm(banerjee_revenues ~ banerjee_treatment))
print(banerjee_revenues_regression)
crepon_revenues_regression <- summary(lm(crepon_revenues ~ crepon_treatment))
print(crepon_revenues_regression)
karlan_revenues_regression <- summary(lm(karlan_revenues ~ karlan_treatment))
print(karlan_revenues_regression)
tarozzi_revenues_regression <- summary(lm(tarozzi_revenues ~ tarozzi_treatment))
print(tarozzi_revenues_regression)

ols_output_revenues <- list(angelucci_revenues_regression, attanasio_revenues_regression, augsberg_revenues_regression,
                          banerjee_revenues_regression, crepon_revenues_regression, karlan_revenues_regression, 
                          tarozzi_revenues_regression)

pick.coefficient.from.summary <- function(lm_summary_object){  return(lm_summary_object$coef[2,1])}
pick.coefficient.sd.from.summary <- function(lm_summary_object){  return(lm_summary_object$coef[2,2])}
pick.mean.from.summary <- function(lm_summary_object){  return(lm_summary_object$coef[1,1])}
pick.mean.sd.from.summary <- function(lm_summary_object){  return(lm_summary_object$coef[1,2])}

ols_output_revenues_coefficients <- unlist(lapply(ols_output_revenues, pick.coefficient.from.summary))
ols_output_revenues_coefficients_sds <- unlist(lapply(ols_output_revenues, pick.coefficient.sd.from.summary))

standardised_ols_output_revenues_coefficients <- the_revenues_standardiser_USD_PPP_per_fortnight*ols_output_revenues_coefficients
standardised_ols_output_revenues_coefficients_sds <- the_revenues_standardiser_USD_PPP_per_fortnight*ols_output_revenues_coefficients_sds

ols_output_revenues_means <- unlist(lapply(ols_output_revenues, pick.mean.from.summary))
ols_output_revenues_means_sds <- unlist(lapply(ols_output_revenues, pick.mean.sd.from.summary))

standardised_ols_output_revenues_means <- the_revenues_standardiser_USD_PPP_per_fortnight*ols_output_revenues_means
standardised_ols_output_revenues_means_sds <- the_revenues_standardiser_USD_PPP_per_fortnight*ols_output_revenues_means_sds


# now with non imputed revenues_non_imputed
angelucci_revenues_non_imputed_regression <- summary(lm(angelucci_revenues_non_imputed ~ angelucci_treatment))
print(angelucci_revenues_non_imputed_regression)
augsberg_revenues_non_imputed_regression <- summary(lm(augsberg_revenues_non_imputed ~ augsberg_treatment))
print(augsberg_revenues_non_imputed_regression)
attanasio_revenues_non_imputed_regression <- summary(lm(attanasio_revenues_non_imputed ~ attanasio_treatment))
print(attanasio_revenues_non_imputed_regression)
banerjee_revenues_non_imputed_regression <- summary(lm(banerjee_revenues_non_imputed ~ banerjee_treatment))
print(banerjee_revenues_non_imputed_regression)
crepon_revenues_non_imputed_regression <- summary(lm(crepon_revenues_non_imputed ~ crepon_treatment))
print(crepon_revenues_non_imputed_regression)
karlan_revenues_non_imputed_regression <- summary(lm(karlan_revenues_non_imputed ~ karlan_treatment))
print(karlan_revenues_non_imputed_regression)
tarozzi_revenues_non_imputed_regression <- summary(lm(tarozzi_revenues_non_imputed ~ tarozzi_treatment))
print(tarozzi_revenues_non_imputed_regression)


ols_output_revenues_non_imputed <- list(angelucci_revenues_non_imputed_regression, attanasio_revenues_non_imputed_regression, augsberg_revenues_non_imputed_regression,
                          banerjee_revenues_non_imputed_regression, crepon_revenues_non_imputed_regression, karlan_revenues_non_imputed_regression, 
                          tarozzi_revenues_non_imputed_regression)


ols_output_revenues_non_imputed_coefficients <- unlist(lapply(ols_output_revenues_non_imputed, pick.coefficient.from.summary))
ols_output_revenues_non_imputed_coefficients_sds <- unlist(lapply(ols_output_revenues_non_imputed, pick.coefficient.sd.from.summary))

standardised_ols_output_revenues_non_imputed_coefficients <- the_revenues_standardiser_USD_PPP_per_fortnight*ols_output_revenues_non_imputed_coefficients
standardised_ols_output_revenues_non_imputed_coefficients_sds <- the_revenues_standardiser_USD_PPP_per_fortnight*ols_output_revenues_non_imputed_coefficients_sds

output_table_dataframe <- data.frame(standardised_reported_coefficients_revenues, standardised_reported_coefficients_revenues_sds,
                                     standardised_ols_output_revenues_coefficients, standardised_ols_output_revenues_coefficients_sds,
                                     standardised_ols_output_revenues_non_imputed_coefficients, standardised_ols_output_revenues_non_imputed_coefficients_sds )


# print a nice table
pdf("//bbkinghome/rmeager/winprofile/mydocs/Research work/bayesian meta analysis/microcredit analysis/replications_revenues_output.pdf", height=4, width=32)
grid.table(output_table_dataframe)
dev.off()
save.image(file = "microcredit_replications_revenues_output.RData")


## BEST MATCH TABLE ##

ols_sep_best_match_list <- list (lm(angelucci_revenues*the_revenues_standardiser_USD_PPP_per_fortnight[1] ~ angelucci_treatment), 
                             lm(attanasio_revenues*the_revenues_standardiser_USD_PPP_per_fortnight[2] ~ attanasio_treatment),
                              lm(augsberg_revenues*the_revenues_standardiser_USD_PPP_per_fortnight[3] ~ augsberg_treatment), 
                             lm(banerjee_revenues*the_revenues_standardiser_USD_PPP_per_fortnight[4] ~ banerjee_treatment),
                              lm(crepon_revenues*the_revenues_standardiser_USD_PPP_per_fortnight[5] ~ crepon_treatment),
                             lm(karlan_revenues*the_revenues_standardiser_USD_PPP_per_fortnight[6] ~ karlan_treatment),
                             lm(tarozzi_revenues*the_revenues_standardiser_USD_PPP_per_fortnight[7] ~ tarozzi_treatment))

ols_sep_se_best_match_list <- lapply(ols_sep_best_match_list, vcovHC,type = "HC")

sqrt.diag <- function(x){sqrt(diag(x))}

ols_sep_robust_se <- lapply(ols_sep_se_best_match_list, sqrt.diag)

pick.se.from.robust.se <- function(robust_se_object){robust_se_object[2]}
pick.mean.se.from.robust.se <- function(robust_se_object){robust_se_object[1]}

sink("microcredit_ols_sep_basic_revenues_regressions.txt")
stargazer(ols_sep_best_match_list, se=ols_sep_robust_se,
          
          #ci=TRUE,
          colnames = NULL,
          column.labels = study_country)
sink()



### NOW RE-ENTER revenues DATA IN ORDER TO HAVE THE BEST MATCH NAMED AS "revenues" IN THE DATA ###

# no change needed


# and re-name the coefficients output

angelucci_revenues_regression <- summary(lm(angelucci_revenues ~ angelucci_treatment))
attanasio_revenues_regression <- summary(lm(attanasio_revenues ~ attanasio_treatment))
augsberg_revenues_regression <- summary(lm(augsberg_revenues ~ augsberg_treatment))
banerjee_revenues_regression <- summary(lm(banerjee_revenues ~ banerjee_treatment))
crepon_revenues_regression <- summary(lm(crepon_revenues ~ crepon_treatment))
karlan_revenues_regression <- summary(lm(karlan_revenues ~ karlan_treatment))
tarozzi_revenues_regression <- summary(lm(tarozzi_revenues ~ tarozzi_treatment))

ols_best_match_output_revenues <- list(angelucci_revenues_regression, attanasio_revenues_regression, augsberg_revenues_regression,
                          banerjee_revenues_regression, crepon_revenues_regression, karlan_revenues_regression, 
                          tarozzi_revenues_regression)

ols_output_revenues_coefficients <- unlist(lapply(ols_best_match_output_revenues, pick.coefficient.from.summary))
ols_output_revenues_coefficients_sds <- unlist(lapply(ols_sep_robust_se, pick.se.from.robust.se))

ols_output_revenues_means <- unlist(lapply(ols_best_match_output_revenues, pick.mean.from.summary))
ols_output_revenues_means_sds <- unlist(lapply(ols_sep_robust_se, pick.mean.se.from.robust.se))

standardised_ols_best_match_output_revenues_coefficients <- the_revenues_standardiser_USD_PPP_per_fortnight*ols_output_revenues_coefficients
standardised_ols_best_match_output_revenues_coefficients_sds <- ols_output_revenues_coefficients_sds # do not re-standardise! already standardised!! 

standardised_ols_best_match_output_revenues_means <- the_revenues_standardiser_USD_PPP_per_fortnight*ols_output_revenues_means
standardised_ols_best_match_output_revenues_means_sds <- ols_output_revenues_means_sds # do not re-standardise! already standardised!! 


# and now write the pooled regression because we will want it later

## POOLED OLS REGRESSION ##

# This preps data so that the model can be written efficiently - it's not necessary but it's the best way I know to code it in STAN
site <- c(angelucci_indicator, attanasio_indicator, augsberg_indicator,banerjee_indicator, crepon_indicator, karlan_indicator, tarozzi_indicator)
revenues <- c(angelucci_revenues, attanasio_revenues, augsberg_revenues,banerjee_revenues, crepon_revenues, karlan_revenues, tarozzi_revenues)
treatment <- c(angelucci_treatment, attanasio_treatment, augsberg_treatment,banerjee_treatment, crepon_treatment, karlan_treatment, tarozzi_treatment)

# Now we have to standardise any variables which are in local currency units to USD PPP per fortnight in 2009 dollars


expanded_standardiser_USD_PPP_per_fortnight <- c( rep(the_revenues_standardiser_USD_PPP_per_fortnight[1],length(angelucci_indicator)),
                                                  rep(the_revenues_standardiser_USD_PPP_per_fortnight[2],length(attanasio_indicator)),
                                                  rep(the_revenues_standardiser_USD_PPP_per_fortnight[3],length(augsberg_indicator)),
                                                  rep(the_revenues_standardiser_USD_PPP_per_fortnight[4],length(banerjee_indicator)),
                                                  rep(the_revenues_standardiser_USD_PPP_per_fortnight[5],length(crepon_indicator)),
                                                  rep(the_revenues_standardiser_USD_PPP_per_fortnight[6],length(karlan_indicator)),
                                                  rep(the_revenues_standardiser_USD_PPP_per_fortnight[7],length(tarozzi_indicator)))

revenues <- revenues*expanded_standardiser_USD_PPP_per_fortnight

# bind everything into a data frame
data <- data.frame(site, revenues, treatment)

# We gotta remove the NA values
data <- data[complete.cases(data),]

ols_pooled <- lm(data$revenues ~ data$treatment + factor(data$site))
summary(ols_pooled)
# now we cluster the standard errors! 

ols_cluster_wild_boot <- cluster.boot(ols_pooled, data$site, parallel = FALSE, use_white = NULL,
                                      force_posdef = FALSE, R = 1000, boot_type = "wild",
                                      wild_type = "rademacher", debug = FALSE)
ols_clustered_vcov <- cluster.vcov(ols_pooled, data$site)

ols_pooled_cluster_sd <- sqrt(diag(ols_cluster_wild_boot))


sink("ols_pooled_regression_revenues_best_match_cluster_ses.txt")
stargazer(ols_pooled, se = list(ols_pooled_cluster_sd, NULL)) 
sink()

sink("ols_pooled_regression_revenues_best_match.txt")
stargazer(ols_pooled)
sink()

# now extract coefficinets from the big regression, which I need to compare to bayes

library(dummies)
site_dummies <- dummy(data$site)
data_with_dummies <- data.frame(data, site_dummies)

standardised_ols_best_match_results_from_pooled_data <- lm(data$revenues ~ factor(data$site) + data$treatment + factor(data$site)*data$treatment )

summary(lm(data$revenues ~ site_dummies + data$treatment + site_dummies*data$treatment ))
# now we cluster the standard errors! 

ols_cluster_wild_boot <- cluster.boot(ols_pooled, data$site, parallel = FALSE, use_white = NULL,
                                      force_posdef = FALSE, R = 1000, boot_type = "wild",
                                      wild_type = "rademacher", debug = FALSE)
ols_clustered_vcov <- cluster.vcov(ols_pooled, data$site)

ols_pooled_cluster_sd <- sqrt(diag(ols_cluster_wild_boot))


save.image(file = "microcredit_project_data_with_replication_revenues.RData")
