
***************************************************************************************************************************************
*** created by Henriette Hanicotte (based on luke crowley do files), feb 6th, 2011                                                                                      ***
*** for data analysis of impact of credit access study at First Macro Bank (philippines)                                            ***
*** borrowing in month before survey                                                                                                ***
***                                                                                                                                 ***
*** files used:                                                                                                                     ***
***    fmbfinaldata.dta                                                                                                             ***
***************************************************************************************************************************************

clear
set more off
set mem 400m
*set maxvar 10000
capture log close
tempfile fu_loan_amount

use fmbfinaldata, clear

***
***  splits
***

gen css_creditscorefinal_hl=.
replace css_creditscorefinal_hl=0 if css_creditscorefinal < 46		// low creditscore
replace css_creditscorefinal_hl=1 if css_creditscorefinal >= 46		// high creditscore
gen x_creditscore_high= css_creditscorefinal_hl * css_loandecision  if sample ==1
gen x_creditscorefinal = css_creditscorefinal  * css_loandecision  if sample ==1


***
***  tables -- borrowing
***

log using fmb_science_theory_byCS.log, replace

***  last month -- <= 50,000 filter -- number of formal loans

xi: reg loans_k50_form_numb_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_k50_form_numb_m css_loandecision css_creditscorefinal_hl x_creditscore_high i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_k50_form_numb_m css_loandecision css_creditscorefinal x_creditscorefinal i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))


#delimit ;
estout * using outreg\fmb_science_theory_borrow_for_CS.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_creditscore_high x_creditscorefinal  )
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

***  last month -- <= 50,000 filter -- number of informal loans

xi: reg loans_k50_inform_numb_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_k50_inform_numb_m css_loandecision css_creditscorefinal_hl x_creditscore_high i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_k50_inform_numb_m css_loandecision css_creditscorefinal x_creditscorefinal i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\fmb_science_theory_borrow_inf_CS.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2)(3) ) label collabels(,none)
keep(css_loandecision x_creditscore_high x_creditscorefinal )
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

foreach x in loans_k50_form_numb_m loans_k50_inform_numb_m {
	sum `x' if sample==1 & css_loandecision==0
	sum `x' if sample==1 & css_loandecision==0 & css_creditscorefinal_hl ==0
	sum `x' if sample==1 & css_loandecision==0 & css_creditscorefinal_hl ==1
}

capture: log off

***  clean business name variable -- set 997 or CLOSED to ""
***  not counting Closed or Temporarily closed businesses

forval x=1/8 {
	replace fu_bus_name_`x'="" if regexm(fu_bus_name_`x',"997")
	replace fu_bus_name_`x'="" if fu_bus_name_`x'=="0"
	replace fu_bus_name_`x'="" if regexm(fu_bus_name_`x',"clo")
}
replace fu_bus_name_1="" if fu_bus_name_1=="nida & lito store (c"
replace fu_bus_name_1="" if fu_bus_name_1=="oleta store (tempora"
replace fu_bus_name_1="" if fu_bus_name_1=="sari-sari store (tem"
replace fu_bus_name_1="" if fu_bus_name_1=="sari-sari (temporary"
replace fu_bus_name_1="" if fu_bus_name_1=="rai rai junk junk (t"

***
***  tables -- business size
***

***  create 'number of businesses' variable
gen noof_business=0 if sample==1
lab var noof_business "Number of Businesses in Household"
for X in any 1 2 3 4 5 6 7 8: replace noof_business=noof_business+1 if fu_bus_name_X!="" & sample==1
gen temp=1 if fu_bus_name_1=="" & fu_bus_name_2=="" & fu_bus_name_3=="" & fu_bus_name_4=="" & fu_bus_name_5=="" & fu_bus_name_6=="" & fu_bus_name_7=="" & fu_bus_name_8==""
replace noof_business=. if temp==1 & sample!=1
drop temp

***  create 'number of paid helpers' variable
forval x=1/15 {
	gen temp_paid_helper_`x'=1 if fu_helpers_salary_`x'>0 & fu_helpers_salary_`x'<. & sample==1
}
egen paid_helper_numb=rowtotal(temp_paid_helper_*) if sample==1

capture: log on
 
xi: reg noof_business css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg noof_business css_loandecision css_creditscorefinal_hl x_creditscore_high i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg noof_business css_loandecision css_creditscorefinal x_creditscorefinal i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\fmb_science_theory_biz_noof_CS.txt, cells(b(star fmt(%12.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3) ) label collabels(,none)
keep(css_loandecision x_creditscore_high x_creditscorefinal  )
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear
 
xi: reg paid_helper_numb css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg paid_helper_numb css_loandecision css_creditscorefinal_hl x_creditscore_high i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg paid_helper_numb css_loandecision css_creditscorefinal x_creditscorefinal i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\fmb_science_theory_biz_paid_help_CS.txt, cells(b(star fmt(%12.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_creditscore_high x_creditscorefinal  )
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

foreach x in noof_business paid_helper_numb { 
	sum `x' if sample==1 & css_loandecision==0 
	sum `x' if sample==1 & css_loandecision==0 & css_creditscorefinal_hl ==0
	sum `x' if sample==1 & css_loandecision==0 & css_creditscorefinal_hl ==1
}

capture: log off 

***
***  tables -- subjective well-being
***

***  calmness
***  fix error in coding of calmness scale:
replace fu_worry_calm=2 if fu_worry_calm==1
replace fu_worry_calm=1 if fu_worry_calm==0
gen calm=fu_worry_calm
lab var calm "Calmness Scale (1-6) 1==Worry All the Time, 6=Worry None of the Time"

***  binary worry
gen noworry=0 if fu_worry==1
replace noworry=1 if fu_worry==0
lab var noworry "Respondent has NOT had a month in the past year where they felt mostly worried/anxious"

***  happiness / life satisfaction
gen life_satisfied=fu_happiness_satisfied_life
lab var life_satisfied "Life Satisfaction Scale (1-4) 1=Not at all, 4=Very"

***  job satisfaction
gen job_satisfied=fu_happiness_satisfied_work
lab var job_satisfied "Job Satisfaction Scale (1-10) 1=dissatisfied"

***  job stress scale (1-12)
gen jobstress=0
	for X in any fu_happiness_job_stressful fu_happiness_job_time fu_happiness_job_tired: replace jobstress=jobstress+1 if X==4
	for X in any fu_happiness_job_stressful fu_happiness_job_time fu_happiness_job_tired: replace jobstress=jobstress+2 if X==3
	for X in any fu_happiness_job_stressful fu_happiness_job_time fu_happiness_job_tired: replace jobstress=jobstress+3 if X==2
	for X in any fu_happiness_job_stressful fu_happiness_job_time fu_happiness_job_tired: replace jobstress=jobstress+4 if X==1
	replace jobstress=. if fu_happiness_job_stressful>=. | fu_happiness_job_time>=. | fu_happiness_job_tired>=.
	gen nojobstress=-jobstress
	lab var nojobstress "Job Stress scale for respondent (scale -12 to 0) -12=always stressed,tired, & busy (positive increase = less stress)"

***  optimism
***  note: 4 of the 10 questions on the survey are standard filler questions that psychologists (and us) do not use to construct the optimism scale.
gen optimism = 0
	lab var optimism "Optimism scale (scale 6-30)"
	note optimism: Higher score=more optimism.
	note optimism: Only asked to primary respondents (not hh surveys), so sample size=551 (2 missing).
foreach var of varlist fu_optimism_expect_best fu_optimism_optimist  fu_optimism_more_good_than_bad{
	replace optimism=optimism+5 if `var'==5
	replace optimism=optimism+4 if `var'==4
	replace optimism=optimism+3 if `var'==3
	replace optimism=optimism+2 if `var'==2
	replace optimism=optimism+1 if `var'==1
	}
foreach var of varlist fu_optimism_never_expect fu_optimism_good_things  fu_optimism_go_wrong{
	replace optimism=optimism+1 if `var'==5
	replace optimism=optimism+2 if `var'==4
	replace optimism=optimism+3 if `var'==3
	replace optimism=optimism+4 if `var'==2
	replace optimism=optimism+5 if `var'==1
	}
replace optimism=. if optimism==0 | fu_optimism_never_expect>=. | fu_optimism_good_things>=. | fu_optimism_go_wrong>=. | fu_optimism_expect_best>=. | fu_optimism_optimist>=. | fu_optimism_more_good_than_bad>=.

***  decision-making scales (sample size: 995 respondents)
gen decmakingsample=(fu_hh_marriage_1==2 | fu_hh_marriage_1==4) if fu_hh_marriage_1!=. & fu_hh_female_1!=.
lab var decmakingsample "1 if in sample for decision making variables"
rename fu_decision_market_cook fu_decision_market
rename fu_decision_family_planning  fu_decision_fam_plan
rename fu_decision_assistance fu_decision_assist
***  clean scale components: who_decides questions
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: gen d_X=.
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace d_X=0 if fu_hh_female_1==1 & X==2
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace d_X=1 if fu_hh_female_1==1 & X==3
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace d_X=2 if fu_hh_female_1==1 & X==1
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace d_X=0 if fu_hh_female_1==0 & X==1
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace d_X=1 if fu_hh_female_1==0 & X==3
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace d_X=2 if fu_hh_female_1==0 & X==2
***  clean scale components: who_prevails questions
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: gen p_X=.
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace p_X=0 if X_conflict==1 & fu_hh_female_1==1 & X_prevail==2
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace p_X=1 if X_conflict==1 & fu_hh_female_1==1 & X_prevail==3
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace p_X=2 if X_conflict==1 & fu_hh_female_1==1 & X_prevail==1
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace p_X=0 if X_conflict==1 & fu_hh_female_1==0 & X_prevail==1
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace p_X=1 if X_conflict==1 & fu_hh_female_1==0 & X_prevail==3
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace p_X=2 if X_conflict==1 & fu_hh_female_1==0 & X_prevail==2
egen decmakingscale=rsum(d_*) if decmakingsample==1
	egen tmp=rownonmiss(d_*) if decmakingsample==1
	count if tmp!=0
	***  6 cases? recode as missing
	replace decmakingscale=. if tmp==.
	drop tmp
	lab var decmakingscale "Decision-making scale for the applicant (range 0-26)"
	note decmakingscale: Score range 0-26. Higher is more power for the applicant with the Lender.
	note decmakingscale: Decision-making questions only asked to married/partnered applicants: 779 respondents
egen tmp=median(decmakingscale) if sample==1
	gen decmakingscale_above=(decmakingscale>=tmp) if !(decmakingscale>=.) & (sample==1)
	lab var decmakingscale_above "Dummy=1 if decision making scale above median"
	gen decmakingscale_below=(decmakingscale<tmp) if !(decmakingscale>=.) & (sample==1)
	lab var decmakingscale_below "Dummy=1 if decision making scale below median"
	drop tmp
drop decmakingsample

***  socio-economic ladder (oprobit of fu_ladder_self_barangay fu_ladder_self_philippines fu_ladder_creditworthiness)
gen se_ladder_b=fu_ladder_self_barangay
gen se_ladder_p=fu_ladder_self_philippines
gen credit_ladder=fu_ladder_creditworthiness

***  index
gen ioptimism=optimism if sample==1
	for X in num 0 1: quietly sum optimism if lower_window==1 & css_loandecision==X & sample==1 \ replace ioptimism=r(mean) if ioptimism>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum optimism if lower_window!=1 & css_loandecision==X & sample==1 \ replace ioptimism=r(mean) if ioptimism>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum ioptimism if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_ioptimism=(ioptimism-r(mean))/r(sd) if lower_window==1
	quietly sum ioptimism if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_ioptimism=(ioptimism-r(mean))/r(sd) if lower_window!=1
	lab var ioptimism "standardized 'optimism' dummy for subjective well-being index"
	drop ioptimism
	gen ioptimism=optimism if !mi(optimism)
	lab var ioptimism "unstandardized 'optimism' dummy (subjective well-being index)"
gen inoworry=noworry if sample==1
	for X in num 0 1: quietly sum noworry if lower_window==1 & css_loandecision==X & sample==1 \ replace inoworry=r(mean) if inoworry>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum noworry if lower_window!=1 & css_loandecision==X & sample==1 \ replace inoworry=r(mean) if inoworry>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum inoworry if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_inoworry=(inoworry-r(mean))/r(sd) if lower_window==1
	quietly sum inoworry if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_inoworry=(inoworry-r(mean))/r(sd) if lower_window!=1
	lab var inoworry "standardized 'no worry' dummy for subjective well-being index"
	drop inoworry
	gen inoworry=noworry if !mi(noworry)
	lab var inoworry "unstandardized 'no worry' dummy (subjective well-being index)"
gen icalm=calm if sample==1
	for X in num 0 1: quietly sum calm if lower_window==1 & css_loandecision==X & sample==1 \ replace icalm=r(mean) if icalm>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum calm if lower_window!=1 & css_loandecision==X & sample==1 \ replace icalm=r(mean) if icalm>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum icalm if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_icalm=(icalm-r(mean))/r(sd) if lower_window==1
	quietly sum icalm if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_icalm=(icalm-r(mean))/r(sd) if lower_window!=1
	lab var icalm "standardized 'calmness' dummy for subjective well-being index"
	drop icalm
	gen icalm=calm if !mi(calm)
	lab var icalm "unstandardized 'calmness' dummy (subjective well-being)"
gen ilife_satisfied=life_satisfied if sample==1
	for X in num 0 1: quietly sum life_satisfied if lower_window==1 & css_loandecision==X & sample==1 \ replace ilife_satisfied=r(mean) if ilife_satisfied>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum life_satisfied if lower_window!=1 & css_loandecision==X & sample==1 \ replace ilife_satisfied=r(mean) if ilife_satisfied>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum ilife_satisfied if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_ilife_satisfied=(ilife_satisfied-r(mean))/r(sd) if lower_window==1
	quietly sum ilife_satisfied if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_ilife_satisfied=(ilife_satisfied-r(mean))/r(sd) if lower_window!=1
	lab var ilife_satisfied "standardized 'life_satisfied' dummy for subjective well-being index"
	drop ilife_satisfied
	gen ilife_satisfied=life_satisfied if !mi(life_satisfied)
	lab var ilife_satisfied "unstandardized 'life_satisfied' dummy (subjective well-being index)"
gen ijob_satisfied=job_satisfied if sample==1
	for X in num 0 1: quietly sum job_satisfied if lower_window==1 & css_loandecision==X & sample==1 \ replace ijob_satisfied=r(mean) if ijob_satisfied>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum job_satisfied if lower_window!=1 & css_loandecision==X & sample==1 \ replace ijob_satisfied=r(mean) if ijob_satisfied>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum ijob_satisfied if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_ijob_satisfied=(ijob_satisfied-r(mean))/r(sd) if lower_window==1
	quietly sum ijob_satisfied if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_ijob_satisfied=(ijob_satisfied-r(mean))/r(sd) if lower_window!=1
	lab var ijob_satisfied "standardized 'job_satisfied' dummy for subjective well-being index"
	drop ijob_satisfied
	gen ijob_satisfied=job_satisfied if !mi(job_satisfied)
	lab var ijob_satisfied "unstandardized 'job_satisfied' dummy (subjective well-being index)"
gen inojobstress=nojobstress if sample==1
	for X in num 0 1: quietly sum nojobstress if lower_window==1 & css_loandecision==X & sample==1 \ replace inojobstress=r(mean) if inojobstress>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum nojobstress if lower_window!=1 & css_loandecision==X & sample==1 \ replace inojobstress=r(mean) if inojobstress>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum inojobstress if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_inojobstress=(inojobstress-r(mean))/r(sd) if lower_window==1
	quietly sum inojobstress if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_inojobstress=(inojobstress-r(mean))/r(sd) if lower_window!=1
	lab var inojobstress "standardized 'nojobstress' dummy for subjective well-being index"
	drop inojobstress
	gen inojobstress=nojobstress if !mi(nojobstress)
	lab var inojobstress "unstandardized 'nojobstress' dummy (subjective well-being index)"
gen idecmakingscale=decmakingscale if sample==1
	for X in num 0 1: quietly sum decmakingscale if lower_window==1 & css_loandecision==X & sample==1 & (fu_hh_marriage_1==2 | fu_hh_marriage_1==4) \ replace idecmakingscale=r(mean) if idecmakingscale>=. & lower_window==1 & css_loandecision==X & sample==1 
	for X in num 0 1: quietly sum decmakingscale if lower_window!=1 & css_loandecision==X & sample==1 & (fu_hh_marriage_1==2 | fu_hh_marriage_1==4) \ replace idecmakingscale=r(mean) if idecmakingscale>=. & lower_window!=1 & css_loandecision==X & sample==1 
	replace idecmakingscale=0 if !(fu_hh_marriage_1==2 | fu_hh_marriage_1==4) & fu_hh_marriage_1!=. & sample==1
	quietly sum idecmakingscale if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_idecmakingscale=(idecmakingscale-r(mean))/r(sd) if lower_window==1
	quietly sum idecmakingscale if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_idecmakingscale=(idecmakingscale-r(mean))/r(sd) if lower_window!=1
	lab var idecmakingscale "standardized 'decmakingscale' dummy for subjective well-being index"
	note std_idecmakingscale: Non-married people were assigned a 0 on index after imputation (imputation done with married/partnered(live-in) respondents only).
	drop idecmakingscale
	gen idecmakingscale=decmakingscale if !mi(decmakingscale)
	lab var idecmakingscale "unstandardized 'decmakingscale' dummy (subjective well-being index)"
gen ise_ladder_b=se_ladder_b if sample==1
	for X in num 0 1: quietly sum se_ladder_b if lower_window==1 & css_loandecision==X & sample==1 \ replace ise_ladder_b=r(mean) if ise_ladder_b>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum se_ladder_b if lower_window!=1 & css_loandecision==X & sample==1 \ replace ise_ladder_b=r(mean) if ise_ladder_b>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum ise_ladder_b if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_ise_ladder_b=(ise_ladder_b-r(mean))/r(sd) if lower_window==1
	quietly sum ise_ladder_b if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_ise_ladder_b=(ise_ladder_b-r(mean))/r(sd) if lower_window!=1
	lab var ise_ladder_b "standardized 'se_ladder_b' dummy for subjective well-being index"
	drop ise_ladder_b
	gen ise_ladder_b=se_ladder_b if !mi(se_ladder_b)
	lab var ise_ladder_b "unstandardized 'se_ladder_b' dummy (subjective well-being index)"
gen ise_ladder_p=se_ladder_p if sample==1
	for X in num 0 1: quietly sum se_ladder_p if lower_window==1 & css_loandecision==X & sample==1 \ replace ise_ladder_p=r(mean) if ise_ladder_p>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum se_ladder_p if lower_window!=1 & css_loandecision==X & sample==1 \ replace ise_ladder_p=r(mean) if ise_ladder_p>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum ise_ladder_p if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_ise_ladder_p=(ise_ladder_p-r(mean))/r(sd) if lower_window==1
	quietly sum ise_ladder_p if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_ise_ladder_p=(ise_ladder_p-r(mean))/r(sd) if lower_window!=1
	lab var ise_ladder_p "standardized 'se_ladder_p' dummy for subjective well-being index"
	drop ise_ladder_p
	gen ise_ladder_p=se_ladder_p if !mi(se_ladder_p)
	lab var ise_ladder_p "unstandardized 'se_ladder_p' dummy (subjective well-being index)"
gen iwellb=(std_ioptimism+std_inoworry+std_icalm+std_ilife_satisfied+std_ijob_satisfied+std_inojobstress+std_idecmakingscale+std_ise_ladder_b+std_ise_ladder_p)/9
	lab var iwellb "Unweighted subjective well-being index"

capture: log on

***  life satisfaction
xi: reg life_satisfied css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg life_satisfied css_loandecision css_creditscorefinal_hl x_creditscore_high i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg life_satisfied css_loandecision css_creditscorefinal x_creditscorefinal i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\fmb_science_theory_wellb_life_CS.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2)(3)) lab collabels(,none)
keep(css_loandecision x_creditscore_high x_creditscorefinal )
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  job stress
xi: reg nojobstress css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg nojobstress css_loandecision css_creditscorefinal_hl x_creditscore_high i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg nojobstress css_loandecision css_creditscorefinal x_creditscorefinal i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\fmb_science_theory_wellb_job_CS.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2)(3)) lab collabels(,none)
keep(css_loandecision x_creditscore_high x_creditscorefinal  )
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  index
xi: reg iwellb css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg iwellb css_loandecision css_creditscorefinal_hl x_creditscore_high i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg iwellb css_loandecision css_creditscorefinal x_creditscorefinal i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\fmb_science_theory_wellb_ind_CS.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) lab collabels(,none)
keep(css_loandecision x_creditscore_high x_creditscorefinal )
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

foreach x in life_satisfied nojobstress iwellb {
	sum `x' if sample==1 & css_loandecision==0
	sum `x'	if sample==1 & css_loandecision==0 & css_creditscorefinal_hl ==0
	sum `x'	if sample==1 & css_loandecision==0 & css_creditscorefinal_hl ==1
}

capture: log close





***************************

***************************************************************************************************************************************
*** created by Henriette Hanicotte (based on kareem haggag do files); last modified Feb, 6th, 2011                                  ***
*** for data analysis of impact of credit access study at First Macro Bank (philippines)                                            ***
*** other household investments and risk management                                                                                 ***
***                                                                                                                                 ***
*** files used:                                                                                                                     ***
***    fmbfinaldata.dta                                                                                                             ***
***************************************************************************************************************************************

clear
set more off
set mem 400m
*set maxvar 10000
capture log close
tempfile fu_loan_amount

use fmbfinaldata, clear

***
***  splits
***


gen css_creditscorefinal_hl=.
replace css_creditscorefinal_hl=0 if css_creditscorefinal < 46		// low creditscore
replace css_creditscorefinal_hl=1 if css_creditscorefinal >= 46		// high creditscore
gen x_creditscore_high= css_creditscorefinal_hl * css_loandecision  if sample ==1
gen x_creditscorefinal = css_creditscorefinal  * css_loandecision  if sample ==1



***
***  tables -- financial instruments
***

***  dummy for any savings
gen have_savings=fu_savings if sample==1
lab var have_savings "Do you or anyone in household have money set aside as savings in a bank/house/paluwagan?"

***  health insurance?
gen health_insurance=0 if sample==1
replace health_insurance=. if fu_hh_h_ins_ph>=. & fu_hh_h_ins_hmo>=. & fu_hh_h_ins_other==""
replace health_insurance=1 if (fu_hh_h_ins_ph==1 |  fu_hh_h_ins_hmo==1 |  (fu_hh_h_ins_other!="" & fu_hh_h_ins_other!="1" & fu_hh_h_ins_other!="2")) & sample==1

***  other insurance?
gen other_insurance=0 if sample==1
replace other_insurance=. if  fu_hh_life_ins==. & fu_hh_fire_ins==. & fu_hh_home_ins==. & fu_hh_business_ins==. & fu_hh_prop_ins==. & fu_hh_car_ins==. &  fu_hh_other_ins==.
replace other_insurance=1 if (fu_hh_life_ins==1 | fu_hh_fire_ins==1 | fu_hh_home_ins==1 | fu_hh_business_ins==1 | fu_hh_prop_ins==1 | fu_hh_car_ins==1 |  fu_hh_other_ins==1) & sample==1

log using fmb_science_practice_byCS.log, replace

***  health insurance
xi: reg health_insurance css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg health_insurance css_loandecision css_creditscorefinal_hl x_creditscore_high i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg health_insurance css_loandecision css_creditscorefinal x_creditscorefinal i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\fmb_science_practice_ins_health_CS.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_creditscore_high x_creditscorefinal )
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  other insurance
xi: reg other_insurance css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg other_insurance css_loandecision css_creditscorefinal_hl x_creditscore_high i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg other_insurance css_loandecision css_creditscorefinal x_creditscorefinal i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\fmb_science_practice_ins_other_CS.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_creditscore_high x_creditscorefinal )
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  have savings?
xi: reg have_savings css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg have_savings css_loandecision css_creditscorefinal_hl x_creditscore_high i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg have_savings css_loandecision css_creditscorefinal x_creditscorefinal i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\fmb_science_practice_savings_CS.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2)) label collabels(,none)
keep(css_loandecision x_creditscore_high x_creditscorefinal  )
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

foreach x in health_insurance other_insurance have_savings {
	sum `x' if sample==1 & css_loandecision==0
	sum `x' if sample==1 & css_loandecision==0 & css_creditscorefinal_hl ==0
	sum `x' if sample==1 & css_loandecision==0 & css_creditscorefinal_hl ==1
}

capture: log off

***
***  tables -- family/community networks
***

***  standardize trust questions so that higher number = more trust**
foreach x in fu_trust_groups_family fu_trust_groups_neighborhood fu_trust_groups_know_personally fu_trust_groups_business_assoc {
	replace `x'=-`x'
}
***  now -4=Do Not Trust At All, -1=Trust Completely

gen theor_get_loan=fu_theor_loan_fr_fam if fu_theor_loan_fr_fam<. & sample==1  
lab var theor_get_loan "In an emergency, could get loan from friends or relatives"
replace theor_get_loan=1 if fu_theor_loan_fr_fam_amt<. & sample==1

gen theor_get_loan_lots=0 if (fu_theor_loan_fr_fam<. | fu_theor_loan_fr_fam_amt<.) & sample==1
lab var theor_get_loan_lots "In an emergency, could get large amt from friends or relatives"
replace theor_get_loan_lots=1 if (fu_theor_loan_fr_fam_amt==1 | (fu_theor_loan_fr_fam_amt>=10000 & fu_theor_loan_fr_fam_amt<.)) & sample==1

gen theor_get_loan_any=0 if (fu_theor_loan_fr_fam<. | fu_theor_loan_fr_fam_amt<.) & sample==1
lab var theor_get_loan_any "In an emergency, could get any amt from friends or relatives"
replace theor_get_loan_any=1 if fu_theor_loan_fr_fam_amt==1 & sample==1

capture: log on

***  trust people take advantage of you
oprobit fu_trust_take_advantage css_loandecision lower_window if sample==1, robust
estimates store m1, title((1))
oprobit fu_trust_take_advantage css_loandecision css_creditscorefinal_hl x_creditscore_high lower_window if sample==1, robust
estimates store m2, title((2))
oprobit fu_trust_take_advantage css_loandecision css_creditscorefinal x_creditscorefinal  lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\fmb_science_practice_trust_advantage_CS.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_creditscore_high x_creditscorefinal )
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  trust people in neighborhood
oprobit fu_trust_groups_neighborhood css_loandecision lower_window if sample==1, robust
estimates store m1, title((1))
oprobit fu_trust_groups_neighborhood css_loandecision css_creditscorefinal_hl x_creditscore_high lower_window if sample==1, robust
estimates store m2, title((2))
oprobit fu_trust_groups_neighborhood css_loandecision css_creditscorefinal x_creditscorefinal lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\fmb_science_practice_trust_hood_CS.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_creditscore_high x_creditscorefinal )
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  trust people you know personally
oprobit fu_trust_groups_know_personally css_loandecision lower_window if sample==1, robust
estimates store m1, title((1))
oprobit fu_trust_groups_know_personally css_loandecision css_creditscorefinal_hl x_creditscore_high lower_window if sample==1, robust
estimates store m2, title((2))
oprobit fu_trust_groups_know_personally css_loandecision css_creditscorefinal x_creditscorefinal lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\fmb_science_practice_trust_personally_CS.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2)(3)) label collabels(,none)
keep(css_loandecision x_creditscore_high x_creditscorefinal )
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  trust business associates
oprobit fu_trust_groups_business_assoc css_loandecision lower_window if sample==1, robust
estimates store m1, title((1))
oprobit fu_trust_groups_business_assoc css_loandecision css_creditscorefinal_hl x_creditscore_high lower_window if sample==1, robust
estimates store m2, title((2))
oprobit fu_trust_groups_business_assoc css_loandecision css_creditscorefinal x_creditscorefinal lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\fmb_science_practice_trust_bizCS.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_creditscore_high x_creditscorefinal )
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

foreach x in fu_trust_take_advantage fu_trust_groups_neighborhood fu_trust_groups_know_personally fu_trust_groups_business_assoc {
	sum `x' if sample==1 & css_loandecision==0
	sum `x'	if sample==1 & css_loandecision==0 & css_creditscorefinal_hl ==0
	sum `x' if sample==1 & css_loandecision==0 & css_creditscorefinal_hl ==1
}

***  can get assistance
xi: reg theor_get_loan css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg theor_get_loan css_loandecision css_creditscorefinal_hl x_creditscore_high i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg theor_get_loan css_loandecision css_creditscorefinal x_creditscorefinal i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\fmb_science_practice_theor_loan_CS.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_creditscore_high x_creditscorefinal )
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  can get 10,000 plus
xi: reg theor_get_loan_lots css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg theor_get_loan_lots css_loandecision css_creditscorefinal_hl x_creditscore_high i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg theor_get_loan_lots css_loandecision css_creditscorefinal x_creditscorefinal i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\fmb_science_practice_theor_lots_CS.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_creditscore_high x_creditscorefinal )
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  can get any
xi: reg theor_get_loan_any css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg theor_get_loan_any css_loandecision css_creditscorefinal_hl x_creditscore_high i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg theor_get_loan_any css_loandecision css_creditscorefinal x_creditscorefinal i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\fmb_science_practice_theor_any_CS.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_creditscore_high x_creditscorefinal  )
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

foreach x in theor_get_loan theor_get_loan_lots theor_get_loan_any {
	sum `x' if sample==1 & css_loandecision==0
	sum `x'	if sample==1 & css_loandecision==0 & css_creditscorefinal_hl ==0
	sum `x' if sample==1 & css_loandecision==0 & css_creditscorefinal_hl ==1
}

capture: log close

******************************




**************************************************************************************************************************************
*** created by luke crowley, february 27th, 2009; last modified april 29th, 2010                                                    ***
*** for data analysis of impact of credit access study at First Macro Bank (philippines)                                            ***
*** borrowing in 12 months before survey                                                                                            ***
***                                                                                                                                 ***
*** files used:                                                                                                                     ***
***    fmbfinaldata.dta                                                                                                             ***
***************************************************************************************************************************************

clear
set more off
set mem 400m
set maxvar 10000
capture log close
tempfile fu_loan_amount

use fmbfinaldata, clear

***
***  splits
***

***  Median income at time of application
egen medinc_app=median(css_netweeklyamt) if sample==1 
gen above_medinc_app=0 if sample==1
lab var above_medinc_app "Above median income at time of application"
replace above_medinc_app=1 if css_netweeklyamt>medinc_app & sample==1

gen male=female
recode male (0=1) (1=0)
gen x_male_decision=male*css_loandecision if sample==1
gen x_above_med_inc_decision=above_medinc_app*css_loandecision if sample==1

***
***  tables
***

log using fmb_at1_X.log, replace

***  last 12 months -- all -- formal

xi: reg loans_form_dum_12_ms css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_form_dum_12_ms css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_form_dum_12_ms css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_formal_12m_a_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg loans_form_numb_12_ms css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_form_numb_12_ms css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_form_numb_12_ms css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_formal_12m_b_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

foreach x in loans_form_dum_12_ms loans_form_numb_12_ms {
	sum `x' if sample==1
	sum `x' if sample==1 & female==1
	sum `x' if sample==1 & female==0
	sum `x' if sample==1 & above_medinc_app==1
	sum `x' if sample==1 & above_medinc_app==0
}

***  last 12 months -- all -- informal

xi: reg loans_inform_dum_12_ms css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_inform_dum_12_ms css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_inform_dum_12_ms css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_informal_12m_a_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg loans_inform_numb_12_ms css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_inform_numb_12_ms css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_inform_numb_12_ms css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_informal_12m_b_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

foreach x in loans_inform_dum_12_ms loans_inform_numb_12_ms {
	sum `x' if sample==1
	sum `x' if sample==1 & female==1
	sum `x' if sample==1 & female==0
	sum `x' if sample==1 & above_medinc_app==1
	sum `x' if sample==1 & above_medinc_app==0
}

***  last 12 months -- all -- any

xi: reg loans_any_dum_12_ms css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_any_dum_12_ms css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_any_dum_12_ms css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_any_12m_a_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg loans_any_numb_12_ms css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_any_numb_12_ms css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_any_numb_12_ms css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_any_12m_b_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

foreach x in loans_any_dum_12_ms loans_any_numb_12_ms {
	sum `x' if sample==1
	sum `x' if sample==1 & female==1
	sum `x' if sample==1 & female==0
	sum `x' if sample==1 & above_medinc_app==1
	sum `x' if sample==1 & above_medinc_app==0
}

***  Any loan denied -- last 12 months

xi: reg fu_loan_denied css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg fu_loan_denied css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg fu_loan_denied css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_any_denied_12m_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

sum fu_loan_denied if sample==1
sum fu_loan_denied if sample==1 & female==1
sum fu_loan_denied if sample==1 & female==0
sum fu_loan_denied if sample==1 & above_medinc_app==1
sum fu_loan_denied if sample==1 & above_medinc_app==0

capture: log close

***************************



***************************************************************************************************************************************
*** created by luke crowley, february 27th, 2009; last modified april 29th, 2010                                                    ***
*** for data analysis of impact of credit access study at First Macro Bank (philippines)                                            ***
*** borrowing in month before survey                                                                                                ***
***                                                                                                                                 ***
*** files used:                                                                                                                     ***
***    fmbfinaldata.dta                                                                                                             ***
***************************************************************************************************************************************

clear
set more off
set mem 400m
set maxvar 10000
capture log close
tempfile fu_loan_amount

use fmbfinaldata, clear

***
***  splits
***

***  Median income at time of application
egen medinc_app=median(css_netweeklyamt) if sample==1 
gen above_medinc_app=0 if sample==1
lab var above_medinc_app "Above median income at time of application"
replace above_medinc_app=1 if css_netweeklyamt>medinc_app & sample==1

gen male=female
recode male (0=1) (1=0)
gen x_male_decision=male*css_loandecision if sample==1
gen x_above_med_inc_decision=above_medinc_app*css_loandecision if sample==1

***
***  create indexes 
***

***  last month -- all -- similar to FMB 1, from competitors data with exact matches to FMB 

gen i_simfmb_dum=loans_form_simfmb_dum_m_c if sample==1
for X in num 0 1: quietly sum loans_form_simfmb_dum_m_c if lower_window==1 & css_loandecision==X & sample==1 \ replace i_simfmb_dum=r(mean) if i_simfmb_dum>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_form_simfmb_dum_m_c if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_simfmb_dum=r(mean) if i_simfmb_dum>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_simfmb_dum if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_simfmb_dum=(i_simfmb_dum-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_simfmb_dum if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_simfmb_dum=(i_simfmb_dum-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_simfmb_dum "standardized 'any business' dummy for 'simfmb' for business index"
drop i_simfmb_dum 
gen i_simfmb_dum=loans_form_simfmb_dum_m_c if !mi(loans_form_simfmb_dum_m_c) & sample==1
lab var i_simfmb_dum "unstandardized 'any business' dummy for 'simfmb' (business index)"

gen i_simfmb_before=loans_simfmb_before_m_c if sample==1
for X in num 0 1: quietly sum loans_simfmb_before_m_c if lower_window==1 & css_loandecision==X & sample==1 \ replace i_simfmb_before=r(mean) if i_simfmb_before>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_simfmb_before_m_c if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_simfmb_before=r(mean) if i_simfmb_before>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_simfmb_before if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_simfmb_before=(i_simfmb_before-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_simfmb_before if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_simfmb_before=(i_simfmb_before-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_simfmb_before "standardized 'level amount' for 'simfmb' for business index"
drop i_simfmb_before 
gen i_simfmb_before=loans_simfmb_before_m_c if !mi(loans_simfmb_before_m_c) & sample==1
lab var i_simfmb_before "unstandardized 'level amount' for 'simfmb' (business index)"

gen i_simfmb_numb=loans_form_simfmb_numb_m_c if sample==1
for X in num 0 1: quietly sum loans_form_simfmb_numb_m_c if lower_window==1 & css_loandecision==X & sample==1 \ replace i_simfmb_numb=r(mean) if i_simfmb_numb>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_form_simfmb_numb_m_c if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_simfmb_numb=r(mean) if i_simfmb_numb>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_simfmb_numb if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_simfmb_numb=(i_simfmb_numb-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_simfmb_numb if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_simfmb_numb=(i_simfmb_numb-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_simfmb_numb "standardized 'number loans' for 'simfmb' for business index"
drop i_simfmb_numb
gen i_simfmb_numb=loans_form_simfmb_numb_m_c if !mi(loans_form_simfmb_numb_m_c) & sample==1
lab var i_simfmb_numb "unstandardized 'number loans' for 'simfmb' (business index)"

gen i_simfmb=(std_i_simfmb_dum+std_i_simfmb_before+std_i_simfmb_numb)/3
lab var i_simfmb "Unweighted simfmb index"
*replace i_simfmb=. if loans_form_simfmb_dum_m_c==. & loans_simfmb_before_m_c==. & loans_form_simfmb_numb_m_c==.

***  last month -- all -- formal

gen i_form_dum=loans_form_dum_m if sample==1
for X in num 0 1: quietly sum loans_form_dum_m if lower_window==1 & css_loandecision==X & sample==1 \ replace i_form_dum=r(mean) if i_form_dum>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_form_dum_m if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_form_dum=r(mean) if i_form_dum>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_form_dum if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_form_dum=(i_form_dum-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_form_dum if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_form_dum=(i_form_dum-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_form_dum "standardized 'any business' dummy for 'formal' for business index"
drop i_form_dum 
gen i_form_dum=loans_form_dum_m if !mi(loans_form_dum_m) & sample==1
lab var i_form_dum "unstandardized 'any business' dummy for 'formal' (business index)"

gen i_form_before=loans_form_before_m if sample==1
for X in num 0 1: quietly sum loans_form_before_m if lower_window==1 & css_loandecision==X & sample==1 \ replace i_form_before=r(mean) if i_form_before>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_form_before_m if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_form_before=r(mean) if i_form_before>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_form_before if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_form_before=(i_form_before-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_form_before if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_form_before=(i_form_before-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_form_before "standardized 'level amount' for 'formal' for business index"
drop i_form_before 
gen i_form_before=loans_form_before_m if !mi(loans_form_before_m) & sample==1
lab var i_form_before "unstandardized 'level amount' for 'formal' (business index)"

gen i_form_numb=loans_form_numb_m if sample==1
for X in num 0 1: quietly sum loans_form_numb_m if lower_window==1 & css_loandecision==X & sample==1 \ replace i_form_numb=r(mean) if i_form_numb>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_form_numb_m if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_form_numb=r(mean) if i_form_numb>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_form_numb if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_form_numb=(i_form_numb-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_form_numb if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_form_numb=(i_form_numb-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_form_numb "standardized 'number loans' for 'formal' for business index"
drop i_form_numb
gen i_form_numb=loans_form_numb_m if !mi(loans_form_numb_m) & sample==1
lab var i_form_numb "unstandardized 'number loans' for 'formal' (business index)"

gen i_form=(std_i_form_dum+std_i_form_before+std_i_form_numb)/3
lab var i_form "Unweighted formal index"
*replace i_form=. if loans_form_dum_m==. & loans_form_before_m==. & loans_form_numb_m==.

***  last month -- all -- informal

gen i_inform_dum=loans_inform_dum_m if sample==1
for X in num 0 1: quietly sum loans_inform_dum_m if lower_window==1 & css_loandecision==X & sample==1 \ replace i_inform_dum=r(mean) if i_inform_dum>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_inform_dum_m if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_inform_dum=r(mean) if i_inform_dum>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_inform_dum if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_inform_dum=(i_inform_dum-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_inform_dum if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_inform_dum=(i_inform_dum-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_inform_dum "standardized 'any business' dummy for 'informal' for business index"
drop i_inform_dum 
gen i_inform_dum=loans_inform_dum_m if !mi(loans_inform_dum_m) & sample==1
lab var i_inform_dum "unstandardized 'any business' dummy for 'informal' (business index)"

gen i_inform_before=loans_inform_before_m if sample==1
for X in num 0 1: quietly sum loans_inform_before_m if lower_window==1 & css_loandecision==X & sample==1 \ replace i_inform_before=r(mean) if i_inform_before>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_inform_before_m if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_inform_before=r(mean) if i_inform_before>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_inform_before if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_inform_before=(i_inform_before-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_inform_before if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_inform_before=(i_inform_before-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_inform_before "standardized 'level amount' for 'informal' for business index"
drop i_inform_before 
gen i_inform_before=loans_inform_before_m if !mi(loans_inform_before_m) & sample==1
lab var i_inform_before "unstandardized 'level amount' for 'informal' (business index)"

gen i_inform_numb=loans_inform_numb_m if sample==1
for X in num 0 1: quietly sum loans_inform_numb_m if lower_window==1 & css_loandecision==X & sample==1 \ replace i_inform_numb=r(mean) if i_inform_numb>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_inform_numb_m if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_inform_numb=r(mean) if i_inform_numb>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_inform_numb if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_inform_numb=(i_inform_numb-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_inform_numb if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_inform_numb=(i_inform_numb-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_inform_numb "standardized 'number loans' for 'informal' for business index"
drop i_inform_numb
gen i_inform_numb=loans_inform_numb_m if !mi(loans_inform_numb_m) & sample==1
lab var i_inform_numb "unstandardized 'number loans' for 'informal' (business index)"

gen i_inform=(std_i_inform_dum+std_i_inform_before+std_i_inform_numb)/3
lab var i_inform "Unweighted informal index"
*replace i_inform=. if loans_inform_dum_m==. & loans_inform_before_m==. & loans_inform_numb_m==.

***  last month -- all -- any

gen i_any_dum=loans_any_dum_m if sample==1
for X in num 0 1: quietly sum loans_any_dum_m if lower_window==1 & css_loandecision==X & sample==1 \ replace i_any_dum=r(mean) if i_any_dum>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_any_dum_m if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_any_dum=r(mean) if i_any_dum>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_any_dum if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_any_dum=(i_any_dum-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_any_dum if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_any_dum=(i_any_dum-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_any_dum "standardized 'any business' dummy for 'any' for business index"
drop i_any_dum 
gen i_any_dum=loans_any_dum_m if !mi(loans_any_dum_m) & sample==1
lab var i_any_dum "unstandardized 'any business' dummy for 'any' (business index)"

gen i_any_before=loans_any_before_m if sample==1
for X in num 0 1: quietly sum loans_any_before_m if lower_window==1 & css_loandecision==X & sample==1 \ replace i_any_before=r(mean) if i_any_before>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_any_before_m if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_any_before=r(mean) if i_any_before>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_any_before if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_any_before=(i_any_before-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_any_before if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_any_before=(i_any_before-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_any_before "standardized 'level amount' for 'any' for business index"
drop i_any_before 
gen i_any_before=loans_any_before_m if !mi(loans_any_before_m) & sample==1
lab var i_any_before "unstandardized 'level amount' for 'any' (business index)"

gen i_any_numb=loans_any_numb_m if sample==1
for X in num 0 1: quietly sum loans_any_numb_m if lower_window==1 & css_loandecision==X & sample==1 \ replace i_any_numb=r(mean) if i_any_numb>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_any_numb_m if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_any_numb=r(mean) if i_any_numb>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_any_numb if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_any_numb=(i_any_numb-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_any_numb if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_any_numb=(i_any_numb-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_any_numb "standardized 'number loans' for 'any' for business index"
drop i_any_numb
gen i_any_numb=loans_any_numb_m if !mi(loans_any_numb_m) & sample==1
lab var i_any_numb "unstandardized 'number loans' for 'any' (business index)"

gen i_any=(std_i_any_dum+std_i_any_before+std_i_any_numb)/3
lab var i_any "Unweighted any index"
*replace i_any=. if loans_any_dum_m==. & loans_any_before_m==. & loans_any_numb_m==.

***
***  tables
***

log using fmb_at2_X.log, replace

***  last month -- all -- similar to FMB 1, from competitors data with exact matches to FMB 

xi: reg loans_form_simfmb_dum_m_c css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_form_simfmb_dum_m_c css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_form_simfmb_dum_m_c css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_simfmb1_a_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg loans_simfmb_before_m_c css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_simfmb_before_m_c css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_simfmb_before_m_c css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_simfmb1_b_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg loans_form_simfmb_numb_m_c css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_form_simfmb_numb_m_c css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_form_simfmb_numb_m_c css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_simfmb2_a_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg i_simfmb css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg i_simfmb css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg i_simfmb css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_simfmb2_b_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

foreach x in loans_form_simfmb_dum_m_c loans_simfmb_before_m_c loans_form_simfmb_numb_m_c i_simfmb {
	sum `x' if sample==1
	sum `x' if sample==1 & female==1
	sum `x' if sample==1 & female==0
	sum `x' if sample==1 & above_medinc_app==1
	sum `x' if sample==1 & above_medinc_app==0
}

***  last month -- all -- formal

xi: reg loans_form_dum_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_form_dum_m css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_form_dum_m css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_formal1_a_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg loans_form_before_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_form_before_m css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_form_before_m css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_formal1_b_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg loans_form_numb_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_form_numb_m css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_form_numb_m css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_formal2_a_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg i_form css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg i_form css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg i_form css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_formal2_b_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

foreach x in loans_form_dum_m loans_form_before_m loans_form_numb_m i_form {
	sum `x' if sample==1
	sum `x' if sample==1 & female==1
	sum `x' if sample==1 & female==0
	sum `x' if sample==1 & above_medinc_app==1
	sum `x' if sample==1 & above_medinc_app==0
}

***  last month -- all -- informal

xi: reg loans_inform_dum_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_inform_dum_m css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_inform_dum_m css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_informal1_a_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg loans_inform_before_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_inform_before_m css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_inform_before_m css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_informal1_b_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg loans_inform_numb_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_inform_numb_m css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_inform_numb_m css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_informal2_a_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg i_inform css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg i_inform css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg i_inform css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_informal2_b_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

foreach x in loans_inform_dum_m loans_inform_before_m loans_inform_numb_m i_inform {
	sum `x' if sample==1
	sum `x' if sample==1 & female==1
	sum `x' if sample==1 & female==0
	sum `x' if sample==1 & above_medinc_app==1
	sum `x' if sample==1 & above_medinc_app==0
}

***  last month -- all -- any

xi: reg loans_any_dum_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_any_dum_m css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_any_dum_m css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_any1_a_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg loans_any_before_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_any_before_m css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_any_before_m css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_any1_b_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg loans_any_numb_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_any_numb_m css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_any_numb_m css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_any2_a_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg i_any css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg i_any css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg i_any css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_any2_b_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

foreach x in loans_any_dum_m loans_any_before_m loans_any_numb_m i_any {
	sum `x' if sample==1
	sum `x' if sample==1 & female==1
	sum `x' if sample==1 & female==0
	sum `x' if sample==1 & above_medinc_app==1
	sum `x' if sample==1 & above_medinc_app==0
}

capture: log close

/*
***  Note: 7 observations have missing (missing_m==1) borrowing information:
custid==210262
custid==320866
custid==506860
custid==506943
custid==507027
custid==716839
custid==935192
*/



**********************************


***************************************************************************************************************************************
*** created by henriette hanicotte (based on luke crowley do files), february 5th, 2011								***
*** for data analysis of impact of credit study at First Macro Bank (philippines)                                                   ***
*** orthogonality of treatment to applicant characteristics    
***                                                                     
***                                                                                                                                 ***
*** files used:                                                                                                                     ***
***    fmbfinaldata.dta                                                                                                             ***
***************************************************************************************************************************************

clear
est clear
set more off
set mem 400m
*set maxvar 10000
capture log close

use fmbfinaldata, clear

***  orthogonality check

gen male=0
replace male=1 if female==0
gen employ0=0
gen employ1=0
replace employ0=1 if css_regularcount1==0
replace employ1=1 if css_regularcount1==1
replace edhi=4 if edhi==5

gen yrsbiz_l=ln(css_yearsinbusiness1)
gen cashflow_l=ln(css_netweeklyamt)
gen loan_assigned=css_loandecision if css_branchid!=6 & css_creditscorefinal>=31
gen loan_obtained=0 if css_branchid!=6 & css_creditscorefinal>=31
replace loan_obtained=1 if custacc!="." & css_branchid!=6 & css_creditscorefinal>=31
gen surveyed=0 if css_branchid!=6 & css_creditscorefinal>=31	
replace surveyed=1 if (fu_loans<. | fu_number_loans<. | fu_loans==.b) & (fu_ladder_self_barangay<. | fu_ladder_self_barangay==.b) & css_branchid!=6 & css_creditscorefinal>=31 


log using fmb_science_ortho_att.log, replace


xi: reg loan_assigned male i.css_civilstatus dependents age i.edhi i.css_businesslocation1 i.css_businessspace1 i.css_businesstype1 employ0 employ1 yrsbiz_l cashflow_l lower_window app_month app_year fu_survey_month fu_survey_year if custid!=406710 & custid!=716898 & custid!=899999, robust plus

xi: reg loan_assigned female i.css_civilstatus dependents age i.edhi i.css_businesslocation1 i.css_businessspace1 i.css_businesstype1 employ0 employ1 yrsbiz_l cashflow_l lower_window app_month app_year fu_survey_month fu_survey_year if custid!=406710 & custid!=716898 & custid!=899999, robust plus
xi: reg loan_assigned female i.css_civilstatus dependents age i.edhi i.css_businesslocation1 i.css_businessspace1 i.css_businesstype1 employ0 employ1 yrsbiz_l cashflow_l lower_window app_month app_year fu_survey_month fu_survey_year, robust plus
xi: reg loan_assigned female i.css_civilstatus dependents age i.edhi i.css_businesslocation1 i.css_businessspace1 i.css_businesstype1 employ0 employ1 yrsbiz_l cashflow_l lower_window, robust plus
xi: reg loan_assigned female i.css_civilstatus dependents age i.edhi i.css_businesslocation1 i.css_businessspace1 i.css_businesstype1 employ0 employ1 yrsbiz_l cashflow_l lower_window if custid!=406710 & custid!=716898 & custid!=899999, robust plus
estimates store m1, title((1))

xi: testparm female i.css_civilstatus dependents age i.edhi i.css_businesslocation1 i.css_businessspace1 i.css_businesstype1 employ0 employ1 yrsbiz_l cashflow_l 
xi: reg surveyed css_loandecision lower_window, robust
estimates store m2, title((2))
xi: reg loan_assigned female i.css_civilstatus dependents age i.edhi i.css_businesslocation1 i.css_businessspace1 i.css_businesstype1 employ0 employ1 yrsbiz_l cashflow_l lower_window if surveyed==1, robust
estimates store m3, title((3))
xi: testparm female i.css_civilstatus dependents age i.edhi i.css_businesslocation1 i.css_businessspace1 i.css_businesstype1 employ0 employ1 yrsbiz_l cashflow_l 

#delimit ;
estout * using outreg/estout_orthogonality.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2_p N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(female _Icss_civil_2 _Icss_civil_3 dependents age _Iedhi_2 _Iedhi_3 _Iedhi_4  _Icss_busin_2 _Icss_busin_3 _Icss_busina2 _Icss_busina3 _Icss_businb2 _Icss_businb3 _Icss_businb4 _Icss_businb5 _Icss_businb6 employ0 employ1 yrsbiz_l cashflow_l)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

sum loan_assigned 
sum surveyed 
sum loan_assigned if surveyed==1


***
***attrition
***

xi: reg surveyed female i.css_civilstatus dependents age i.edhi i.css_businesslocation1 i.css_businessspace1 i.css_businesstype1 employ0 employ1 yrsbiz_l cashflow_l lower_window if custid!=406710 & custid!=716898 & custid!=899999, robust plus
estimates store m1, title((1))
xi: testparm female i.css_civilstatus dependents age i.edhi i.css_businesslocation1 i.css_businessspace1 i.css_businesstype1 employ0 employ1 yrsbiz_l cashflow_l 

#delimit ;
estout * using outreg/estout_orthogonality_att.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2_p N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1)) label collabels(,none)
keep(female _Icss_civil_2 _Icss_civil_3 dependents age _Iedhi_2 _Iedhi_3 _Iedhi_4  _Icss_busin_2 _Icss_busin_3 _Icss_busina2 _Icss_busina3 _Icss_businb2 _Icss_businb3 _Icss_businb4 _Icss_businb5 _Icss_businb6 employ0 employ1 yrsbiz_l cashflow_l)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

capture: log off

gen maleT= male*css_loandecision 
gen femaleT= female*css_loandecision 
gen  _Icss_civil_2T =  _Icss_civil_2*css_loandecision 
gen  _Icss_civil_3T =  _Icss_civil_3*css_loandecision 
gen dependentsT= dependents*css_loandecision 
gen ageT= age*css_loandecision 
gen _Iedhi_2T= _Iedhi_2*css_loandecision 
gen _Iedhi_3T= _Iedhi_3*css_loandecision 
gen _Iedhi_4T= _Iedhi_4*css_loandecision 
gen _Icss_busin_2T= _Icss_busin_2*css_loandecision  
gen _Icss_busin_3T= _Icss_busin_3*css_loandecision 
gen _Icss_busina2T= _Icss_busina2*css_loandecision 
gen _Icss_busina3T= _Icss_busina3*css_loandecision 
gen _Icss_businb2T= _Icss_businb2*css_loandecision 
gen _Icss_businb3T= _Icss_businb3*css_loandecision 
gen _Icss_businb4T= _Icss_businb4*css_loandecision 
gen _Icss_businb5T= _Icss_businb5*css_loandecision 
gen _Icss_businb6T= _Icss_businb6*css_loandecision 
gen employ0T= employ0*css_loandecision 
gen employ1T= employ1*css_loandecision 
gen yrsbiz_lT = yrsbiz_l*css_loandecision 
gen cashflow_lT= cashflow_l*css_loandecision  

capture: log on

xi: reg surveyed female i.css_civilstatus dependents age i.edhi i.css_businesslocation1 i.css_businessspace1 i.css_businesstype1 employ0 employ1 yrsbiz_l cashflow_l femaleT  _Icss_civil_2T _Icss_civil_3T dependentsT ageT  _Iedhi_2T _Iedhi_3T _Iedhi_4T _Icss_busin_2T _Icss_busin_3T _Icss_busina2T _Icss_busina3T _Icss_businb2T _Icss_businb3T _Icss_businb4T _Icss_businb5T _Icss_businb6T employ0T employ1T yrsbiz_lT cashflow_lT lower_window if custid!=406710 & custid!=716898 & custid!=899999, robust plus
estimates store m2, title((3))
xi: testparm femaleT  _Icss_civil_2T _Icss_civil_3T dependentsT ageT  _Iedhi_2T _Iedhi_3T _Iedhi_4T _Icss_busin_2T _Icss_busin_3T _Icss_busina2T _Icss_busina3T _Icss_businb2T _Icss_businb3T _Icss_businb4T _Icss_businb5T _Icss_businb6T employ0T employ1T yrsbiz_lT cashflow_lT 

#delimit ;
estout * using outreg/estout_orthogonality_attT.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2_p N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1)) label collabels(,none)
keep(femaleT _Icss_civil_2T _Icss_civil_3T dependentsT ageT _Iedhi_2T _Iedhi_3T _Iedhi_4T  _Icss_busin_2T _Icss_busin_3T _Icss_busina2T _Icss_busina3T _Icss_businb2T _Icss_businb3T _Icss_businb4T _Icss_businb5T _Icss_businb6T employ0T employ1T yrsbiz_lT cashflow_lT)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

sum surveyed 

capture: log close


**************************************


***************************************************************************************************************************************
*** created by luke crowley, april 29th, 2010                                                                                       ***
*** for data analysis of impact of credit access study at First Macro Bank (philippines)                                            ***
*** borrowing in month before survey                                                                                                ***
***                                                                                                                                 ***
*** files used:                                                                                                                     ***
***    fmbfinaldata.dta                                                                                                             ***
***************************************************************************************************************************************

clear
set more off
set mem 400m
set maxvar 10000
capture log close
tempfile fu_loan_amount

use fmbfinaldata, clear

***
***  splits
***

***  Median income at time of application
egen medinc_app=median(css_netweeklyamt) if sample==1 
gen above_medinc_app=0 if sample==1
lab var above_medinc_app "Above median income at time of application"
replace above_medinc_app=1 if css_netweeklyamt>medinc_app & sample==1

gen male=female
recode male (0=1) (1=0)
gen x_male_decision=male*css_loandecision if sample==1
gen x_above_med_inc_decision=above_medinc_app*css_loandecision if sample==1

***
***  create indexes 
***

***  last month -- <= 50,000 filter -- similar to FMB 1, from competitors data with exact matches to FMB 

gen i_simfmb_dum=loans_k50_form_simfmb_dum_m_c if sample==1
for X in num 0 1: quietly sum loans_k50_form_simfmb_dum_m_c if lower_window==1 & css_loandecision==X & sample==1 \ replace i_simfmb_dum=r(mean) if i_simfmb_dum>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_k50_form_simfmb_dum_m_c if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_simfmb_dum=r(mean) if i_simfmb_dum>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_simfmb_dum if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_simfmb_dum=(i_simfmb_dum-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_simfmb_dum if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_simfmb_dum=(i_simfmb_dum-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_simfmb_dum "standardized 'any business' dummy for 'simfmb' for business index"
drop i_simfmb_dum 
gen i_simfmb_dum=loans_k50_form_simfmb_dum_m_c if !mi(loans_k50_form_simfmb_dum_m_c) & sample==1
lab var i_simfmb_dum "unstandardized 'any business' dummy for 'simfmb' (business index)"

gen i_simfmb_before=loans_k50_simfmb_before_m_c if sample==1
for X in num 0 1: quietly sum loans_k50_simfmb_before_m_c if lower_window==1 & css_loandecision==X & sample==1 \ replace i_simfmb_before=r(mean) if i_simfmb_before>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_k50_simfmb_before_m_c if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_simfmb_before=r(mean) if i_simfmb_before>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_simfmb_before if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_simfmb_before=(i_simfmb_before-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_simfmb_before if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_simfmb_before=(i_simfmb_before-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_simfmb_before "standardized 'level amount' for 'simfmb' for business index"
drop i_simfmb_before 
gen i_simfmb_before=loans_k50_simfmb_before_m_c if !mi(loans_k50_simfmb_before_m_c) & sample==1
lab var i_simfmb_before "unstandardized 'level amount' for 'simfmb' (business index)"

gen i_simfmb_numb=loans_k50_form_simfmb_numb_m_c if sample==1
for X in num 0 1: quietly sum loans_k50_form_simfmb_numb_m_c if lower_window==1 & css_loandecision==X & sample==1 \ replace i_simfmb_numb=r(mean) if i_simfmb_numb>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_k50_form_simfmb_numb_m_c if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_simfmb_numb=r(mean) if i_simfmb_numb>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_simfmb_numb if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_simfmb_numb=(i_simfmb_numb-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_simfmb_numb if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_simfmb_numb=(i_simfmb_numb-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_simfmb_numb "standardized 'number loans' for 'simfmb' for business index"
drop i_simfmb_numb
gen i_simfmb_numb=loans_k50_form_simfmb_numb_m_c if !mi(loans_k50_form_simfmb_numb_m_c) & sample==1
lab var i_simfmb_numb "unstandardized 'number loans' for 'simfmb' (business index)"

gen i_simfmb=(std_i_simfmb_dum+std_i_simfmb_before+std_i_simfmb_numb)/3
lab var i_simfmb "Unweighted simfmb index"
*replace i_simfmb=. if loans_k50_form_simfmb_dum_m_c==. & loans_k50_simfmb_before_m_c==. & loans_k50_form_simfmb_numb_m_c==.

***  last month -- <= 50,000 filter -- formal

gen i_form_dum=loans_k50_form_dum_m if sample==1
for X in num 0 1: quietly sum loans_k50_form_dum_m if lower_window==1 & css_loandecision==X & sample==1 \ replace i_form_dum=r(mean) if i_form_dum>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_k50_form_dum_m if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_form_dum=r(mean) if i_form_dum>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_form_dum if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_form_dum=(i_form_dum-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_form_dum if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_form_dum=(i_form_dum-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_form_dum "standardized 'any business' dummy for 'formal' for business index"
drop i_form_dum 
gen i_form_dum=loans_k50_form_dum_m if !mi(loans_k50_form_dum_m) & sample==1
lab var i_form_dum "unstandardized 'any business' dummy for 'formal' (business index)"

gen i_form_before=loans_k50_form_before_m if sample==1
for X in num 0 1: quietly sum loans_k50_form_before_m if lower_window==1 & css_loandecision==X & sample==1 \ replace i_form_before=r(mean) if i_form_before>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_k50_form_before_m if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_form_before=r(mean) if i_form_before>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_form_before if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_form_before=(i_form_before-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_form_before if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_form_before=(i_form_before-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_form_before "standardized 'level amount' for 'formal' for business index"
drop i_form_before 
gen i_form_before=loans_k50_form_before_m if !mi(loans_k50_form_before_m) & sample==1
lab var i_form_before "unstandardized 'level amount' for 'formal' (business index)"

gen i_form_numb=loans_k50_form_numb_m if sample==1
for X in num 0 1: quietly sum loans_k50_form_numb_m if lower_window==1 & css_loandecision==X & sample==1 \ replace i_form_numb=r(mean) if i_form_numb>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_k50_form_numb_m if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_form_numb=r(mean) if i_form_numb>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_form_numb if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_form_numb=(i_form_numb-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_form_numb if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_form_numb=(i_form_numb-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_form_numb "standardized 'number loans' for 'formal' for business index"
drop i_form_numb
gen i_form_numb=loans_k50_form_numb_m if !mi(loans_k50_form_numb_m) & sample==1
lab var i_form_numb "unstandardized 'number loans' for 'formal' (business index)"

gen i_form=(std_i_form_dum+std_i_form_before+std_i_form_numb)/3
lab var i_form "Unweighted formal index"
*replace i_form=. if loans_k50_form_dum_m==. & loans_k50_form_before_m==. & loans_k50_form_numb_m==.

***  last month -- <= 50,000 filter -- informal

gen i_inform_dum=loans_k50_inform_dum_m if sample==1
for X in num 0 1: quietly sum loans_k50_inform_dum_m if lower_window==1 & css_loandecision==X & sample==1 \ replace i_inform_dum=r(mean) if i_inform_dum>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_k50_inform_dum_m if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_inform_dum=r(mean) if i_inform_dum>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_inform_dum if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_inform_dum=(i_inform_dum-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_inform_dum if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_inform_dum=(i_inform_dum-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_inform_dum "standardized 'any business' dummy for 'informal' for business index"
drop i_inform_dum 
gen i_inform_dum=loans_k50_inform_dum_m if !mi(loans_k50_inform_dum_m) & sample==1
lab var i_inform_dum "unstandardized 'any business' dummy for 'informal' (business index)"

gen i_inform_before=loans_k50_inform_before_m if sample==1
for X in num 0 1: quietly sum loans_k50_inform_before_m if lower_window==1 & css_loandecision==X & sample==1 \ replace i_inform_before=r(mean) if i_inform_before>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_k50_inform_before_m if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_inform_before=r(mean) if i_inform_before>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_inform_before if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_inform_before=(i_inform_before-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_inform_before if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_inform_before=(i_inform_before-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_inform_before "standardized 'level amount' for 'informal' for business index"
drop i_inform_before 
gen i_inform_before=loans_k50_inform_before_m if !mi(loans_k50_inform_before_m) & sample==1
lab var i_inform_before "unstandardized 'level amount' for 'informal' (business index)"

gen i_inform_numb=loans_k50_inform_numb_m if sample==1
for X in num 0 1: quietly sum loans_k50_inform_numb_m if lower_window==1 & css_loandecision==X & sample==1 \ replace i_inform_numb=r(mean) if i_inform_numb>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_k50_inform_numb_m if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_inform_numb=r(mean) if i_inform_numb>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_inform_numb if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_inform_numb=(i_inform_numb-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_inform_numb if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_inform_numb=(i_inform_numb-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_inform_numb "standardized 'number loans' for 'informal' for business index"
drop i_inform_numb
gen i_inform_numb=loans_k50_inform_numb_m if !mi(loans_k50_inform_numb_m) & sample==1
lab var i_inform_numb "unstandardized 'number loans' for 'informal' (business index)"

gen i_inform=(std_i_inform_dum+std_i_inform_before+std_i_inform_numb)/3
lab var i_inform "Unweighted informal index"
*replace i_inform=. if loans_k50_inform_dum_m==. & loans_k50_inform_before_m==. & loans_k50_inform_numb_m==.

***  last month -- <= 50,000 filter -- any

gen i_any_dum=loans_k50_any_dum_m if sample==1
for X in num 0 1: quietly sum loans_k50_any_dum_m if lower_window==1 & css_loandecision==X & sample==1 \ replace i_any_dum=r(mean) if i_any_dum>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_k50_any_dum_m if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_any_dum=r(mean) if i_any_dum>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_any_dum if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_any_dum=(i_any_dum-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_any_dum if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_any_dum=(i_any_dum-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_any_dum "standardized 'any business' dummy for 'any' for business index"
drop i_any_dum 
gen i_any_dum=loans_k50_any_dum_m if !mi(loans_k50_any_dum_m) & sample==1
lab var i_any_dum "unstandardized 'any business' dummy for 'any' (business index)"

gen i_any_before=loans_k50_any_before_m if sample==1
for X in num 0 1: quietly sum loans_k50_any_before_m if lower_window==1 & css_loandecision==X & sample==1 \ replace i_any_before=r(mean) if i_any_before>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_k50_any_before_m if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_any_before=r(mean) if i_any_before>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_any_before if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_any_before=(i_any_before-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_any_before if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_any_before=(i_any_before-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_any_before "standardized 'level amount' for 'any' for business index"
drop i_any_before 
gen i_any_before=loans_k50_any_before_m if !mi(loans_k50_any_before_m) & sample==1
lab var i_any_before "unstandardized 'level amount' for 'any' (business index)"

gen i_any_numb=loans_k50_any_numb_m if sample==1
for X in num 0 1: quietly sum loans_k50_any_numb_m if lower_window==1 & css_loandecision==X & sample==1 \ replace i_any_numb=r(mean) if i_any_numb>=. & lower_window==1 & css_loandecision==X & sample==1
for X in num 0 1: quietly sum loans_k50_any_numb_m if lower_window!=1 & css_loandecision==X & sample==1 \ replace i_any_numb=r(mean) if i_any_numb>=. & lower_window!=1 & css_loandecision==X & sample==1
quietly sum i_any_numb if css_loandecision==0 & sample==1 & lower_window==1
gen double std_i_any_numb=(i_any_numb-r(mean))/r(sd) if lower_window==1 & sample==1
quietly sum i_any_numb if css_loandecision==0 & sample==1 & lower_window!=1
replace std_i_any_numb=(i_any_numb-r(mean))/r(sd) if lower_window!=1 & sample==1
lab var i_any_numb "standardized 'number loans' for 'any' for business index"
drop i_any_numb
gen i_any_numb=loans_k50_any_numb_m if !mi(loans_k50_any_numb_m) & sample==1
lab var i_any_numb "unstandardized 'number loans' for 'any' (business index)"

gen i_any=(std_i_any_dum+std_i_any_before+std_i_any_numb)/3
lab var i_any "Unweighted any index"
*replace i_any=. if loans_k50_any_dum_m==. & loans_k50_any_before_m==. & loans_k50_any_numb_m==.

***
***  tables for jz
***

log using fmb_t4_X.log, replace

***  last month -- <= 50,000 filter -- similar to FMB 1, from competitors data with exact matches to FMB 

xi: reg loans_k50_form_simfmb_dum_m_c css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_k50_form_simfmb_dum_m_c css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_k50_form_simfmb_dum_m_c css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_k50_sfmb1_a_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg loans_k50_simfmb_before_m_c css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_k50_simfmb_before_m_c css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_k50_simfmb_before_m_c css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_k50_sfmb1_b_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg loans_k50_form_simfmb_numb_m_c css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_k50_form_simfmb_numb_m_c css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_k50_form_simfmb_numb_m_c css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_k50_sfmb2_a_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg i_simfmb css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg i_simfmb css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg i_simfmb css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_k50_sfmb2_b_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

foreach x in loans_k50_form_simfmb_dum_m_c loans_k50_simfmb_before_m_c loans_k50_form_simfmb_numb_m_c i_simfmb {
	sum `x' if sample==1
	sum `x' if sample==1 & female==1
	sum `x' if sample==1 & female==0
	sum `x' if sample==1 & above_medinc_app==1
	sum `x' if sample==1 & above_medinc_app==0
}

***  last month -- <= 50,000 filter -- formal

xi: reg loans_k50_form_dum_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_k50_form_dum_m css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_k50_form_dum_m css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_k50_form1_a_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg loans_k50_form_before_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_k50_form_before_m css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_k50_form_before_m css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_k50_form1_b_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg loans_k50_form_numb_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_k50_form_numb_m css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_k50_form_numb_m css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_k50_form2_a_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg i_form css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg i_form css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg i_form css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_k50_form2_b_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

foreach x in loans_k50_form_dum_m loans_k50_form_before_m loans_k50_form_numb_m i_form {
	sum `x' if sample==1
	sum `x' if sample==1 & female==1
	sum `x' if sample==1 & female==0
	sum `x' if sample==1 & above_medinc_app==1
	sum `x' if sample==1 & above_medinc_app==0
}

***  last month -- <= 50,000 filter -- informal

xi: reg loans_k50_inform_dum_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_k50_inform_dum_m male x_male_decision css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_k50_inform_dum_m above_medinc_app x_above_med_inc_decision css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_k50_inform1_a_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg loans_k50_inform_before_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_k50_inform_before_m css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_k50_inform_before_m css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_k50_inform1_b_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg loans_k50_inform_numb_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_k50_inform_numb_m css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_k50_inform_numb_m css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_k50_inform2_a_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg i_inform css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg i_inform css_loandecision i.app_month male x_male_decision i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg i_inform css_loandecision i.app_month above_medinc_app x_above_med_inc_decision i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_k50_inform2_b_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

foreach x in loans_k50_inform_dum_m loans_k50_inform_before_m loans_k50_inform_numb_m i_inform {
	sum `x' if sample==1
	sum `x' if sample==1 & female==1
	sum `x' if sample==1 & female==0
	sum `x' if sample==1 & above_medinc_app==1
	sum `x' if sample==1 & above_medinc_app==0
}

***  last month -- <= 50,000 filter -- any

xi: reg loans_k50_any_dum_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_k50_any_dum_m css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_k50_any_dum_m css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_k50_any1_a_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg loans_k50_any_before_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_k50_any_before_m css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_k50_any_before_m css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_k50_any1_b_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg loans_k50_any_numb_m css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg loans_k50_any_numb_m css_loandecision male x_male_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg loans_k50_any_numb_m css_loandecision above_medinc_app x_above_med_inc_decision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_k50_any2_a_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

xi: reg i_any css_loandecision i.app_month i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg i_any css_loandecision i.app_month male x_male_decision i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg i_any css_loandecision i.app_month above_medinc_app x_above_med_inc_decision i.app_year i.fu_survey_month i.fu_survey_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\debtreg_k50_any2_b_X.txt, cells(b(star fmt(%13.3f)) se(par)) stats(r2 N pbar, fmt(%9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

foreach x in loans_k50_any_dum_m loans_k50_any_before_m loans_k50_any_numb_m i_any {
	sum `x' if sample==1
	sum `x' if sample==1 & female==1
	sum `x' if sample==1 & female==0
	sum `x' if sample==1 & above_medinc_app==1
	sum `x' if sample==1 & above_medinc_app==0
}

capture: log close

/*
***  Note: 7 observations have missing (missing_m==1) borrowing information:
custid==210262
custid==320866
custid==506860
custid==506943
custid==507027
custid==716839
custid==935192
*/




***************************************


***************************************************************************************************************************************
*** created by kareem haggag; last modified by luke crowley april 29th, 2010                                                        ***
*** for data analysis of impact of credit access study at First Macro Bank (philippines)                                            ***
*** business outcomes                                                                                                               ***
***                                                                                                                                 ***
*** files used:                                                                                                                     ***
***    fmbfinaldata.dta                                                                                                             ***
***************************************************************************************************************************************

clear
set more off
set mem 400m
set maxvar 10000
capture log close
tempfile fu_loan_amount

use fmbfinaldata, clear

***
***  splits
***

***  Median income at time of application
egen medinc_app=median(css_netweeklyamt) if sample==1 
gen above_medinc_app=0 if sample==1
lab var above_medinc_app "Above median income at time of application"
replace above_medinc_app=1 if css_netweeklyamt>medinc_app & sample==1

gen male=female
recode male (0=1) (1=0)
gen x_male_decision=male*css_loandecision if sample==1
gen x_above_med_inc_decision=above_medinc_app*css_loandecision if sample==1

***  clean business name variable -- set 997 or CLOSED to ""
***  not counting Closed or Temporarily closed businesses

forval x=1/8 {
	replace fu_bus_name_`x'="" if regexm(fu_bus_name_`x',"997")
	replace fu_bus_name_`x'="" if fu_bus_name_`x'=="0"
	replace fu_bus_name_`x'="" if regexm(fu_bus_name_`x',"clo")
}
replace fu_bus_name_1="" if fu_bus_name_1=="nida & lito store (c"
replace fu_bus_name_1="" if fu_bus_name_1=="oleta store (tempora"
replace fu_bus_name_1="" if fu_bus_name_1=="sari-sari store (tem"
replace fu_bus_name_1="" if fu_bus_name_1=="sari-sari (temporary"
replace fu_bus_name_1="" if fu_bus_name_1=="rai rai junk junk (t"

***
***  create variables for biz analysis
***

***  number of businesses
gen noof_business=0 if sample==1
lab var noof_business "Number of Businesses in Household"
for X in any 1 2 3 4 5 6 7 8: replace noof_business=noof_business+1 if fu_bus_name_X!="" & sample==1
gen temp=1 if fu_bus_name_1=="" & fu_bus_name_2=="" & fu_bus_name_3=="" & fu_bus_name_4=="" & fu_bus_name_5=="" & fu_bus_name_6=="" & fu_bus_name_7=="" & fu_bus_name_8==""
replace noof_business=. if temp==1 & sample!=1
drop temp

***  still own a business?
gen any_business=0 if sample==1
replace any_business=1 if noof_business>0 & noof_business<. & sample==1

***  business sales
egen temp=rownonmiss(fu_gross_sales_*)
egen bus_sales=rsum(fu_gross_sales_*) if temp>0 & sample==1
lab var bus_sales "Total sales in last month from households' businesses"
replace bus_sales=0 if noof_business==0 & sample==1
drop temp
xtile pctile_bus_sales=bus_sales if bus_sales<. & sample==1, n(100)
lab var pctile_bus_sales "Percentile of business sales"

***  business profits
egen temp=rownonmiss(fu_profit_*)
egen bus_profit=rsum(fu_profit_*) if temp>0 & sample==1
lab var bus_profit "Total profits in last month from households' businesses"
replace bus_profit=0 if noof_business==0 & sample==1
drop temp
xtile pctile_bus_profit=bus_profit if bus_profit<. & sample==1, n(100)
lab var pctile_bus_profit "Percentile of business profit"

***  business inventory
egen temp=rownonmiss(fu_inventory_*)
egen bus_inventory=rsum(fu_inventory_*) if temp>0 & sample==1
lab var bus_inventory "Total current inventory value from households' businesses"
replace bus_inventory=0 if noof_business==0 & sample==1
drop temp
xtile pctile_bus_inventory=bus_inventory if bus_inventory<. & sample==1, n(100)
lab var pctile_bus_inventory "Percentile of business inventory value"

***  number of helpers
gen noof_helpers=fu_helpers if sample==1
lab var noof_helpers "Number of helpers in HH Businesses - as directly reported"
replace noof_helpers=0 if fu_helpers==.c & sample==1
replace noof_helpers=1 if fu_helpers==. &  fu_helpers_names_1!="" & sample==1
replace noof_helpers=2 if fu_helpers==. &  fu_helpers_names_2!="" & sample==1

***  business owner self-salary
gen self_salary=fu_self_salary_amount_month if sample==1
lab var self_salary "Self salary amount in last month"
replace self_salary=0 if fu_self_salary_amount_month==. & !(fu_self_salary>=.) & sample==1
xtile pctile_self_salary=self_salary if self_salary<. & sample==1, n(100)
lab var pctile_self_salary "Percentile of self salary amount in last month"

***  number of paid helpers
forval x=1/15 {
	gen temp_paid_helper_`x'=1 if fu_helpers_salary_`x'>0 & fu_helpers_salary_`x'<. & sample==1
}
egen paid_helper_numb=rowtotal(temp_paid_helper_*) if sample==1

***  number of unpaid helpers
forval x=1/15 {
	gen temp_unpaid_helper_`x'=1 if fu_helpers_salary_`x'==.d | fu_helpers_salary_`x'==0 & sample==1
}
egen unpaid_helper_numb=rowtotal(temp_unpaid_helper_*) if sample==1

***  busines profits tweaked

***  profit calculated as sum of parts
***  note: if entire row is missing, treats it as missing (but if Number of Businesses=0 then treats it as 0)
egen bus_grossearnings=rowtotal(fu_gross_sales_*)
lab var bus_grossearnings "Total amount of gross sales in past month across all businesses in hh"
replace bus_grossearnings=0 if noof_business==0 
replace bus_grossearnings=. if sample==0 | (bus_grossearnings==0 & (fu_gross_sales_1==. | fu_gross_sales_1==.a | fu_gross_sales_1==.b | fu_gross_sales_1==.c))

egen bus_spending=rsum(fu_expenses_*)
lab var bus_spending "Total amount of expenses in past month in business across all businesses in hh"
replace bus_spending=0 if noof_business==0 
#delimit ;
replace bus_spending=. if sample==0 | (bus_spending==0 & (
(fu_expenses_inventory_1==. | fu_expenses_inventory_1==.a | fu_expenses_inventory_1==.b | fu_expenses_inventory_1==.c) & 
(fu_expenses_bills_1==. | fu_expenses_bills_1==.a | fu_expenses_bills_1==.b | fu_expenses_bills_1==.c) & 
(fu_expenses_wages_1==. | fu_expenses_wages_1==.a | fu_expenses_wages_1==.b | fu_expenses_wages_1==.c) & 
(fu_expenses_rent_equip_1==. | fu_expenses_rent_equip_1==.a | fu_expenses_rent_equip_1==.b | fu_expenses_rent_equip_1==.c) & 
(fu_expenses_rent_building_1==. | fu_expenses_rent_building_1==.a | fu_expenses_rent_building_1==.b | fu_expenses_rent_building_1==.c) & 
(fu_expenses_taxes_1==. | fu_expenses_taxes_1==.a | fu_expenses_taxes_1==.b | fu_expenses_taxes_1==.c) & 
(fu_expenses_maint_1==. | fu_expenses_maint_1==.a | fu_expenses_maint_1==.b | fu_expenses_maint_1==.c) & 
(fu_expenses_transport_1==. | fu_expenses_transport_1==.a | fu_expenses_transport_1==.b | fu_expenses_transport_1==.c) & 
(fu_expenses__other_1==. | fu_expenses__other_1==.a | fu_expenses__other_1==.b | fu_expenses__other_1==.c))) ;
#delimit cr

gen bus_netearning=bus_grossearnings-bus_spending if sample==1
lab var bus_netearning "Total profit generated in past month by all businesses in hh"
note bus_netearning: This is a variable from month before follow-up survey (subtract 'past month bus. expenses' from 'past month business gross earnings').
gen bus_profit_compiled=bus_netearning if sample==1
lab var bus_profit_compiled "Compiled Profit (from report sales and expenses)"

gen bus1_spending=fu_expenses_inventory_1+fu_expenses_bills_1+fu_expenses_wages_1+fu_expenses_rent_equip_1+fu_expenses_rent_building_1+fu_expenses_taxes_1+fu_expenses_maint_1+fu_expenses_transport_1+fu_expenses__other_1 if sample==1
replace bus1_spending=0 if noof_business==0 & sample==1
gen bus2_spending=fu_expenses_inventory_2+fu_expenses_bills_2+fu_expenses_wages_2+fu_expenses_rent_equip_2+fu_expenses_rent_building_2+fu_expenses_taxes_2+fu_expenses_maint_2+fu_expenses_transport_2+fu_expenses__other_2 if sample==1
replace bus2_spending=0 if noof_business<2 & sample==1
	
***  business profits plus self salary
gen bus_profit_selfsal=bus_profit+self_salary if !(self_salary>=.) & sample==1
lab var bus_profit_compiled "Reported Profit + Self Salary"
gen bus_profit_compiled_selfsal=bus_profit_compiled+self_salary if !(self_salary>=.) & sample==1
lab var bus_profit_compiled_selfsal "Compiled Profit + Self Salary"

xtile pctile_bus_profit_selfsal=bus_profit_selfsal if bus_profit_selfsal<. & sample==1, n(100)
lab var pctile_bus_profit_selfsal "Percentile of profits plus self-salary (distribution based on non-zero. zero income reset to 0)"
xtile pctile_bus_profit_compiled=bus_profit_compiled if bus_profit_compiled<. & sample==1, n(100)
replace pctile_bus_profit_compiled=0 if bus_profit_compiled==0 & sample==1
*xtile pctile_bus_profit_compiled_selfsal=bus_profit_compiled_self_salary if bus_profit_compiled_self_salary>0 & bus_profit_compiled_self_salary<., n(100)
*replace pctile_bus_profit_compiled_selfsal=0 if bus_profit_compiled_self_salary==0

foreach lhs in bus_inventory bus_sales bus_profit bus_profit_selfsal {
	gen `lhs'_condl=`lhs' if noof_business>0 & noof_business<.
	gen `lhs'_condl_trim=`lhs' if (noof_business>0 & noof_business<.) & (pctile_`lhs'>1 & pctile_`lhs'<100)
	gen `lhs'_trim=`lhs' if (pctile_`lhs'>1 & pctile_`lhs'<100)
	gen ln`lhs'=log(`lhs')
	gen `lhs'_any=`lhs'>0 if `lhs'<.
	gen `lhs'_any_condl=`lhs'_any
	replace `lhs'_any_condl=. if noof_business==0
	replace pctile_`lhs'=. if `lhs'<=0
	gen `lhs'_nr=`lhs'==. if sample==1
}
for var *any_condl *_nr: tab X
egen nra=rsum(*_nr) if sample==1
gen nr_any=nra>0 if sample==1
gen nr_zero_any=nr_any
replace nr_zero_any=1 if (bus_profit==0 | bus_sales==0 | bus_inventory==0)

***  adjust income - ".c" Not Applicable should be counted as 0 income
gen income=fu_hh_total_inc if sample==1
replace income=0 if fu_hh_total_inc==.c & sample==1

***  median variables
foreach x in bus_profit bus_inventory bus_sales bus_profit_selfsal income {
	egen med_`x'=median(`x') if `x'<. & sample==1 
	gen above_med_`x'=0 if `x'<. & sample==1
	lab var above_med_`x' "Above median `x'"
	replace above_med_`x'=1 if `x'>med_`x' & `x'<. & sample==1
}

***
***  tables
***

log using fmb_t5_X.log, replace

set more off
est clear
# delimit;
foreach lhs in
bus_profit    	   bus_profit_trim    	   lnbus_profit
bus_profit_selfsal bus_profit_selfsal_trim lnbus_profit_selfsal
bus_sales     	   bus_sales_trim     	   lnbus_sales
bus_inventory 	   bus_inventory_trim 	   lnbus_inventory 
noof_business 
noof_helpers
paid_helper_numb   unpaid_helper_numb
{ ;
# delimit cr
	xi: reg `lhs' css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
	estimates store m1, title((1))
	xi: reg `lhs' css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
	estimates store m2, title((2))
	xi: reg `lhs' css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
	estimates store m3, title((3))

	#delimit ;
	estout * using outreg\estout_`lhs'_X.txt, cells(b(star fmt(%12.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
	mlabels((1) (2) (3)) label collabels(,none)
	keep(css_loandecision x_male_decision x_above_med_inc_decision)
	prehead() postfoot(@starlegend.) replace margin nodiscrete ;
	#delimit cr
	est clear
}

# delimit;
foreach lhs in
bus_profit    	   bus_profit_trim    	   lnbus_profit
bus_profit_selfsal bus_profit_selfsal_trim lnbus_profit_selfsal
bus_sales     	   bus_sales_trim     	   lnbus_sales
bus_inventory 	   bus_inventory_trim 	   lnbus_inventory 
noof_business 
noof_helpers
paid_helper_numb   unpaid_helper_numb
{ ;
# delimit cr
	sum `lhs' if sample==1 
	sum `lhs' if sample==1 & female==1
	sum `lhs' if sample==1 & female==0 
	sum `lhs' if sample==1 & above_medinc_app==1 
	sum `lhs' if sample==1 & above_medinc_app==0 
}

capture: log close

***********************


***************************************************************************************************************************************
*** created by luke crowley; last modified by luke crowley on april 29th, 2010                                                      ***
*** for data analysis of impact of credit access study at First Macro Bank (philippines)                                            ***
*** other human capital and occupational choice                                                                                     ***
***                                                                                                                                 ***
*** files used:                                                                                                                     ***
***    fmbfinaldata.dta                                                                                                             ***
***************************************************************************************************************************************

clear
set more off
set mem 400m
set maxvar 10000
capture log close
tempfile fu_loan_amount
*log using fmb_outcomes_hh_memb_activities.log, replace

use fmbfinaldata, clear

***
***  splits
***

***  Median income at time of application
egen medinc_app=median(css_netweeklyamt) if sample==1 
gen above_medinc_app=0 if sample==1
lab var above_medinc_app "Above median income at time of application"
replace above_medinc_app=1 if css_netweeklyamt>medinc_app & sample==1

gen male=female
recode male (0=1) (1=0)
gen x_male_decision=male*css_loandecision if sample==1
gen x_above_med_inc_decision=above_medinc_app*css_loandecision if sample==1

***
***  create variables for household members' activities
***

***  number of household members under age 18
egen numb_hh_under_18=anycount(fu_hh_age_*), v(0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17)
lab var numb_hh_under_18 "Number of hh members under 18"

***  number of household members in total
egen numb_hh_total=rownonmiss(fu_hh_mem_name_*), strok
lab var numb_hh_total "Number of hh members in total"

***  students (any, number)
egen student_any=anymatch(fu_hh_employment_*), v(2) 
lab var student_any "Any students in hh"
egen student_numb=anycount(fu_hh_employment_*), v(2)
lab var student_numb "Number of students in hh"

***  school age
egen school_age=anymatch(fu_hh_age_*), v(4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21)

***  unemployed or on the job training
egen unempl_ojt_any=anymatch(fu_hh_employment_*), v(7 8) 
lab var unempl_ojt_any "Any unemployed or OJT in hh"
egen unempl_ojt_numb=anycount(fu_hh_employment_*), v(7 8)
lab var unempl_ojt_numb "Number of unemployed or OJT in hh"

***  on the job training
egen ojt_any=anymatch(fu_hh_employment_*), v(7) 
lab var ojt_any "Any OJT in hh"
egen ojt_numb=anycount(fu_hh_employment_*), v(7)
lab var ojt_numb "Number of OJT in hh"

***  regularly employed (any, number, respondent)
egen regular_any=anymatch(fu_hh_employment_*), v(3)
lab var regular_any "Any regular employment in hh"
egen regular_numb=anycount(fu_hh_employment_*), v(3)
lab var regular_numb "Number of regularly employed in hh"
gen regular_any_primary=0 if sample==1 
lab var regular_any_primary "Head of hh regularly employed"
replace regular_any_primary=1 if fu_hh_employment_1==3 & sample==1

***  regularly, casually, or part-time employed (any, number, respondent)
egen employ_any=anymatch(fu_hh_employment_*), v(3 6)
lab var employ_any "Any regular, casual, or part-time employment in hh"
egen employ_numb=anycount(fu_hh_employment_*), v(3 6)
lab var employ_numb "Number of regularly, casually, or part-time employed in hh"
gen employ_any_primary=0 if sample==1 
lab var employ_any_primary "Head of hh regularly, casually, or part-time employed"
replace employ_any_primary=1 if (fu_hh_employment_1==3 | fu_hh_employment_1==6) & sample==1
replace employ_any_primary=1 if fu_second_employment==1 | fu_second_employment==2 | (fu_second_employment==3 & fu_business_description_2=="")

***  OFW
egen ofw_any=anymatch(fu_hh_employment_*), v(4) 
lab var ofw_any "Any OFWs in hh"

***  household member helping in family business - any
egen hh_memb_fam_biz_any=anymatch(fu_hh_employment_2 fu_hh_employment_3 fu_hh_employment_4 fu_hh_employment_5 fu_hh_employment_6 fu_hh_employment_7 fu_hh_employment_8 fu_hh_employment_9 fu_hh_employment_10 fu_hh_employment_11 fu_hh_employment_12 fu_hh_employment_13 fu_hh_employment_14 fu_hh_employment_15), v(5) 
lab var hh_memb_fam_biz_any "Any hh memb helping in family business"

***
***  new tables for referree comments
***

log using fmb_t6_X.log, replace

***  household members under 18 - number 
xi: reg numb_hh_under_18 css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg numb_hh_under_18 css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg numb_hh_under_18 css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_under_18_num_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  household members - number 
xi: reg numb_hh_total css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg numb_hh_total css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg numb_hh_total css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_hh_mems_num_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

foreach x in numb_hh_under_18 numb_hh_total {
	sum `x' if sample==1 
	sum `x' if sample==1 & female==1
	sum `x' if sample==1 & female==0 
	sum `x' if sample==1 & above_medinc_app==1 
	sum `x' if sample==1 & above_medinc_app==0 
}

***
***  tables
***

***  regular, casual, part-time employment - any, respondent --> "Business Owner/Operator has Second Job Outside The Job"
xi: reg employ_any_primary css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg employ_any_primary css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg employ_any_primary css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_employ_any_resp_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  hh member in family business - any --> "Any Household Member Helping in Family Business"
xi: reg hh_memb_fam_biz_any css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg hh_memb_fam_biz_any css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg hh_memb_fam_biz_any css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_hh_memb_fam_biz_any_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  regular, casual, part-time employment - any --> "Any Household Member Employed Outside the Family Business"
xi: reg employ_any css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg employ_any css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg employ_any css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_employ_any_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  OFW - any --> "Any Overseas Foreign Workers in Household"
xi: reg ofw_any css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg ofw_any css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg ofw_any css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_hh_memb_ofw_any_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  students - any--> "Any Students in Household"
xi: reg student_any css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg student_any css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg student_any css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_student_any_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

foreach x in employ_any_primary hh_memb_fam_biz_any employ_any ofw_any student_any {
	sum `x' if sample==1 
	sum `x' if sample==1 & female==1
	sum `x' if sample==1 & female==0 
	sum `x' if sample==1 & above_medinc_app==1 
	sum `x' if sample==1 & above_medinc_app==0 
	sum `x' if sample==1 & fu_dum_challenge_lack_capital==1 
	sum `x' if sample==1 & fu_dum_challenge_lack_capital==0 
}

capture: log close

*************************************



***************************************************************************************************************************************
*** created by kareem haggag; last modified by luke crowley april 29th, 2010                                                        ***
*** for data analysis of impact of credit access study at First Macro Bank (philippines)                                            ***
*** non-inventory fixed assets                                                                                                      ***
***                                                                                                                                 ***
*** files used:                                                                                                                     ***
***    fmbfinaldata.dta                                                                                                             ***
***************************************************************************************************************************************

clear
set more off
set mem 400m
set maxvar 10000
capture: log close
tempfile fu_loan_amount

use fmbfinaldata, clear

***
***  control variables
***

forval x=1/15 {
	replace css_improvements`x'=0 if css_improvements`x'==1
	gen property_value`x'=css_depreciation1+css_improvements1
}
egen property_tot=rowtotal(property_value*)

gen own_space=0 if css_businessspace1<.
replace own_space=1 if css_businessspace1==1

gen edu_some_college=0 if css_educattainment<.
replace edu_some_college=1 if css_educattainment==1 | css_educattainment==2

***
***  splits
***

***  Median income at time of application
egen medinc_app=median(css_netweeklyamt) if sample==1 
gen above_medinc_app=0 if sample==1
lab var above_medinc_app "Above median income at time of application"
replace above_medinc_app=1 if css_netweeklyamt>medinc_app & sample==1

gen male=female
recode male (0=1) (1=0)
gen x_male_decision=male*css_loandecision if sample==1
gen x_above_med_inc_decision=above_medinc_app*css_loandecision if sample==1

***
***  surveyor observational variables
***

gen walls_quality=.
replace walls_quality=1 if fu_obs_walls==7 | fu_obs_walls_other_specify=="bamboo" | fu_obs_walls_other_specify=="chicken wire w/ lumb"
replace walls_quality=2 if fu_obs_walls==4 | fu_obs_walls==5 | fu_obs_walls==6
replace walls_quality=3 if fu_obs_walls==1 
replace walls_quality=4 if fu_obs_walls==3 
replace walls_quality=5 if fu_obs_walls==2 
lab var walls_quality "Wall material"
#delimit ;
lab def walls_quality
1 "Salvaged, scrap, bamboo" 
2 "Wood, plain GI sheet" 
3 "Unfinished concrete" 
4 "Semi-concrete" 
5 "Finished concrete" ;
#delimit cr
lab val walls_quality walls_quality
gen walls_dum=0 if sample==1
replace walls_dum=1 if walls_quality==5 & sample==1

gen floor_quality=.
replace floor_quality=1 if fu_obs_floor==7 | fu_obs_floor_other_specify=="bamboo" | fu_obs_floor_other_specify=="kubo" | fu_obs_floor_other_specify=="tabla, kahoy, bahagy"
replace floor_quality=2 if fu_obs_floor==6
replace floor_quality=3 if fu_obs_floor==2 | fu_obs_floor==5
replace floor_quality=4 if fu_obs_floor==3 | fu_obs_floor==4
replace floor_quality=5 if fu_obs_floor==1
lab var floor_quality "Floor material"
#delimit ;
lab def floor_quality 
1 "Earth, sand, bamboo" 
2 "Wood (parquet)" 
3 "Unfinished concrete, vinyl tiles" 
4 "Finished concrete, ceramic tiles" 
5 "Marble" ;
#delimit cr
lab val floor_quality floor_quality
gen floor_dum=0 if sample==1
replace floor_dum=1 if (fu_obs_floor==1 | fu_obs_floor==3) & sample==1

gen roof_dum=0 if sample==1
replace roof_dum=1 if fu_obs_roof==1 | fu_obs_roof==2 | fu_obs_roof==3
lab var roof_dum "Roof is concrete slab or metal sheet"

***
***  tables
***

log using fmb_t7_c_X.log, replace

***  walls
xi: reg walls_dum css_loandecision css_age married edu_some_college css_stockvalue css_assetvalue own_space i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg walls_dum css_loandecision male x_male_decision css_age married edu_some_college css_stockvalue css_assetvalue own_space i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg walls_dum css_loandecision above_medinc_app x_above_med_inc_decision css_age married edu_some_college css_stockvalue css_assetvalue own_space i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_asset_obs_walls_c_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  floors
xi: reg floor_dum css_loandecision css_age married edu_some_college css_stockvalue css_assetvalue own_space i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg floor_dum css_loandecision male x_male_decision css_age married edu_some_college css_stockvalue css_assetvalue own_space i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg floor_dum css_loandecision above_medinc_app x_above_med_inc_decision css_age married edu_some_college css_stockvalue css_assetvalue own_space i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_asset_obs_floor_c_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  roof
xi: reg roof_dum css_loandecision css_age married edu_some_college css_stockvalue css_assetvalue own_space i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg roof_dum css_loandecision male x_male_decision css_age married edu_some_college css_stockvalue css_assetvalue own_space i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg roof_dum css_loandecision above_medinc_app x_above_med_inc_decision css_age married edu_some_college css_stockvalue css_assetvalue own_space i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_asset_obs_roof_c_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

foreach x in walls_dum floor_dum roof_dum {
	sum `x' if sample==1 
	sum `x' if sample==1 & female==1
	sum `x' if sample==1 & female==0 
	sum `x' if sample==1 & above_medinc_app==1 
	sum `x' if sample==1 & above_medinc_app==0 
}

capture: log close




**********************************


***************************************************************************************************************************************
*** created by kareem haggag; last modified by luke crowley april 29th, 2010                                                        ***
*** for data analysis of impact of credit access study at First Macro Bank (philippines)                                            ***
*** non-inventory fixed assets                                                                                                      ***
***                                                                                                                                 ***
*** files used:                                                                                                                     ***
***    fmbfinaldata.dta                                                                                                             ***
***************************************************************************************************************************************

clear
set more off
set mem 400m
set maxvar 10000
capture log close
tempfile fu_loan_amount

use fmbfinaldata, clear

***
***  splits
***

***  Median income at time of application
egen medinc_app=median(css_netweeklyamt) if sample==1 
gen above_medinc_app=0 if sample==1
lab var above_medinc_app "Above median income at time of application"
replace above_medinc_app=1 if css_netweeklyamt>medinc_app & sample==1

gen male=female
recode male (0=1) (1=0)
gen x_male_decision=male*css_loandecision if sample==1
gen x_above_med_inc_decision=above_medinc_app*css_loandecision if sample==1

***
***  assets variables
***

***  assets purchased
foreach x in land buildings cell_phones stoves fans ac tv_sets vhs_dvd jeepneys h2o_pur_dev fridge computers bus_equip livestock furniture cars_excl_jeep motor_tri_bi_cy other1 other2 {
	replace fu_asset_pur_num_`x'=0 if fu_asset_pur_num_`x'==.c
}
egen temp=rownonmiss(fu_asset_pur_num_*)
egen asset_purch_count=rsum(fu_asset_pur_num_*) if temp>0 & sample==1
lab var asset_purch_count "Number of assets purchased in the last year"
drop temp
gen log_asset_purch_count=log(asset_purch_count+1) if sample==1
egen temp=rownonmiss(fu_asset_pur_num_jeepneys fu_asset_pur_num_cars_excl_jeep fu_asset_pur_num_land fu_asset_pur_num_buildings fu_asset_pur_num_computers fu_asset_pur_num_livestock)
egen asset_purch_major_count=rsum(fu_asset_pur_num_jeepneys fu_asset_pur_num_cars_excl_jeep fu_asset_pur_num_land fu_asset_pur_num_buildings fu_asset_pur_num_computers fu_asset_pur_num_livestock) if temp>0 & sample==1
lab var asset_purch_major_count "Number of major assets purchased in the last year"
drop temp
gen asset_purch=0 if asset_purch_count==0 & sample==1
lab var asset_purch "Any assets purchased in the last year?"
replace asset_purch=1 if asset_purch_count>0 & !(asset_purch_count>=.) & sample==1

***  assets sold
foreach x in land buildings cell_phones stoves fans ac tv_sets vhs_dvd cars jeepneys motor_tri_bi h2o_pur_dev fridge computers bus_equip livestock furniture other1 other2{
	replace fu_asset_sold_num_`x'=0 if fu_asset_sold_num_`x'==.c
}
egen temp=rownonmiss(fu_asset_sold_num_*)
egen asset_sold_count=rsum(fu_asset_sold_num_*) if temp>0 & sample==1
lab var asset_sold_count "Number of assets sold in the last year"
drop temp
gen log_asset_sold_count=log(asset_sold_count+1)
egen temp=rownonmiss(fu_asset_sold_num_jeepneys fu_asset_sold_num_cars fu_asset_sold_num_land fu_asset_sold_num_buildings fu_asset_sold_num_computers fu_asset_sold_num_livestock)
egen asset_sold_major_count=rsum(fu_asset_sold_num_jeepneys fu_asset_sold_num_cars fu_asset_sold_num_land fu_asset_sold_num_buildings fu_asset_sold_num_computers fu_asset_sold_num_livestock) if temp>0 & sample==1
lab var asset_sold_major_count "Number of major assets sold in the last year"
gen asset_sold=0 if asset_sold_count==0 & sample==1
lab var asset_sold "Any assets sold in the last year?"
replace asset_sold=1 if asset_sold_count>0 & !(asset_sold_count>=.) & sample==1

***
***  surveyor observational variables
***

gen walls_quality=.
replace walls_quality=1 if fu_obs_walls==7 | fu_obs_walls_other_specify=="bamboo" | fu_obs_walls_other_specify=="chicken wire w/ lumb"
replace walls_quality=2 if fu_obs_walls==4 | fu_obs_walls==5 | fu_obs_walls==6
replace walls_quality=3 if fu_obs_walls==1 
replace walls_quality=4 if fu_obs_walls==3 
replace walls_quality=5 if fu_obs_walls==2 
lab var walls_quality "Wall material"
#delimit ;
lab def walls_quality
1 "Salvaged, scrap, bamboo" 
2 "Wood, plain GI sheet" 
3 "Unfinished concrete" 
4 "Semi-concrete" 
5 "Finished concrete" ;
#delimit cr
lab val walls_quality walls_quality
gen walls_dum=0 if sample==1
replace walls_dum=1 if walls_quality==5 & sample==1

gen floor_quality=.
replace floor_quality=1 if fu_obs_floor==7 | fu_obs_floor_other_specify=="bamboo" | fu_obs_floor_other_specify=="kubo" | fu_obs_floor_other_specify=="tabla, kahoy, bahagy"
replace floor_quality=2 if fu_obs_floor==6
replace floor_quality=3 if fu_obs_floor==2 | fu_obs_floor==5
replace floor_quality=4 if fu_obs_floor==3 | fu_obs_floor==4
replace floor_quality=5 if fu_obs_floor==1
lab var floor_quality "Floor material"
#delimit ;
lab def floor_quality 
1 "Earth, sand, bamboo" 
2 "Wood (parquet)" 
3 "Unfinished concrete, vinyl tiles" 
4 "Finished concrete, ceramic tiles" 
5 "Marble" ;
#delimit cr
lab val floor_quality floor_quality
gen floor_dum=0 if sample==1
replace floor_dum=1 if (fu_obs_floor==1 | fu_obs_floor==3) & sample==1

gen roof_dum=0 if sample==1
replace roof_dum=1 if fu_obs_roof==1 | fu_obs_roof==2 | fu_obs_roof==3
lab var roof_dum "Roof is concrete slab or metal sheet"

gen any_phone=0 if fu_obs_telephone==4
replace any_phone=1 if fu_obs_telephone==1 | fu_obs_telephone==2 | fu_obs_telephone==3 

***
***  create index
*** 

gen iasset_purch=asset_purch if sample==1
	for X in num 0 1: quietly sum asset_purch if lower_window==1 & css_loandecision==X & sample==1 \ replace iasset_purch=r(mean) if iasset_purch>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum asset_purch if lower_window!=1 & css_loandecision==X & sample==1 \ replace iasset_purch=r(mean) if iasset_purch>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum iasset_purch if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_iasset_purch=(iasset_purch-r(mean))/r(sd) if lower_window==1 & sample==1
	quietly sum iasset_purch if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_iasset_purch=(iasset_purch-r(mean))/r(sd) if lower_window!=1 & sample==1
	lab var iasset_purch "standardized 'asset_purch' dummy for household index"
	drop iasset_purch
	gen iasset_purch=asset_purch if !mi(asset_purch) & sample==1
	lab var iasset_purch "unstandardized 'asset_purch' dummy"
gen iasset_sold=-1*asset_sold if sample==1
	for X in num 0 1: quietly sum asset_sold if lower_window==1 & css_loandecision==X & sample==1 \ replace iasset_sold=-1*r(mean) if iasset_sold>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum asset_sold if lower_window!=1 & css_loandecision==X & sample==1 \ replace iasset_sold=-1*r(mean) if iasset_sold>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum iasset_sold if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_iasset_sold=(iasset_sold-r(mean))/r(sd) if lower_window==1 & sample==1
	quietly sum iasset_sold if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_iasset_sold=(iasset_sold-r(mean))/r(sd) if lower_window!=1 & sample==1
	lab var iasset_sold "standardized 'asset_sold' dummy for household index"
	drop iasset_sold
	gen iasset_sold=asset_sold if !mi(asset_sold) & sample==1
	lab var iasset_sold "unstandardized 'asset_sold' dummy"
gen iwalls_dum=walls_dum if sample==1
	for X in num 0 1: quietly sum walls_dum if lower_window==1 & css_loandecision==X & sample==1 \ replace iwalls_dum=r(mean) if iwalls_dum>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum walls_dum if lower_window!=1 & css_loandecision==X & sample==1 \ replace iwalls_dum=r(mean) if iwalls_dum>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum iwalls_dum if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_iwalls_dum=(iwalls_dum-r(mean))/r(sd) if lower_window==1 & sample==1
	quietly sum iwalls_dum if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_iwalls_dum=(iwalls_dum-r(mean))/r(sd) if lower_window!=1 & sample==1
	lab var iwalls_dum "standardized 'walls_dum' for household index"
	drop iwalls_dum
	gen iwalls_dum=walls_dum if !mi(walls_dum) & sample==1
	lab var iwalls_dum "unstandardized 'walls_dum'"
gen ifloor_dum=floor_dum if sample==1
	for X in num 0 1: quietly sum floor_dum if lower_window==1 & css_loandecision==X & sample==1 \ replace ifloor_dum=r(mean) if ifloor_dum>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum floor_dum if lower_window!=1 & css_loandecision==X & sample==1 \ replace ifloor_dum=r(mean) if ifloor_dum>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum ifloor_dum if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_ifloor_dum=(ifloor_dum-r(mean))/r(sd) if lower_window==1 & sample==1
	quietly sum ifloor_dum if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_ifloor_dum=(ifloor_dum-r(mean))/r(sd) if lower_window!=1 & sample==1
	lab var ifloor_dum "standardized 'floor_dum' for household index"
	drop ifloor_dum
	gen ifloor_dum=floor_dum if !mi(floor_dum) & sample==1
	lab var ifloor_dum "unstandardized 'floor_dum'"
gen iroof_dum=roof_dum if sample==1
	for X in num 0 1: quietly sum roof_dum if lower_window==1 & css_loandecision==X & sample==1 \ replace iroof_dum=r(mean) if iroof_dum>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum roof_dum if lower_window!=1 & css_loandecision==X & sample==1 \ replace iroof_dum=r(mean) if iroof_dum>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum iroof_dum if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_iroof_dum=(iroof_dum-r(mean))/r(sd) if lower_window==1 & sample==1
	quietly sum iroof_dum if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_iroof_dum=(iroof_dum-r(mean))/r(sd) if lower_window!=1 & sample==1
	lab var iroof_dum "standardized 'roof_dum' for household index"
	drop iroof_dum
	gen iroof_dum=roof_dum if !mi(roof_dum) & sample==1
	lab var iroof_dum "unstandardized 'roof_dum'"
gen iany_phone=any_phone if sample==1
	for X in num 0 1: quietly sum any_phone if lower_window==1 & css_loandecision==X & sample==1 \ replace iany_phone=r(mean) if iany_phone>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum any_phone if lower_window!=1 & css_loandecision==X & sample==1 \ replace iany_phone=r(mean) if iany_phone>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum iany_phone if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_iany_phone=(iany_phone-r(mean))/r(sd) if lower_window==1 & sample==1
	quietly sum iany_phone if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_iany_phone=(iany_phone-r(mean))/r(sd) if lower_window!=1 & sample==1
	lab var iany_phone "standardized 'any_phone' for household index"
	drop iany_phone
	gen iany_phone=any_phone if !mi(any_phone) & sample==1
	lab var iany_phone "unstandardized 'any_phone'"
gen iassets_observationals=(std_iasset_purch+std_iasset_sold+std_iwalls_dum+std_ifloor_dum+std_iroof_dum+std_iany_phone)/6
	lab var iassets_observationals "Unweighted assets and observationals index"
*	replace iassets_observationals=. if std_iasset_purch==. | std_iasset_sold==. | std_iwalls_dum==. | std_ifloor_dum==. | std_iroof_dum==. | std_iany_phone==.

***
***  tables
***

log using fmb_t7_X.log, replace

***  asset purchased
xi: reg asset_purch css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg asset_purch css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg asset_purch css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_asset_obs_asset_purch_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  asset sold
xi: reg asset_sold css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg asset_sold css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg asset_sold css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_asset_obs_asset_sold_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  walls
xi: reg walls_dum css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg walls_dum css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg walls_dum css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_asset_obs_walls_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  floors
xi: reg floor_dum css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg floor_dum css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg floor_dum css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_asset_obs_floor_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  roof
xi: reg roof_dum css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg roof_dum css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg roof_dum css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_asset_obs_roof_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  phone
xi: reg any_phone css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg any_phone css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg any_phone css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_asset_obs_phone_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  index
xi: reg iassets_observationals css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg iassets_observationals css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg iassets_observationals css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_asset_obs_index_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

foreach x in asset_purch asset_sold walls_dum floor_dum roof_dum any_phone iassets_observationals {
	sum `x' if sample==1 
	sum `x' if sample==1 & female==1
	sum `x' if sample==1 & female==0 
	sum `x' if sample==1 & above_medinc_app==1 
	sum `x' if sample==1 & above_medinc_app==0 
}

capture: log close



**********************************


***************************************************************************************************************************************
*** created by kareem haggag; last modified by luke crowley april 29th, 2009                                                        ***
*** for data analysis of impact of credit access study at First Macro Bank (philippines)                                            ***
*** other household investments and risk management                                                                                 ***
***                                                                                                                                 ***
*** files used:                                                                                                                     ***
***    fmbfinaldata.dta                                                                                                             ***
***************************************************************************************************************************************

clear
set more off
set mem 400m
set maxvar 10000
capture log close
tempfile fu_loan_amount

use fmbfinaldata, clear

***
***  splits
***

gen male=female
recode male (0=1) (1=0)
gen x_male_decision=male*css_loandecision if sample==1

***
***  variables
***

***  dummy for any savings
gen have_savings=fu_savings if sample==1
lab var have_savings "Do you or anyone in household have money set aside as savings in a bank/house/paluwagan?"

***  health insurance?
gen health_insurance=0 if sample==1
replace health_insurance=. if fu_hh_h_ins_ph>=. & fu_hh_h_ins_hmo>=. & fu_hh_h_ins_other==""
replace health_insurance=1 if (fu_hh_h_ins_ph==1 |  fu_hh_h_ins_hmo==1 |  (fu_hh_h_ins_other!="" & fu_hh_h_ins_other!="1" & fu_hh_h_ins_other!="2")) & sample==1

***  other insurance?
gen other_insurance=0 if sample==1
replace other_insurance=. if  fu_hh_life_ins==. & fu_hh_fire_ins==. & fu_hh_home_ins==. & fu_hh_business_ins==. & fu_hh_prop_ins==. & fu_hh_car_ins==. &  fu_hh_other_ins==.
replace other_insurance=1 if (fu_hh_life_ins==1 | fu_hh_fire_ins==1 | fu_hh_home_ins==1 | fu_hh_business_ins==1 | fu_hh_prop_ins==1 | fu_hh_car_ins==1 |  fu_hh_other_ins==1) & sample==1

***  remittances
gen lnrem_rec=log(fu_hh_rec_rem_amt+1) if sample==1
lab var lnrem_rec "Log of remittances received"
replace lnrem_rec=log(1) if lnrem_rec==. & fu_hh_rec_rem<. & sample==1 
gen lnrem_send=log(fu_hh_send_rem_amt+1) if sample==1
lab var lnrem_send "Log of remittances sent"
replace lnrem_send=log(1) if lnrem_send==. & fu_hh_send_rem<. & sample==1

gen rem_rec=fu_hh_rec_rem if sample==1
lab var rem_rec "Any remittances received"
replace rem_rec=1 if fu_hh_rec_rem_amt<. & fu_hh_rec_rem_amt>0 & sample==1
gen rem_send=fu_hh_send_rem if sample==1
lab var rem_send "Any remittances sent"
replace rem_send=1 if fu_hh_send_rem_amt<. & fu_hh_send_rem_amt>0 & sample==1

***
***  tables 
***

log using fmb_t8_X.log, replace

***  health insurance
xi: reg health_insurance css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg health_insurance css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg health_insurance css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_hh_health_insurance_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  other insurance
xi: reg other_insurance css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg other_insurance css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg other_insurance css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_hh_other_insurance_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  have savings?
xi: reg have_savings css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg have_savings css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg have_savings css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_hh_savings_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  remittances sent
xi: reg rem_send css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg rem_send css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg rem_send css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_remit_any_send_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

foreach x in health_insurance other_insurance have_savings rem_send {
	sum `x' if sample==1 
	sum `x' if sample==1 & female==1
	sum `x' if sample==1 & female==0 
	sum `x' if sample==1 & above_medinc_app==1 
	sum `x' if sample==1 & above_medinc_app==0 
}

capture: log close



*****************************


***************************************************************************************************************************************
*** created by kareem haggag; last modified by luke crowley april 29th, 2009                                                        ***
*** for data analysis of impact of credit access study at First Macro Bank (philippines)                                            ***
*** trust and informal access                                                                                                       ***
***                                                                                                                                 ***
*** files used:                                                                                                                     ***
***    fmbfinaldata.dta                                                                                                             ***
***************************************************************************************************************************************

clear
set more off
set mem 400m
set maxvar 10000
capture log close
tempfile fu_loan_amount

use fmbfinaldata, clear

***
***  splits
***

***  Median income at time of application
egen medinc_app=median(css_netweeklyamt) if sample==1 
gen above_medinc_app=0 if sample==1
lab var above_medinc_app "Above median income at time of application"
replace above_medinc_app=1 if css_netweeklyamt>medinc_app & sample==1

gen male=female
recode male (0=1) (1=0)
gen x_male_decision=male*css_loandecision if sample==1
gen x_above_med_inc_decision=above_medinc_app*css_loandecision if sample==1

***
***  create variables for trust and informal analysis
***

***  standardize trust questions so that higher number = more trust**
foreach x in fu_trust_groups_family fu_trust_groups_neighborhood fu_trust_groups_know_personally fu_trust_groups_business_assoc {
	replace `x'=-`x'
}
***  now -4=Do Not Trust At All, -1=Trust Completely

gen theor_get_loan=fu_theor_loan_fr_fam if fu_theor_loan_fr_fam<. & sample==1  
lab var theor_get_loan "In an emergency, could get loan from friends or relatives"
replace theor_get_loan=1 if fu_theor_loan_fr_fam_amt<. & sample==1

gen theor_get_loan_lots=0 if (fu_theor_loan_fr_fam<. | fu_theor_loan_fr_fam_amt<.) & sample==1
lab var theor_get_loan_lots "In an emergency, could get large amt from friends or relatives"
replace theor_get_loan_lots=1 if (fu_theor_loan_fr_fam_amt==1 | (fu_theor_loan_fr_fam_amt>=10000 & fu_theor_loan_fr_fam_amt<.)) & sample==1

gen theor_get_loan_any=0 if (fu_theor_loan_fr_fam<. | fu_theor_loan_fr_fam_amt<.) & sample==1
lab var theor_get_loan_any "In an emergency, could get any amt from friends or relatives"
replace theor_get_loan_any=1 if fu_theor_loan_fr_fam_amt==1 & sample==1

***
***  create index
***

gen ifu_trust_take_advantage=fu_trust_take_advantage if sample==1
	for X in num 0 1: quietly sum fu_trust_take_advantage if lower_window==1 & css_loandecision==X & sample==1 \ replace ifu_trust_take_advantage=r(mean) if ifu_trust_take_advantage>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum fu_trust_take_advantage if lower_window!=1 & css_loandecision==X & sample==1 \ replace ifu_trust_take_advantage=r(mean) if ifu_trust_take_advantage>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum ifu_trust_take_advantage if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_ifu_trust_take_advan=(ifu_trust_take_advantage-r(mean))/r(sd) if lower_window==1 & sample==1
	quietly sum ifu_trust_take_advantage if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_ifu_trust_take_advan=(ifu_trust_take_advantage-r(mean))/r(sd) if lower_window!=1 & sample==1
	lab var ifu_trust_take_advantage "standardized 'fu_trust_take_advantage' dummy for trust index"
	drop ifu_trust_take_advantage
	gen ifu_trust_take_advantage=fu_trust_take_advantage if !mi(fu_trust_take_advantage) & sample==1
	lab var ifu_trust_take_advantage "unstandardized 'fu_trust_take_advantage' dummy (trust index)"
gen ifu_trust_groups_neighborhood=fu_trust_groups_neighborhood if sample==1
	for X in num 0 1: quietly sum fu_trust_groups_neighborhood if lower_window==1 & css_loandecision==X & sample==1 \ replace ifu_trust_groups_neighborhood=r(mean) if ifu_trust_groups_neighborhood>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum fu_trust_groups_neighborhood if lower_window!=1 & css_loandecision==X & sample==1 \ replace ifu_trust_groups_neighborhood=r(mean) if ifu_trust_groups_neighborhood>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum ifu_trust_groups_neighborhood if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_ifu_trust_groups_neighb=(ifu_trust_groups_neighborhood-r(mean))/r(sd) if lower_window==1 & sample==1
	quietly sum ifu_trust_groups_neighborhood if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_ifu_trust_groups_neighb=(ifu_trust_groups_neighborhood-r(mean))/r(sd) if lower_window!=1 & sample==1
	lab var ifu_trust_groups_neighborhood "standardized 'fu_trust_groups_neighborhood' dummy for trust index"
	drop ifu_trust_groups_neighborhood
	gen ifu_trust_groups_neighborhood=fu_trust_groups_neighborhood if !mi(fu_trust_groups_neighborhood) & sample==1
	lab var ifu_trust_groups_neighborhood "unstandardized 'fu_trust_groups_neighborhood' dummy (trust index)"
gen ifu_trust_groups_know_personally=fu_trust_groups_know_personally if sample==1
	for X in num 0 1: quietly sum fu_trust_groups_know_personally if lower_window==1 & css_loandecision==X & sample==1 \ replace ifu_trust_groups_know_personally=r(mean) if ifu_trust_groups_know_personally>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum fu_trust_groups_know_personally if lower_window!=1 & css_loandecision==X & sample==1 \ replace ifu_trust_groups_know_personally=r(mean) if ifu_trust_groups_know_personally>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum ifu_trust_groups_know_personally if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_ifu_trust_groups_know_pers=(ifu_trust_groups_know_personally-r(mean))/r(sd) if lower_window==1 & sample==1
	quietly sum ifu_trust_groups_know_personally if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_ifu_trust_groups_know_pers=(ifu_trust_groups_know_personally-r(mean))/r(sd) if lower_window!=1 & sample==1
	lab var ifu_trust_groups_know_personally "standardized 'fu_trust_groups_know_personally' dummy for trust index"
	drop ifu_trust_groups_know_personally
	gen ifu_trust_groups_know_personally=fu_trust_groups_know_personally if !mi(fu_trust_groups_know_personally) & sample==1
	lab var ifu_trust_groups_know_personally "unstandardized 'fu_trust_groups_know_personally' dummy (trust index)"
gen ifu_trust_groups_business_assoc=fu_trust_groups_business_assoc if sample==1
	for X in num 0 1: quietly sum fu_trust_groups_business_assoc if lower_window==1 & css_loandecision==X & sample==1 \ replace ifu_trust_groups_business_assoc=r(mean) if ifu_trust_groups_business_assoc>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum fu_trust_groups_business_assoc if lower_window!=1 & css_loandecision==X & sample==1 \ replace ifu_trust_groups_business_assoc=r(mean) if ifu_trust_groups_business_assoc>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum ifu_trust_groups_business_assoc if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_ifu_trust_groups_bus=(ifu_trust_groups_business_assoc-r(mean))/r(sd) if lower_window==1 & sample==1
	quietly sum ifu_trust_groups_business_assoc if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_ifu_trust_groups_bus=(ifu_trust_groups_business_assoc-r(mean))/r(sd) if lower_window!=1 & sample==1
	lab var ifu_trust_groups_business_assoc "standardized 'fu_trust_groups_business_assoc' dummy for trust index"
	drop ifu_trust_groups_business_assoc
	gen ifu_trust_groups_business_assoc=fu_trust_groups_business_assoc if !mi(fu_trust_groups_business_assoc) & sample==1
	lab var ifu_trust_groups_business_assoc "unstandardized 'fu_trust_groups_business_assoc' dummy (trust index)"

gen itheor_get_loan=theor_get_loan if sample==1
	for X in num 0 1: quietly sum theor_get_loan if lower_window==1 & css_loandecision==X & sample==1 \ replace itheor_get_loan=r(mean) if itheor_get_loan>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum theor_get_loan if lower_window!=1 & css_loandecision==X & sample==1 \ replace itheor_get_loan=r(mean) if itheor_get_loan>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum itheor_get_loan if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_itheor_get_loan=(itheor_get_loan-r(mean))/r(sd) if lower_window==1 & sample==1
	quietly sum itheor_get_loan if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_itheor_get_loan=(itheor_get_loan-r(mean))/r(sd) if lower_window!=1 & sample==1
	lab var itheor_get_loan "standardized 'theor_get_loan' dummy for trust index"
	drop itheor_get_loan
	gen itheor_get_loan=theor_get_loan if !mi(theor_get_loan) & sample==1
	lab var itheor_get_loan "unstandardized 'theor_get_loan' dummy (trust index)"
gen itheor_get_loan_lots=theor_get_loan_lots if sample==1
	for X in num 0 1: quietly sum theor_get_loan_lots if lower_window==1 & css_loandecision==X & sample==1 \ replace itheor_get_loan_lots=r(mean) if itheor_get_loan_lots>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum theor_get_loan_lots if lower_window!=1 & css_loandecision==X & sample==1 \ replace itheor_get_loan_lots=r(mean) if itheor_get_loan_lots>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum itheor_get_loan_lots if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_itheor_get_loan_lots=(itheor_get_loan_lots-r(mean))/r(sd) if lower_window==1 & sample==1
	quietly sum itheor_get_loan_lots if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_itheor_get_loan_lots=(itheor_get_loan_lots-r(mean))/r(sd) if lower_window!=1 & sample==1
	lab var itheor_get_loan_lots "standardized 'theor_get_loan_lots' dummy for trust index"
	drop itheor_get_loan_lots
	gen itheor_get_loan_lots=theor_get_loan_lots if !mi(theor_get_loan_lots) & sample==1
	lab var itheor_get_loan_lots "unstandardized 'theor_get_loan_lots' dummy (trust index)"
gen itheor_get_loan_any=theor_get_loan_any if sample==1
	for X in num 0 1: quietly sum theor_get_loan_any if lower_window==1 & css_loandecision==X & sample==1 \ replace itheor_get_loan_any=r(mean) if itheor_get_loan_any>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum theor_get_loan_any if lower_window!=1 & css_loandecision==X & sample==1 \ replace itheor_get_loan_any=r(mean) if itheor_get_loan_any>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum itheor_get_loan_any if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_itheor_get_loan_any=(itheor_get_loan_any-r(mean))/r(sd) if lower_window==1 & sample==1
	quietly sum itheor_get_loan_any if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_itheor_get_loan_any=(itheor_get_loan_any-r(mean))/r(sd) if lower_window!=1 & sample==1
	lab var itheor_get_loan_any "standardized 'theor_get_loan_any' dummy for trust index"
	drop itheor_get_loan_any
	gen itheor_get_loan_any=theor_get_loan_any if !mi(theor_get_loan_any) & sample==1
	lab var itheor_get_loan_any "unstandardized 'theor_get_loan_any' dummy (trust index)"

gen itrust=(std_ifu_trust_take_advan+std_ifu_trust_groups_neighb+std_ifu_trust_groups_know_pers+std_ifu_trust_groups_bus+std_itheor_get_loan+std_itheor_get_loan_lots+std_itheor_get_loan_any)/7
	lab var itrust "Unweighted trust index"
*	replace itrust=. if std_ifu_trust_take_advan==. | std_ifu_trust_groups_neighb==. | std_ifu_trust_groups_know_pers==. | std_ifu_trust_groups_bus==. | std_itheor_get_loan==. | std_itheor_get_loan_lots==. | std_itheor_get_loan_any==.

***
***  tables 
***

log using fmb_t9_X.log, replace

***  trust people take advantage of you
oprobit fu_trust_take_advantage css_loandecision lower_window if sample==1, robust
estimates store m1, title((1))
oprobit fu_trust_take_advantage css_loandecision male x_male_decision lower_window if sample==1, robust
estimates store m2, title((2))
oprobit fu_trust_take_advantage css_loandecision above_medinc_app x_above_med_inc_decision lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_trust_take_advantage_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  trust people in neighborhood
oprobit fu_trust_groups_neighborhood css_loandecision lower_window if sample==1, robust
estimates store m1, title((1))
oprobit fu_trust_groups_neighborhood css_loandecision male x_male_decision lower_window if sample==1, robust
estimates store m2, title((2))
oprobit fu_trust_groups_neighborhood css_loandecision above_medinc_app x_above_med_inc_decision lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_trust_groups_neighborhood_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  trust people you know personally
oprobit fu_trust_groups_know_personally css_loandecision lower_window if sample==1, robust
estimates store m1, title((1))
oprobit fu_trust_groups_know_personally css_loandecision male x_male_decision lower_window if sample==1, robust
estimates store m2, title((2))
oprobit fu_trust_groups_know_personally css_loandecision above_medinc_app x_above_med_inc_decision lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_trust_groups_know_personally_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  trust business associates
oprobit fu_trust_groups_business_assoc css_loandecision lower_window if sample==1, robust
estimates store m1, title((1))
oprobit fu_trust_groups_business_assoc css_loandecision male x_male_decision lower_window if sample==1, robust
estimates store m2, title((2))
oprobit fu_trust_groups_business_assoc css_loandecision above_medinc_app x_above_med_inc_decision lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_trust_groups_business_assoc_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

foreach x in fu_trust_take_advantage fu_trust_groups_neighborhood fu_trust_groups_know_personally fu_trust_groups_business_assoc {
	sum `x' if sample==1
	sum `x'	if sample==1 & female==1
	sum `x' if sample==1 & female==0
	sum `x'	if sample==1 & above_medinc_app==1
	sum `x'	if sample==1 & above_medinc_app==0
}

***  can get assistance
xi: reg theor_get_loan css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg theor_get_loan css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg theor_get_loan css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_trust_get_loan_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  can get 10,000 plus
xi: reg theor_get_loan_lots css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg theor_get_loan_lots css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg theor_get_loan_lots css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_trust_get_loan_lots_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  can get any
xi: reg theor_get_loan_any css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg theor_get_loan_any css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg theor_get_loan_any css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_trust_get_loan_any_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  index
xi: reg itrust css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg itrust css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg itrust css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_trust_itrust_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

foreach x in theor_get_loan theor_get_loan_lots theor_get_loan_any itrust {
	sum `x' if sample==1
	sum `x'	if sample==1 & female==1
	sum `x' if sample==1 & female==0
	sum `x'	if sample==1 & above_medinc_app==1
	sum `x'	if sample==1 & above_medinc_app==0
}

capture: log close

***************************


***************************************************************************************************************************************
*** created by kareem haggag; last modified by luke crowley april 29th, 2009                                                        ***
*** for data analysis of impact of credit access study at First Macro Bank (philippines)                                            ***
*** household income and consumption                                                                                                ***
***                                                                                                                                 ***
*** files used:                                                                                                                     ***
***    fmbfinaldata.dta                                                                                                             ***
***************************************************************************************************************************************

clear
set more off
set mem 400m
set maxvar 10000
capture: log close
tempfile fu_loan_amount

use fmbfinaldata, clear

***
***  splits
***

***  Median income at time of application
egen medinc_app=median(css_netweeklyamt) if sample==1 
gen above_medinc_app=0 if sample==1
lab var above_medinc_app "Above median income at time of application"
replace above_medinc_app=1 if css_netweeklyamt>medinc_app & sample==1

gen male=female
recode male (0=1) (1=0)
gen x_male_decision=male*css_loandecision if sample==1
gen x_above_med_inc_decision=above_medinc_app*css_loandecision if sample==1

***
***  household (included in index) analysis variables
***

***  adjust income - ".c" Not Applicable should be counted as 0 income
gen income=fu_hh_total_inc if sample==1
replace income=0 if fu_hh_total_inc==.c & sample==1
xtile pctile_income=income if income<. & sample==1, n(100)
lab var pctile_income "Percentile of income"
gen lnincome=log(income)
lab var lnincome "Log of income"
gen income_trim=income if pctile_income>1 & pctile_income<100 & sample==1
lab var income_trim "Income, trim top & bottom percentiles"

***  household size
gen hhsize=0 if sample==1 
forval x=1/15 {
	replace hhsize=hhsize+1 if fu_hh_mem_name_`x'!="" & sample==1
}
lab var hhsize "Number of household members"

***  poverty line
***  note: 20566/year/capita  for 2006 National Capital District - source: National Statistical Coordination Board - http://www.nscb.gov.ph/poverty/2006_05mar08/table_1.asp
***  for reference: incidence is 7.1% for all families in National Capital Region
gen above_povline=(fu_hh_total_inc>(1713.8333*hhsize)) if fu_hh_total_inc<. & hhsize<. & sample==1
lab var above_povline "Household above poverty line"

***  food quality
gen food_qual=(fu_hh_food_comp==4 | fu_hh_food_comp==5) if sample==1
lab var food_qual "Food quality improved"

***  no one was prevented from going to the doctor in the last 12 months due to financial constraints
gen could_go2doc=0 if fu_hh_not_seek_treat==1
replace could_go2doc=1 if fu_hh_not_seek_treat==0
lab var could_go2doc "No one in household prevented from going to doctor b/c financial constraints"

***  remittances
gen lnrem_rec=log(fu_hh_rec_rem_amt+1) if sample==1
lab var lnrem_rec "Log of remittances received"
replace lnrem_rec=log(1) if lnrem_rec==. & fu_hh_rec_rem<. & sample==1 
gen lnrem_send=log(fu_hh_send_rem_amt+1) if sample==1
lab var lnrem_send "Log of remittances sent"
replace lnrem_send=log(1) if lnrem_send==. & fu_hh_send_rem<. & sample==1

gen rem_rec=fu_hh_rec_rem if sample==1
lab var rem_rec "Any remittances received"
replace rem_rec=1 if fu_hh_rec_rem_amt<. & fu_hh_rec_rem_amt>0 & sample==1
gen rem_send=fu_hh_send_rem if sample==1
lab var rem_send "Any remittances sent"
replace rem_send=1 if fu_hh_send_rem_amt<. & fu_hh_send_rem_amt>0 & sample==1

***
***  tables
***

log using fmb_t10_X.log, replace

***  income
xi: reg income css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg income css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg income css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_hh_income_X.txt, cells(b(star fmt(%12.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  income, trimmed
xi: reg income_trim css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg income_trim css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg income_trim css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_hh_income_trim_X.txt, cells(b(star fmt(%12.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  log of income
xi: reg lnincome css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg lnincome css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg lnincome css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_hh_lnincome_X.txt, cells(b(star fmt(%12.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  above the poverty line
xi: reg above_povline css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg above_povline css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg above_povline css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_hh_above_povline_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  remittances received
xi: reg rem_rec css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg rem_rec css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg rem_rec css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_remit_any_rec_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  food quality
xi: reg food_qual css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg food_qual css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg food_qual css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_hh_food_qual_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  could go to doctor
xi: reg could_go2doc css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg could_go2doc css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg could_go2doc css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_hh_could_go2doc_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) label collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

foreach x in income income_trim lnincome above_povline rem_rec food_qual could_go2doc {
	sum `x' if sample==1 
	sum `x'	if sample==1 & female==1
	sum `x' if sample==1 & female==0
	sum `x'	if sample==1 & above_medinc_app==1
	sum `x'	if sample==1 & above_medinc_app==0
}

capture: log close

*************************************************



***************************************************************************************************************************************
*** created by kareem haggag; last modified by luke crowley april 29th, 2010                                                        ***
*** for data analysis of impact of credit access study at First Macro Bank (philippines)                                            ***
*** subjective well-being                                                                                                           ***
***                                                                                                                                 ***
*** files used:                                                                                                                     ***
***    fmbfinaldata.dta                                                                                                             ***
***************************************************************************************************************************************

clear
set more off
set mem 400m
set maxvar 10000
capture: log close
tempfile fu_loan_amount

use fmbfinaldata, clear

***
***  splits
***

***  Median income at time of application
egen medinc_app=median(css_netweeklyamt) if sample==1 
gen above_medinc_app=0 if sample==1
lab var above_medinc_app "Above median income at time of application"
replace above_medinc_app=1 if css_netweeklyamt>medinc_app & sample==1

gen male=female
recode male (0=1) (1=0)
gen x_male_decision=male*css_loandecision if sample==1
gen x_above_med_inc_decision=above_medinc_app*css_loandecision if sample==1

***
***  variables
***

***  calmness
***  fix error in coding of calmness scale:
replace fu_worry_calm=2 if fu_worry_calm==1
replace fu_worry_calm=1 if fu_worry_calm==0
gen calm=fu_worry_calm
lab var calm "Calmness Scale (1-6) 1==Worry All the Time, 6=Worry None of the Time"

***  binary worry
gen noworry=0 if fu_worry==1
replace noworry=1 if fu_worry==0
lab var noworry "Respondent has NOT had a month in the past year where they felt mostly worried/anxious"

***  happiness / life satisfaction
gen life_satisfied=fu_happiness_satisfied_life
lab var life_satisfied "Life Satisfaction Scale (1-4) 1=Not at all, 4=Very"

***  job satisfaction
gen job_satisfied=fu_happiness_satisfied_work
lab var job_satisfied "Job Satisfaction Scale (1-10) 1=dissatisfied"

***  job stress scale (1-12)
gen jobstress=0
	for X in any fu_happiness_job_stressful fu_happiness_job_time fu_happiness_job_tired: replace jobstress=jobstress+1 if X==4
	for X in any fu_happiness_job_stressful fu_happiness_job_time fu_happiness_job_tired: replace jobstress=jobstress+2 if X==3
	for X in any fu_happiness_job_stressful fu_happiness_job_time fu_happiness_job_tired: replace jobstress=jobstress+3 if X==2
	for X in any fu_happiness_job_stressful fu_happiness_job_time fu_happiness_job_tired: replace jobstress=jobstress+4 if X==1
	replace jobstress=. if fu_happiness_job_stressful>=. | fu_happiness_job_time>=. | fu_happiness_job_tired>=.
	gen nojobstress=-jobstress
	lab var nojobstress "Job Stress scale for respondent (scale -12 to 0) -12=always stressed,tired, & busy (positive increase = less stress)"

***  optimism
***  note: 4 of the 10 questions on the survey are standard filler questions that psychologists (and us) do not use to construct the optimism scale.
gen optimism = 0
	lab var optimism "Optimism scale (scale 6-30)"
	note optimism: Higher score=more optimism.
	note optimism: Only asked to primary respondents (not hh surveys), so sample size=551 (2 missing).
foreach var of varlist fu_optimism_expect_best fu_optimism_optimist  fu_optimism_more_good_than_bad{
	replace optimism=optimism+5 if `var'==5
	replace optimism=optimism+4 if `var'==4
	replace optimism=optimism+3 if `var'==3
	replace optimism=optimism+2 if `var'==2
	replace optimism=optimism+1 if `var'==1
	}
foreach var of varlist fu_optimism_never_expect fu_optimism_good_things  fu_optimism_go_wrong{
	replace optimism=optimism+1 if `var'==5
	replace optimism=optimism+2 if `var'==4
	replace optimism=optimism+3 if `var'==3
	replace optimism=optimism+4 if `var'==2
	replace optimism=optimism+5 if `var'==1
	}
replace optimism=. if optimism==0 | fu_optimism_never_expect>=. | fu_optimism_good_things>=. | fu_optimism_go_wrong>=. | fu_optimism_expect_best>=. | fu_optimism_optimist>=. | fu_optimism_more_good_than_bad>=.

***  decision-making scales (sample size: 995 respondents)
gen decmakingsample=(fu_hh_marriage_1==2 | fu_hh_marriage_1==4) if fu_hh_marriage_1!=. & fu_hh_female_1!=.
lab var decmakingsample "1 if in sample for decision making variables"
rename fu_decision_market_cook fu_decision_market
rename fu_decision_family_planning  fu_decision_fam_plan
rename fu_decision_assistance fu_decision_assist
***  clean scale components: who_decides questions
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: gen d_X=.
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace d_X=0 if fu_hh_female_1==1 & X==2
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace d_X=1 if fu_hh_female_1==1 & X==3
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace d_X=2 if fu_hh_female_1==1 & X==1
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace d_X=0 if fu_hh_female_1==0 & X==1
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace d_X=1 if fu_hh_female_1==0 & X==3
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace d_X=2 if fu_hh_female_1==0 & X==2
***  clean scale components: who_prevails questions
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: gen p_X=.
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace p_X=0 if X_conflict==1 & fu_hh_female_1==1 & X_prevail==2
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace p_X=1 if X_conflict==1 & fu_hh_female_1==1 & X_prevail==3
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace p_X=2 if X_conflict==1 & fu_hh_female_1==1 & X_prevail==1
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace p_X=0 if X_conflict==1 & fu_hh_female_1==0 & X_prevail==1
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace p_X=1 if X_conflict==1 & fu_hh_female_1==0 & X_prevail==3
	for X in any fu_decision_market fu_decision_appliances fu_decision_children fu_decision_fam_plan fu_decision_assist fu_decision_personal fu_decision_recreation fu_decision_sell fu_decision_work fu_decision_school: replace p_X=2 if X_conflict==1 & fu_hh_female_1==0 & X_prevail==2
egen decmakingscale=rsum(d_*) if decmakingsample==1
	egen tmp=rownonmiss(d_*) if decmakingsample==1
	count if tmp!=0
	***  6 cases? recode as missing
	replace decmakingscale=. if tmp==.
	drop tmp
	lab var decmakingscale "Decision-making scale for the applicant (range 0-26)"
	note decmakingscale: Score range 0-26. Higher is more power for the applicant with the Lender.
	note decmakingscale: Decision-making questions only asked to married/partnered applicants: 779 respondents
egen tmp=median(decmakingscale) if sample==1
	gen decmakingscale_above=(decmakingscale>=tmp) if !(decmakingscale>=.) & (sample==1)
	lab var decmakingscale_above "Dummy=1 if decision making scale above median"
	gen decmakingscale_below=(decmakingscale<tmp) if !(decmakingscale>=.) & (sample==1)
	lab var decmakingscale_below "Dummy=1 if decision making scale below median"
	drop tmp
drop decmakingsample

***  socio-economic ladder (oprobit of fu_ladder_self_barangay fu_ladder_self_philippines fu_ladder_creditworthiness)
gen se_ladder_b=fu_ladder_self_barangay
gen se_ladder_p=fu_ladder_self_philippines
gen credit_ladder=fu_ladder_creditworthiness

***
***  index
***

gen ioptimism=optimism if sample==1
	for X in num 0 1: quietly sum optimism if lower_window==1 & css_loandecision==X & sample==1 \ replace ioptimism=r(mean) if ioptimism>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum optimism if lower_window!=1 & css_loandecision==X & sample==1 \ replace ioptimism=r(mean) if ioptimism>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum ioptimism if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_ioptimism=(ioptimism-r(mean))/r(sd) if lower_window==1
	quietly sum ioptimism if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_ioptimism=(ioptimism-r(mean))/r(sd) if lower_window!=1
	lab var ioptimism "standardized 'optimism' dummy for subjective well-being index"
	drop ioptimism
	gen ioptimism=optimism if !mi(optimism)
	lab var ioptimism "unstandardized 'optimism' dummy (subjective well-being index)"
gen inoworry=noworry if sample==1
	for X in num 0 1: quietly sum noworry if lower_window==1 & css_loandecision==X & sample==1 \ replace inoworry=r(mean) if inoworry>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum noworry if lower_window!=1 & css_loandecision==X & sample==1 \ replace inoworry=r(mean) if inoworry>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum inoworry if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_inoworry=(inoworry-r(mean))/r(sd) if lower_window==1
	quietly sum inoworry if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_inoworry=(inoworry-r(mean))/r(sd) if lower_window!=1
	lab var inoworry "standardized 'no worry' dummy for subjective well-being index"
	drop inoworry
	gen inoworry=noworry if !mi(noworry)
	lab var inoworry "unstandardized 'no worry' dummy (subjective well-being index)"
gen icalm=calm if sample==1
	for X in num 0 1: quietly sum calm if lower_window==1 & css_loandecision==X & sample==1 \ replace icalm=r(mean) if icalm>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum calm if lower_window!=1 & css_loandecision==X & sample==1 \ replace icalm=r(mean) if icalm>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum icalm if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_icalm=(icalm-r(mean))/r(sd) if lower_window==1
	quietly sum icalm if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_icalm=(icalm-r(mean))/r(sd) if lower_window!=1
	lab var icalm "standardized 'calmness' dummy for subjective well-being index"
	drop icalm
	gen icalm=calm if !mi(calm)
	lab var icalm "unstandardized 'calmness' dummy (subjective well-being)"
gen ilife_satisfied=life_satisfied if sample==1
	for X in num 0 1: quietly sum life_satisfied if lower_window==1 & css_loandecision==X & sample==1 \ replace ilife_satisfied=r(mean) if ilife_satisfied>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum life_satisfied if lower_window!=1 & css_loandecision==X & sample==1 \ replace ilife_satisfied=r(mean) if ilife_satisfied>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum ilife_satisfied if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_ilife_satisfied=(ilife_satisfied-r(mean))/r(sd) if lower_window==1
	quietly sum ilife_satisfied if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_ilife_satisfied=(ilife_satisfied-r(mean))/r(sd) if lower_window!=1
	lab var ilife_satisfied "standardized 'life_satisfied' dummy for subjective well-being index"
	drop ilife_satisfied
	gen ilife_satisfied=life_satisfied if !mi(life_satisfied)
	lab var ilife_satisfied "unstandardized 'life_satisfied' dummy (subjective well-being index)"
gen ijob_satisfied=job_satisfied if sample==1
	for X in num 0 1: quietly sum job_satisfied if lower_window==1 & css_loandecision==X & sample==1 \ replace ijob_satisfied=r(mean) if ijob_satisfied>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum job_satisfied if lower_window!=1 & css_loandecision==X & sample==1 \ replace ijob_satisfied=r(mean) if ijob_satisfied>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum ijob_satisfied if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_ijob_satisfied=(ijob_satisfied-r(mean))/r(sd) if lower_window==1
	quietly sum ijob_satisfied if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_ijob_satisfied=(ijob_satisfied-r(mean))/r(sd) if lower_window!=1
	lab var ijob_satisfied "standardized 'job_satisfied' dummy for subjective well-being index"
	drop ijob_satisfied
	gen ijob_satisfied=job_satisfied if !mi(job_satisfied)
	lab var ijob_satisfied "unstandardized 'job_satisfied' dummy (subjective well-being index)"
gen inojobstress=nojobstress if sample==1
	for X in num 0 1: quietly sum nojobstress if lower_window==1 & css_loandecision==X & sample==1 \ replace inojobstress=r(mean) if inojobstress>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum nojobstress if lower_window!=1 & css_loandecision==X & sample==1 \ replace inojobstress=r(mean) if inojobstress>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum inojobstress if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_inojobstress=(inojobstress-r(mean))/r(sd) if lower_window==1
	quietly sum inojobstress if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_inojobstress=(inojobstress-r(mean))/r(sd) if lower_window!=1
	lab var inojobstress "standardized 'nojobstress' dummy for subjective well-being index"
	drop inojobstress
	gen inojobstress=nojobstress if !mi(nojobstress)
	lab var inojobstress "unstandardized 'nojobstress' dummy (subjective well-being index)"
gen idecmakingscale=decmakingscale if sample==1
	for X in num 0 1: quietly sum decmakingscale if lower_window==1 & css_loandecision==X & sample==1 & (fu_hh_marriage_1==2 | fu_hh_marriage_1==4) \ replace idecmakingscale=r(mean) if idecmakingscale>=. & lower_window==1 & css_loandecision==X & sample==1 
	for X in num 0 1: quietly sum decmakingscale if lower_window!=1 & css_loandecision==X & sample==1 & (fu_hh_marriage_1==2 | fu_hh_marriage_1==4) \ replace idecmakingscale=r(mean) if idecmakingscale>=. & lower_window!=1 & css_loandecision==X & sample==1 
	replace idecmakingscale=0 if !(fu_hh_marriage_1==2 | fu_hh_marriage_1==4) & fu_hh_marriage_1!=. & sample==1
	quietly sum idecmakingscale if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_idecmakingscale=(idecmakingscale-r(mean))/r(sd) if lower_window==1
	quietly sum idecmakingscale if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_idecmakingscale=(idecmakingscale-r(mean))/r(sd) if lower_window!=1
	lab var idecmakingscale "standardized 'decmakingscale' dummy for subjective well-being index"
	note std_idecmakingscale: Non-married people were assigned a 0 on index after imputation (imputation done with married/partnered(live-in) respondents only).
	drop idecmakingscale
	gen idecmakingscale=decmakingscale if !mi(decmakingscale)
	lab var idecmakingscale "unstandardized 'decmakingscale' dummy (subjective well-being index)"
gen ise_ladder_b=se_ladder_b if sample==1
	for X in num 0 1: quietly sum se_ladder_b if lower_window==1 & css_loandecision==X & sample==1 \ replace ise_ladder_b=r(mean) if ise_ladder_b>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum se_ladder_b if lower_window!=1 & css_loandecision==X & sample==1 \ replace ise_ladder_b=r(mean) if ise_ladder_b>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum ise_ladder_b if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_ise_ladder_b=(ise_ladder_b-r(mean))/r(sd) if lower_window==1
	quietly sum ise_ladder_b if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_ise_ladder_b=(ise_ladder_b-r(mean))/r(sd) if lower_window!=1
	lab var ise_ladder_b "standardized 'se_ladder_b' dummy for subjective well-being index"
	drop ise_ladder_b
	gen ise_ladder_b=se_ladder_b if !mi(se_ladder_b)
	lab var ise_ladder_b "unstandardized 'se_ladder_b' dummy (subjective well-being index)"
gen ise_ladder_p=se_ladder_p if sample==1
	for X in num 0 1: quietly sum se_ladder_p if lower_window==1 & css_loandecision==X & sample==1 \ replace ise_ladder_p=r(mean) if ise_ladder_p>=. & lower_window==1 & css_loandecision==X & sample==1
	for X in num 0 1: quietly sum se_ladder_p if lower_window!=1 & css_loandecision==X & sample==1 \ replace ise_ladder_p=r(mean) if ise_ladder_p>=. & lower_window!=1 & css_loandecision==X & sample==1
	quietly sum ise_ladder_p if css_loandecision==0 & sample==1 & lower_window==1
	gen double std_ise_ladder_p=(ise_ladder_p-r(mean))/r(sd) if lower_window==1
	quietly sum ise_ladder_p if css_loandecision==0 & sample==1 & lower_window!=1
	replace std_ise_ladder_p=(ise_ladder_p-r(mean))/r(sd) if lower_window!=1
	lab var ise_ladder_p "standardized 'se_ladder_p' dummy for subjective well-being index"
	drop ise_ladder_p
	gen ise_ladder_p=se_ladder_p if !mi(se_ladder_p)
	lab var ise_ladder_p "unstandardized 'se_ladder_p' dummy (subjective well-being index)"
gen iwellb=(std_ioptimism+std_inoworry+std_icalm+std_ilife_satisfied+std_ijob_satisfied+std_inojobstress+std_idecmakingscale+std_ise_ladder_b+std_ise_ladder_p)/9
	lab var iwellb "Unweighted subjective well-being index"

***
***  tables
***

log using fmb_t11_X.log, replace

***  optimism
xi: reg optimism css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg optimism css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg optimism css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_wellb_optimism_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) lab collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  calmness
xi: reg calm css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg calm css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg calm css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_wellb_calm_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) lab collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  no worry
xi: reg noworry css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg noworry css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg noworry css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_wellb_noworry_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) lab collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  life satisfaction
xi: reg life_satisfied css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg life_satisfied css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg life_satisfied css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_wellb_life_satisfied_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) lab collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  job satisfaction
xi: reg job_satisfied css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg job_satisfied css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg job_satisfied css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_wellb_job_satisfied_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) lab collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  job stress
xi: reg nojobstress css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg nojobstress css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg nojobstress css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_wellb_job_stress_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) lab collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  decision-making power
xi: reg decmakingscale css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg decmakingscale css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg decmakingscale css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_wellb_decmakingscale_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) lab collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  socio-economic ladder, others in village
xi: reg se_ladder_b css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg se_ladder_b css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg se_ladder_b css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_wellb_se_ladder_b_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) lab collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  socio-economic ladder, others in philippines
xi: reg se_ladder_p css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg se_ladder_p css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg se_ladder_p css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_wellb_se_ladder_p_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) lab collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

***  index
xi: reg iwellb css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg iwellb css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))
xi: reg iwellb css_loandecision above_medinc_app x_above_med_inc_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m3, title((3))

#delimit ;
estout * using outreg\estout_wellb_iwellb_X.txt, cells(b(star fmt(%9.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2) (3)) lab collabels(,none)
keep(css_loandecision x_male_decision x_above_med_inc_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
estimates clear

foreach x in optimism calm noworry life_satisfied job_satisfied nojobstress decmakingscale se_ladder_b se_ladder_p iwellb {
	sum `x' if sample==1
	sum `x'	if sample==1 & female==1
	sum `x'	if sample==1 & female==0 
	sum `x'	if sample==1 & above_medinc_app==1
	sum `x'	if sample==1 & above_medinc_app==0
}

capture: log close

*************************************


***************************************************************************************************************************************
*** created by Henriette Hanicotte (based on luke crowley do files), February 2nd, 2011                                             ***                                        ***
*** for data analysis of impact of credit access study at First Macro Bank (philippines)                                            ***
*** borrowing in month before survey                                                                                                ***
***                                                                                                                                 ***
*** files used:                                                                                                                     ***
***    fmbfinaldata.dta                                                                                                             ***
***************************************************************************************************************************************

clear
set more off
set mem 400m
set maxvar 10000
capture log close
tempfile fu_loan_amount

use fmbfinaldata, clear

***
***  splits
***

gen male=female
recode male (0=1) (1=0)
gen x_male_decision=male*css_loandecision if sample==1


***
***  tables -- business size
***

*** create 'total profit of businesses' variable

replace fu_profit_2 =0 if fu_profit_2>=. & (fu_profit_1 !=. & fu_profit_1 !=.b & fu_profit_1 !=.c)
replace fu_profit_3 =0 if fu_profit_3>=. & (fu_profit_2 !=. & fu_profit_2 !=.b & fu_profit_2 !=.c)
replace fu_profit_4 =0 if fu_profit_4>=. & (fu_profit_3 !=. & fu_profit_3 !=.b & fu_profit_3 !=.c)
replace fu_profit_5 =0 if fu_profit_5>=. & (fu_profit_4 !=. & fu_profit_4 !=.b & fu_profit_4 !=.c)
replace fu_profit_6 =0 if fu_profit_6>=. & (fu_profit_5 !=. & fu_profit_5 !=.b & fu_profit_5 !=.c)
replace fu_profit_7 =0 if fu_profit_7>=. & (fu_profit_6 !=. & fu_profit_6 !=.b & fu_profit_6 !=.c)
replace fu_profit_8 =0 if fu_profit_8>=. & (fu_profit_7 !=. & fu_profit_7 !=.b & fu_profit_7 !=.c)

gen profit_business= fu_profit_1 + fu_profit_2 + fu_profit_3 + fu_profit_4 + fu_profit_5 + fu_profit_6 + fu_profit_7 + fu_profit_8
replace profit_business=. if profit_business==0

*** create 'total inventory of businesses' variable

replace fu_inventory_2 =0 if fu_inventory_2>=. & (fu_inventory_1 !=. & fu_inventory_1 !=.b & fu_inventory_1 !=.c)
replace fu_inventory_3 =0 if fu_inventory_3>=. & (fu_inventory_2 !=. & fu_inventory_2 !=.b & fu_inventory_2 !=.c)
replace fu_inventory_4 =0 if fu_inventory_4>=. & (fu_inventory_3 !=. & fu_inventory_3 !=.b & fu_inventory_3 !=.c)
replace fu_inventory_5 =0 if fu_inventory_5>=. & (fu_inventory_4 !=. & fu_inventory_4 !=.b & fu_inventory_4 !=.c)
replace fu_inventory_6 =0 if fu_inventory_6>=. & (fu_inventory_5 !=. & fu_inventory_5 !=.b & fu_inventory_5 !=.c)
replace fu_inventory_7 =0 if fu_inventory_7>=. & (fu_inventory_6 !=. & fu_inventory_6 !=.b & fu_inventory_6 !=.c)
replace fu_inventory_8 =0 if fu_inventory_8>=. & (fu_inventory_7 !=. & fu_inventory_7 !=.b & fu_inventory_7 !=.c)

gen inventory_business= fu_inventory_1 + fu_inventory_2 + fu_inventory_3 + fu_inventory_4 + fu_inventory_5 + fu_inventory_6 + fu_inventory_7 + fu_inventory_8
replace inventory_business=. if inventory_business==0

*** create 'total gross sales of businesses' variable

replace fu_gross_sales_2 =0 if fu_gross_sales_2>=. & (fu_gross_sales_1 !=. & fu_gross_sales_1 !=.b & fu_gross_sales_1 !=.c)
replace fu_gross_sales_3 =0 if fu_gross_sales_3>=. & (fu_gross_sales_2 !=. & fu_gross_sales_2 !=.b & fu_gross_sales_2 !=.c) 
replace fu_gross_sales_4 =0 if fu_gross_sales_4>=. & (fu_gross_sales_3 !=. & fu_gross_sales_3 !=.b & fu_gross_sales_3 !=.c) 
replace fu_gross_sales_5 =0 if fu_gross_sales_5>=. & (fu_gross_sales_4 !=. & fu_gross_sales_4 !=.b & fu_gross_sales_4 !=.c) 
replace fu_gross_sales_6 =0 if fu_gross_sales_6>=. & (fu_gross_sales_5 !=. & fu_gross_sales_5 !=.b & fu_gross_sales_5 !=.c) 
replace fu_gross_sales_7 =0 if fu_gross_sales_7>=. & (fu_gross_sales_6 !=. & fu_gross_sales_6 !=.b & fu_gross_sales_6 !=.c) 
replace fu_gross_sales_8 =0 if fu_gross_sales_8>=. & (fu_gross_sales_7 !=. & fu_gross_sales_7 !=.b & fu_gross_sales_7 !=.c)  

gen gross_sales_business= fu_gross_sales_1 + fu_gross_sales_2 + fu_gross_sales_3 + fu_gross_sales_4 + fu_gross_sales_5 + fu_gross_sales_6 + fu_gross_sales_7 + fu_gross_sales_8
replace gross_sales_business=. if gross_sales_business==0

log using fmb_science_theory.log, replace

*** regressions

gen sales =log(gross_sales_business )

xi: reg sales css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg sales css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))

#delimit ;
estout * using outreg\fmb_science_impact_logsales.txt, cells(b(star fmt(%12.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2)) label collabels(,none)
keep(css_loandecision x_male_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

gen inventory=log(inventory_business)
xi: reg inventory css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg inventory css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))

#delimit ;
estout * using outreg\fmb_science_impact_loginventory.txt, cells(b(star fmt(%12.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2)) label collabels(,none)
keep(css_loandecision x_male_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

gen profit=log(profit_business)

xi: reg profit css_loandecision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m1, title((1))
xi: reg profit css_loandecision male x_male_decision i.fu_survey_month i.fu_survey_year i.app_month i.app_year lower_window if sample==1, robust
estimates store m2, title((2))

#delimit ;
estout * using outreg\fmb_science_impact_logprofits.txt, cells(b(star fmt(%12.3f)) se(par)) stats(r2 N, fmt(%9.3f %9.0g)) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01)
mlabels((1) (2)) label collabels(,none)
keep(css_loandecision x_male_decision)
prehead() postfoot(@starlegend.) replace margin nodiscrete ;
#delimit cr
est clear

foreach x in gross_sales_business inventory_business profit_business  { 
	sum `x' if sample==1 & css_loandecision==0 
	sum `x' if sample==1 & css_loandecision==0 & female==1
	sum `x' if sample==1 & css_loandecision==0 & female==0 
}


capture: log close


***************************************















